@@ -3,8 +3,7 @@
 #include "macro.h"
 
 #ifdef PERMTRUE
-INT cast_apply_barperm(a) OP a;
-/* AK 280294 */
+INT cast_apply_barperm(OP a)
 {
     INT erg = OK;
     EOP("cast_apply_barperm(1)",a);
@@ -24,13 +23,13 @@ INT cast_apply_barperm(a) OP a;
                 }
         default:
             printobjectkind(a);
-            erg += WTO("cast_apply_barperm",a);
+            WTO("cast_apply_barperm",a);
             break;
         }
     ENDR("cast_apply_barperm");
 }
 
-INT invers_bar(a,b) OP a,b;
+INT invers_bar(OP a, OP b)
 {
     INT i,erg =OK,j;
     CH2D(a,b);
@@ -38,7 +37,7 @@ INT invers_bar(a,b) OP a,b;
     erg += absolute(S_P_S(a),S_P_S(b));
     erg += invers(b,b);
     for (i=0L;i<S_P_LI(a);i++)
-        if (S_P_II(a,i) < 0) 
+        if (S_P_II(a,i) < 0)
             {
             j = (S_P_II(a,i)+1)* (-1);
             M_I_I(S_P_II(b,j) * -1, S_P_I(b,j));
@@ -47,7 +46,7 @@ INT invers_bar(a,b) OP a,b;
     ENDR("invers_bar");
 }
 
-INT new_divdiff_bar(a,b,c) OP a,b,c;
+INT new_divdiff_bar(OP a, OP b, OP c)
 {
     OP d;
     INT erg = OK;
@@ -59,7 +58,7 @@ INT new_divdiff_bar(a,b,c) OP a,b,c;
     ENDR("new_divdiff_bar");
 
 }
-INT divdiff_bar(a,b,c) OP a,b,c;
+INT divdiff_bar(OP a, OP b, OP c)
 {
     OP d;
     INT erg = OK;
@@ -72,42 +71,40 @@ INT divdiff_bar(a,b,c) OP a,b,c;
 
 }
 
-INT new_divideddiff_rz_bar(rzt,poly,c) OP    rzt, poly, c;
-/* AK 020392 */
 /* rzt is reduced decomposition of barred permutation */
+INT new_divideddiff_rz_bar(OP rzt, OP poly, OP c)
 {
     INT i = 0 ;
     INT erg = OK;
     erg += copy (poly,c);
-    if (EMPTYP(rzt)) 
+    if (EMPTYP(rzt))
         goto endr_ende;
     while (i < S_V_LI(rzt))
-    { 
+    {
         erg += new_divideddifference_bar(S_V_I(rzt,i),c,c);
-        i++; 
+        i++;
     };
     ENDR("new_divideddiff_rz_bar");
 }
 
-INT divideddiff_rz_bar(rzt,poly,c) OP    rzt, poly, c;
-/* AK 020392 */
 /* rzt is reduced decomposition of barred permutation */
+INT divideddiff_rz_bar(OP rzt, OP poly, OP c)
 {
     INT i = 0 ;
     INT erg = OK;
     erg += copy (poly,c);
-    if (EMPTYP(rzt)) 
+    if (EMPTYP(rzt))
         goto endr_ende;
     while (i < S_V_LI(rzt))
-    { 
+    {
         erg += divideddifference_bar(S_V_I(rzt,i),c,c);
-        i++; 
+        i++;
     };
     ENDR("divideddiff_rz_bar");
 }
 
 #ifdef POLYTRUE
-INT divideddifference_bar(i,poly,c) OP i,poly,c;
+INT divideddifference_bar(OP i, OP poly, OP c)
 {
 
     OP     zeiger = poly, zwischen;
@@ -116,15 +113,15 @@ INT divideddifference_bar(i,poly,c) OP i,poly,c;
     if (EMPTYP(poly)) return(OK);
     zwischen = callocobject();
     if (poly == c)
-    { 
+    {
         *zwischen = *c;
         C_O_K(c,0);
         erg += divideddifference_bar(i,zwischen,c);
-        erg += freeall(zwischen); 
+        erg += freeall(zwischen);
         return erg;
     };
     init(POLYNOM,c);
-        
+
     if (index < 0L) /* symplectic */
         {
         index++;
@@ -159,10 +156,10 @@ INT divideddifference_bar(i,poly,c) OP i,poly,c;
 
     while (zeiger != NULL)
     {
-        if (S_L_S(zeiger) !=  NULL) 
+        if (S_L_S(zeiger) !=  NULL)
         {
         if (S_O_K(S_PO_S(zeiger)) != VECTOR)
-        { 
+        {
             printobjectkind(S_PO_S(zeiger));
             error("kind != VECTOR in divideddifference_bar");
             return(ERROR);
@@ -170,9 +167,9 @@ INT divideddifference_bar(i,poly,c) OP i,poly,c;
 
         if (S_I_I(i) == S_PO_SLI(zeiger))
         /* operiert auf letzten exponenten */
-        { 
+        {
             inc(S_PO_S(zeiger));
-            M_I_I(0L,S_PO_SI(zeiger,S_I_I(i))); 
+            M_I_I(0L,S_PO_SI(zeiger,S_I_I(i)));
         }
         else if (S_I_I(i) > S_PO_SLI(zeiger)) goto dividedend;
         expo1 = S_PO_SII(zeiger,index);
@@ -180,7 +177,7 @@ INT divideddifference_bar(i,poly,c) OP i,poly,c;
         if (expo1 > expo2)
         {
             for (j=expo1-1L,k=expo2 ;j>= expo2; j--,k++)
-            { 
+            {
             b_skn_po(callocobject(),callocobject(),NULL,zwischen);
             copy(S_PO_S(zeiger),S_PO_S(zwischen));
             copy(S_PO_K(zeiger),S_PO_K(zwischen));
@@ -207,13 +204,12 @@ INT divideddifference_bar(i,poly,c) OP i,poly,c;
 dividedend:
         zeiger = S_PO_N(zeiger);
     };
-    freeall(zwischen); 
+    freeall(zwischen);
     return(OK);
 }
 #endif /* POLYTRUE */
 
-INT rz_bar(a,b) OP a,b;
-/* AK 050995 */
+INT rz_bar(OP a, OP b)
 {
     INT erg = OK;
     OP c;
@@ -226,8 +222,7 @@ INT rz_bar(a,b) OP a,b;
     ENDR("rz_bar");
 }
 
-INT rz_lehmercode_bar(a,b) OP a,b;
-/* AK 020392 */
+INT rz_lehmercode_bar(OP a, OP b)
 {
     OP e,f,g;
     INT i,j,k;
@@ -261,10 +256,8 @@ ende:
     ENDR("rz_lehmercode_bar");
 }
 
-INT sscan_bar(t,a) OP a; char *t;
-/* AK 050194 to read permutation from string
-        format [1,2,3,..]
-*/
+/* read permutation from string format [1,2,3,..] */
+INT sscan_bar(char *t, OP a)
 {
     INT erg = OK;
     COP("sscan_bar(1)",t);
@@ -275,8 +268,7 @@ INT sscan_bar(t,a) OP a; char *t;
     ENDR("sscan_permutation");
 }
 
-INT scan_bar(b) OP b;
-/* AK 230695 */
+INT scan_bar(OP b)
 {
     INT erg=OK;
     CTO(EMPTY,"scan_bar(1)",b);
@@ -295,11 +287,10 @@ spa:
     ENDR("scan_bar");
 }
 
-INT strong_check_barp(a) OP a;
-/* AK 230695 */
+INT strong_check_barp(OP a)
 {
     OP h;
-    INT i,SYM_abs();
+    INT i;
 
     if (a == NULL)
         return FALSE;
@@ -314,17 +305,17 @@ INT strong_check_barp(a) OP a;
         if (S_P_S(a) == NULL)
             return FALSE;
         if (
-            (S_O_K(S_P_S(a)) != INTEGERVECTOR) 
+            (S_O_K(S_P_S(a)) != INTEGERVECTOR)
              &&
-             (S_O_K(S_P_S(a)) != VECTOR) 
-           )                       
+             (S_O_K(S_P_S(a)) != VECTOR)
+           )
             return FALSE;
         h = callocobject();
         m_il_v(S_P_LI(a),h);
         for (i=0L;i<S_V_LI(h);i++)
             M_I_I(i+(INT)1, S_V_I(h,i));
         for (i=0L;i<S_V_LI(h);i++)
-            M_I_I((INT)0, S_V_I(h,SYM_abs(S_P_II(a,i)) -(INT)1));
+            M_I_I((INT)0, S_V_I(h,labs(S_P_II(a,i)) -(INT)1));
         i = nullp(h);
         freeall(h);
         return i;
@@ -333,8 +324,7 @@ INT strong_check_barp(a) OP a;
 }
 
 
-INT first_bar(a,b) OP a,b;
-/* AK 230695 */
+INT first_bar(OP a, OP b)
 {
     INT erg = OK;
     CTO(INTEGER,"first_bar",a);
@@ -344,9 +334,8 @@ INT first_bar(a,b) OP a,b;
     ENDR("first_bar");
 }
 
-INT max_bar(a,b) OP a,b;
-/* AK 060995 */
 /* barred perm with maiximal reduced length */
+INT max_bar(OP a, OP b)
 {
     INT i,erg = OK;
     CTO(INTEGER,"max_bar",a);
@@ -360,8 +349,7 @@ INT max_bar(a,b) OP a,b;
 }
 
 
-INT ordcon_bar(a,b) OP a,b;
-/* AK 260292 */
+INT ordcon_bar(OP a, OP b)
 {
     OP c;
     INT erg = OK;
@@ -376,8 +364,7 @@ INT ordcon_bar(a,b) OP a,b;
     ENDR("ordcon_bar");
 }
 
-INT ordcen_bar(a,b) OP a,b;
-/* AK 260292 */
+INT ordcen_bar(OP a, OP b)
 {
     INT i,j;
     INT erg = OK;
@@ -388,9 +375,9 @@ INT ordcen_bar(a,b) OP a,b;
     for (i=0L;i<S_M_HI(a);i++)
     for (j=0L;j<S_M_LI(a);j++)
         {
-        erg += fakul(S_M_IJ(a,i,j),c); 
+        erg += fakul(S_M_IJ(a,i,j),c);
         erg += mult_apply(c,b);
-        erg += m_i_i((i+1L) * 2L,c); 
+        erg += m_i_i((i+1L) * 2L,c);
         erg += hoch(c,S_M_IJ(a,i,j),c);
         erg += mult_apply(c,b);
         }
@@ -398,14 +385,13 @@ INT ordcen_bar(a,b) OP a,b;
     ENDR("ordcen_bar");
 }
 
-INT makevectorof_class_rep_bar(a,b) OP a,b;
-/* AK 260292 */
+INT makevectorof_class_rep_bar(OP a, OP b)
 {
     INT i,erg=OK;
     OP c;
     CTO(INTEGER,"makevectorof_class_rep_bar(1)",a);
     c = callocobject();
-    
+
     erg += makevectorof_class_bar(a,c);
     erg += m_il_v(S_V_LI(c),b);
     for (i=0L;i<S_V_LI(c);i++)
@@ -414,8 +400,7 @@ INT makevectorof_class_rep_bar(a,b) OP a,b;
     ENDR("makevectorof_class_rep_bar");
 }
 
-INT makevectorof_class_bar(a,b) OP a,b;
-/* AK 260292 */
+INT makevectorof_class_bar(OP a, OP b)
 {
     INT i,erg=OK;
     OP c;
@@ -427,12 +412,11 @@ INT makevectorof_class_bar(a,b) OP a,b;
     for (i=0L;i<S_V_LI(b);i++)
         erg += kranztypus_to_matrix(S_V_I(c,i),S_V_I(b,i));
     erg += freeall(c);
-    erg += SYM_sort(b); /* AK 130592 */
+    erg += SYM_sort(b);
     ENDR("makevectorof_class_bar");
 }
 
-INT class_rep_bar(a,b) OP a,b;
-/* AK 260292 */
+INT class_rep_bar(OP a, OP b)
 {
     INT i,j,k=0L,l;
     m_il_p(S_M_HI(a),b);
@@ -457,7 +441,7 @@ INT class_rep_bar(a,b) OP a,b;
                 m_i_i(k+2L,S_P_I(b,k));
                 k++;
                 }
-            m_i_i(k-i,S_P_I(b,k-1L)); /* damit ist ein i+1 Zykel 
+            m_i_i(k-i,S_P_I(b,k-1L)); /* damit ist ein i+1 Zykel
                             fertig */
             }
         }
@@ -465,8 +449,7 @@ INT class_rep_bar(a,b) OP a,b;
 }
 
 
-INT class_bar(a,b) OP a,b;
-/* AK 260292 */
+INT class_bar(OP a, OP b)
 {
     INT i,j,k,m,n;
     INT erg = OK;
@@ -500,8 +483,7 @@ INT class_bar(a,b) OP a,b;
     ENDR("class_bar");
 }
 
-INT t_BARCYCLE_BAR(a,b) OP a,b;
-/* AK 260292 */
+INT t_BARCYCLE_BAR(OP a, OP b)
 {
     INT i,j;
     INT erg = OK;
@@ -528,8 +510,7 @@ INT t_BARCYCLE_BAR(a,b) OP a,b;
     ENDR("t_BARCYCLE_BAR");
 }
 
-INT t_BAR_BARCYCLE(a,b) OP a,b;
-/* AK 260292 */
+INT t_BAR_BARCYCLE(OP a, OP b)
 {
     INT i,j;
     OP c = callocobject();
@@ -551,8 +532,7 @@ INT t_BAR_BARCYCLE(a,b) OP a,b;
     return OK;
 }
 
-INT mult_bar_bar(a,b,c) OP a,b,c;
-/* AK 250292 */
+INT mult_bar_bar(OP a, OP b, OP c)
 {
     INT i;
     INT erg = OK;
@@ -565,12 +545,9 @@ INT mult_bar_bar(a,b,c) OP a,b,c;
     C_P_K(c,BAR);
     for (i=0L;i<S_P_LI(c);i++)
     {
-    if (S_P_II(b,i) < 0L) 
+    if (S_P_II(b,i) < 0L)
         {
-        /* if (S_P_II(a, - S_P_II(b,i) -1L)  > 0L) */
             erg += m_i_i(- S_P_II(a,- S_P_II(b,i)-1L), S_P_I(c,i));
-        /* else
-            erg += m_i_i(- S_P_II(a,- S_P_II(b,i)-1L), S_P_I(c,i));*/
         }
     else
         erg += m_i_i(S_P_II(a,S_P_II(b,i)-1L), S_P_I(c,i));
@@ -579,8 +556,7 @@ INT mult_bar_bar(a,b,c) OP a,b,c;
     ENDR("mult_bar_bar");
 }
 
-INT random_bar(n,b) OP n,b;
-/* AK 250292 */
+INT random_bar(OP n, OP b)
 {
     OP a,c;
     INT i,erg = OK;
@@ -596,7 +572,7 @@ INT random_bar(n,b) OP n,b;
     for (i=0L;i<S_I_I(n);i++)
         {
         erg += random_integer(c,NULL,NULL);
-        if (oddp(c)) 
+        if (oddp(c))
             erg += m_i_i(1L,S_V_I(S_V_I(a,0L),i));
         }
     erg += lehmercode_vector_bar(a,b);
@@ -605,8 +581,7 @@ INT random_bar(n,b) OP n,b;
     ENDR("random_bar");
 }
 
-INT length_bar(a,b) OP a,b;
-/* AK 250292 */
+INT length_bar(OP a, OP b)
 {
     OP c,d;
     INT i,erg = OK;
@@ -629,8 +604,7 @@ INT length_bar(a,b) OP a,b;
     ENDR("length_bar");
 }
 
-INT lehmercode_bar(a,b) OP a,b;
-/* AK 250292 */
+INT lehmercode_bar(OP a, OP b)
 {
     INT i,j;
     INT erg = OK;
@@ -642,7 +616,7 @@ INT lehmercode_bar(a,b) OP a,b;
     m_l_nv(S_P_L(a),S_V_I(b,1L));
     for (i=0L;i<S_P_LI(a);i++)
         {
-        if (S_P_II(a,i) < 0L) 
+        if (S_P_II(a,i) < 0L)
             m_i_i(1L,S_V_I(S_V_I(b,0L),-S_P_II(a,i) -1L));
         for (j=i+1L;j<S_P_LI(a);j++)
             if (S_P_II(a,j) < S_P_II(a,i))
@@ -652,15 +626,13 @@ INT lehmercode_bar(a,b) OP a,b;
 }
 
 
-INT next_apply_bar(a) OP a;
-/* AK 120902 V2.1 */ 
+INT next_apply_bar(OP a)
 {
     return next_bar(a,a);
 }
-INT next_bar(a,b) OP a,b;
-/* AK 230695 */
-/* AK 120902 V2.1 */
+
 /* a and b may be equal */
+INT next_bar(OP a, OP b)
 {
     INT erg,i;
     OP c,d;
@@ -700,11 +672,11 @@ INT next_bar(a,b) OP a,b;
          M_I_I(1,S_V_I(S_V_I(d,0L),i));
     for (;i<S_P_LI(a);i++)
          M_I_I(0,S_V_I(S_V_I(d,0L),i));
-        
+
 bb:
     lehmercode_vector_bar(d,b);
     erg = OK;
-    
+
 aa:
     freeall(c);
     freeall(d);
@@ -712,8 +684,7 @@ aa:
 }
 
 
-INT lehmercode_vector_bar(a,b) OP a,b;
-/* AK 250292 */
+INT lehmercode_vector_bar(OP a, OP b)
 {
     INT i,j,k;
     OP self,liste,vec;
@@ -724,8 +695,8 @@ INT lehmercode_vector_bar(a,b) OP a,b;
 
     m_il_v(k,self);
     m_il_v(k,liste);
-    /* initialisierung zweier vektoren fuer
-        eine Liste und fuer die zu berechnende Permutation */
+    /* initialisierung zweier vektoren fuer eine Liste und fuer die zu
+     * berechnende Permutation */
     j=0L;
     for(i=k-1L;i>=0L;i--)
         {
@@ -746,8 +717,8 @@ INT lehmercode_vector_bar(a,b) OP a,b;
         M_I_I(S_V_II(liste,k),S_V_I(self,i));
         /* daher ist ei = k-te Element aus der aktuellen Liste*/
         for (j=k;j<(S_V_LI(vec)-1L)-i;j++)
-            /* in der liste wird das k-te Element gestrichen.
-            und von rechts aufgefuellt */
+            /* in der liste wird das k-te Element gestrichen. und von
+             * rechts aufgefuellt */
             C_I_I(S_V_I(liste,j),S_V_II(liste,j+1L));
     };
     freeall(liste);
@@ -759,15 +730,13 @@ INT lehmercode_vector_bar(a,b) OP a,b;
 
 #ifdef POLYTRUE
 
-INT new_divideddifference_bar(i,poly,c) OP i,poly,c;
+INT new_divideddifference_bar(OP i, OP poly, OP c)
 {
     divideddifference_bar(i,poly,c);
-/*    if (S_I_I(i) > 0) 
-        addinvers(c,c); */
     return OK;
 }
 
-INT scalarproduct_bar_schubert(a,b,g) OP a,b,g;
+INT scalarproduct_bar_schubert(OP a, OP b, OP g)
 {
     INT erg = OK;
     OP c,d,e,f;
@@ -791,14 +760,14 @@ INT scalarproduct_bar_schubert(a,b,g) OP a,b,g;
     ENDR("scalarproduct_bar_schubert");
 }
 
-INT starting_bar_schubert(n,res) OP n,res;
+INT starting_bar_schubert(OP n, OP res)
 {
     OP a,b,c,y,e,d;
     INT i;
     FILE *fp;
     char s[100];
 
-    sprintf(s,"startbarschubert%ld",S_I_I(n));
+    sprintf(s,"startbarschubert%" PRIdPTR,S_I_I(n));
     fp = fopen(s,"r");
     if (fp != NULL)
         {
@@ -817,7 +786,7 @@ INT starting_bar_schubert(n,res) OP n,res;
 
     compute_elmsym_with_alphabet(b,n,res);
     b_skn_po(callocobject(),callocobject(),NULL,d);
-    if (((S_I_I(n)*(S_I_I(n)-1))/2)%2 == 0) 
+    if (((S_I_I(n)*(S_I_I(n)-1))/2)%2 == 0)
             m_i_i(1L,S_PO_K(d));
     else
             m_i_i(-1L,S_PO_K(d));
@@ -837,7 +806,7 @@ INT starting_bar_schubert(n,res) OP n,res;
     return OK;
 }
 
-INT m_bar_schubert(bar,res) OP bar,res;
+INT m_bar_schubert(OP bar, OP res)
 {
     OP a,b,c,y,e,d;
     INT erg = OK;
@@ -854,7 +823,7 @@ INT m_bar_schubert(bar,res) OP bar,res;
 
 
     erg += max_bar(S_P_L(bar),e);
-    erg += mult(bar,e,b); 
+    erg += mult(bar,e,b);
 
     erg += freeself(res);
     erg += new_divdiff_bar(b,c,res);
@@ -870,7 +839,7 @@ INT m_bar_schubert(bar,res) OP bar,res;
 
 #endif /* POLYTRUE */
 
-INT t_bar_doubleperm(a,b) OP a,b;
+INT t_bar_doubleperm(OP a, OP b)
 {
     INT i,k;
     b_ks_p(VECTOR,callocobject(),b);
@@ -891,9 +860,8 @@ INT t_bar_doubleperm(a,b) OP a,b;
     return OK;
 }
 
-INT bar_rectr(a,v) OP a,v;
-/* input double perm output rectr */
-/* half of rectr of s_2n */
+/* input double perm output rectr. half of rectr of s_2n */
+INT bar_rectr(OP a, OP v)
 {
 OP  b,u; INT i,k,x,y,z,iv,i1;
                    b=callocobject();u=callocobject();
@@ -912,21 +880,19 @@ OP  b,u; INT i,k,x,y,z,iv,i1;
     return OK;
 }
 
-INT comp_bigr_perm(u,perm)  OP u,perm;
-/* compare bigrassmannian (= vector of length 3 ) with permutation */
-/* returns TRUE if u <= perm in bruhat order FALSE else */
-/* works for s_n */
+/* compare bigrassmannian (= vector of length 3 ) with permutation.
+ * returns TRUE if u <= perm in bruhat order FALSE else. works for s_n
+ */
+INT comp_bigr_perm(OP u, OP perm)
 {  INT i,x,r0,r1,r2;
         r0=S_V_II(u,0L);r1=S_V_II(u,1L);r2=S_V_II(u,2L); x=0L;
   for(i=0L;i<r0+r1;i++)  { if (S_P_II(perm,i) >r0+r2 ) x++; }
       if(x< r1) return (FALSE); else return (TRUE);
 }
 
-/*   rectrices  de Sn sur 3 composantes; renvoie 1 si  u <= v , 0 sinon */
-INT comp_bigr_bigr(u,v)  OP u,v;
-/* compares according bruhat */
-/* returns 1 if u <= v */
-/* works for s_n */
+/* rectrices de Sn sur 3 composantes; renvoie 1 si u <= v , 0 sinon.
+ * compares according bruhat.  returns 1 if u <= v.  works for s_n. */
+INT comp_bigr_bigr(OP u, OP v)
 { if (S_V_II(u,0L)< S_V_II(v,0L) ) return 0L;
   if (S_V_II(u,1L)>S_V_II(v,1L)) return 0L;
   if (S_V_II(u,2L)>S_V_II(v,2L)) return 0L;
