@@ -1,6 +1,6 @@
 #include "def.h"
 #include "macro.h"
-/* AK  291288 */
+
 typedef struct node {
     char * _key; /* dies enthaelt ein object */
     struct node * _l, * _r;
@@ -19,62 +19,60 @@ typedef enum {
 VISIT;
 
 
-static INT AK_twalk();
-static void AK_tfree();
-static char ** AK_tsearch();
-static char ** AK_tdelete();
-static char ** AK_tfind();
-static void walk();
-static void freeself_bintree_action();
-static void fprint_bintree_action();
-static void insert_bt_bt_action();
-static void copy_bintree_action();
-static void t_BINTREE_LIST_action();
-static void t_BINTREE_SCHUR_action();
-static void t_BINTREE_POLYNOM_action();
-static void t_BINTREE_HOMSYM_action();
-static void t_BINTREE_ELMSYM_action();
-static void t_BINTREE_POWSYM_action();
-static void t_BINTREE_MONOMIAL_action();
-static void t_BINTREE_SCHUBERT_action();
-static void t_BINTREE_GRAL_action();
-static void t_BINTREE_SCHUR_action_apply();
-static void t_BINTREE_POLYNOM_action_apply();
-static void t_BINTREE_HOMSYM_action_apply();
-static void t_BINTREE_POWSYM_action_apply();
-static void t_BINTREE_MONOMIAL_action_apply();
-static void t_BINTREE_ELMSYM_action_apply();
+static INT AK_twalk(Node *, void (*)(OP*,VISIT,INT));
+static void AK_tfree(Node **, void (*)(OP *, VISIT, OP, INT (*)(OP,OP), INT (*)(OP,OP)), OP, INT (*)(OP,OP), INT (*)(OP,OP));
+static char ** AK_tsearch(char *, Node **, INT (*)(char*,char*));
+static char ** AK_tdelete(char *, Node **, INT (*)(char*,char*));
+static char ** AK_tfind(char *k, Node **rootp, INT (*compar)(char*,char*));
+static void walk(Node *, void (*)(OP*,VISIT,INT), INT);
+static void freeself_bintree_action(OP *, VISIT, OP, INT (*)(OP,OP), INT (*)(OP,OP));
+static void fprint_bintree_action(OP *, VISIT, INT);
+static void insert_bt_bt_action(OP *, VISIT, OP, INT (*)(OP,OP), INT (*)(OP,OP));
+static void copy_bintree_action(OP *, VISIT, INT);
+static void t_BINTREE_LIST_action(OP *, VISIT, INT);
+static void t_BINTREE_SCHUR_action(OP *, VISIT, INT);
+static void t_BINTREE_POLYNOM_action(OP *, VISIT, INT);
+static void t_BINTREE_HOMSYM_action(OP *, VISIT, INT);
+static void t_BINTREE_ELMSYM_action(OP *, VISIT, INT);
+static void t_BINTREE_POWSYM_action(OP *, VISIT, INT);
+static void t_BINTREE_MONOMIAL_action(OP *, VISIT, INT);
+static void t_BINTREE_SCHUBERT_action(OP *, VISIT, INT);
+static void t_BINTREE_GRAL_action(OP *, VISIT, INT);
+static void t_BINTREE_SCHUR_action_apply(OP *, VISIT, INT);
+static void t_BINTREE_POLYNOM_action_apply(OP *, VISIT, INT);
+static void t_BINTREE_HOMSYM_action_apply(OP *, VISIT, INT);
+static void t_BINTREE_POWSYM_action_apply(OP *, VISIT, INT);
+static void t_BINTREE_MONOMIAL_action_apply(OP *, VISIT, INT);
+static void t_BINTREE_ELMSYM_action_apply(OP *, VISIT, INT);
 
 static char *_bt_p1, *_bt_p2, *_bt_p3; /* fur twalk */
-#define TWALK(a,b) AK_twalk((Node *)a,b)
-#define TSEARCH AK_tsearch
-#define TFIND(a,b,c) AK_tfind((char*)a,(Node **) b,c)
-#define TDELETE AK_tdelete
+#define TWALK(a,b) AK_twalk((Node *)a, b)
+#define TSEARCH(a,b,c) AK_tsearch((char *)a, (Node **)b, c)
+#define TFIND(a,b,c) AK_tfind((char*)a, (Node **) b, c)
+#define TDELETE(a,b,c) AK_tdelete((char*)a, (Node **)b, c)
 
 #ifdef BINTREETRUE
-static void freeself_bintree_action(a,type) OP *a; VISIT type;
-/* AK 210891 V1.3 */
+static void freeself_bintree_action(OP *a, VISIT type, OP bt, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
-    if ((type==postorder) ||  (type==leaf))     
+    if ((type==postorder) ||  (type==leaf))
         freeall(*a);
 }
 
 
-INT freeself_bintree(a) OP a;
-/* AK 050891 V1.3 */
+INT freeself_bintree(OP a)
 {
     OBJECTSELF d ;
     d = S_O_S(a);
-    AK_tfree(& d.ob_charpointer,freeself_bintree_action,NULL,NULL,NULL);
+
+    // Cast to Node** should be OK since the first member of
+    // a Node struct is a char*?
+    AK_tfree((Node**)&d.ob_charpointer,freeself_bintree_action,NULL,NULL,NULL);
     C_O_K(a,EMPTY);
-    return OK; /* AK 050891 */
+    return OK;
 }
 
 
-
-
-INT init_bintree(a) OP a;
-/* AK 050891 V1.3 */
+INT init_bintree(OP a)
 {
     OBJECTSELF d;
     C_O_K(a,BINTREE);
@@ -84,9 +82,7 @@ INT init_bintree(a) OP a;
 }
 
 
-
-static void length_bintree_action(a,type,l) OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void length_bintree_action(OP *a, VISIT type, INT l)
 {
     OP p1 = (OP ) _bt_p1;
     if ((type==postorder)||  (type==leaf))
@@ -95,16 +91,15 @@ static void length_bintree_action(a,type,l) OP *a;VISIT type;INT l;
     }
 }
 
-static void fprint_bintree_action(a,type,l) OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void fprint_bintree_action(OP *a, VISIT type, INT l)
 {
     FILE *p1 = (FILE *) _bt_p1;
     if ((type==postorder)||  (type==leaf))
     {
         fprint(p1,*a);
         fprintf(p1," ");
-        if (p1==stdout) 
-            {    
+        if (p1==stdout)
+            {
             zeilenposition++;
             if (zeilenposition >70L) {
                 fprintf(p1,"\n");
@@ -116,10 +111,8 @@ static void fprint_bintree_action(a,type,l) OP *a;VISIT type;INT l;
 
 
 
-INT length_bintree(a,b) OP a,b;
-/* AK 211097 */
+INT length_bintree(OP a, OP b)
 {
-    void length_bintree_action();
     OBJECTSELF d;
     m_i_i(0,b);
     d = S_O_S(a);
@@ -134,11 +127,10 @@ INT length_bintree(a,b) OP a,b;
     return OK;
 }
 
-INT fprint_bintree(fp,a) FILE *fp; OP a;
-/* AK 050891 V1.3 */
+
 /* gibt einen bintree aus */
+INT fprint_bintree(FILE *fp, OP a)
 {
-    void fprint_bintree_action();
     OBJECTSELF d;
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
@@ -157,28 +149,24 @@ INT fprint_bintree(fp,a) FILE *fp; OP a;
 }
 
 
-
-INT insert_bintree(a,bt,eh,cf) OP a,bt; INT (*cf)(), (*eh)();
-/* fuegt a in bintree bt ein */
-/* cf ist die vergleichsfunktion
-       eh gibt die operation bei schon vorhandenem
-       gleichen eintrag an */
-/* AK 040189 */ /* AK 210891 V1.3 */
+/* fuegt a in bintree bt ein. cf ist die vergleichsfunktion eh gibt
+ * die operation bei schon vorhandenem gleichen eintrag an */
+INT insert_bintree(OP a, OP bt, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     INT erg = OK;
     char ** result;
 
-    if (S_O_K(a) == BINTREE) 
+    if (S_O_K(a) == BINTREE)
         {
         OBJECTSELF d;
         d = S_O_S(a);
-        if (d.ob_charpointer == NULL) /* AK 300997 */
+        if (d.ob_charpointer == NULL)
             {
             freeall(a);
             return INSERTOK;
             }
         d = S_O_S(bt);
-                if (d.ob_charpointer == NULL) /* AK 300997 */
+                if (d.ob_charpointer == NULL)
                         {
                         swap(a,bt);
             freeall(a);
@@ -201,49 +189,52 @@ INT insert_bintree(a,bt,eh,cf) OP a,bt; INT (*cf)(), (*eh)();
         return INSERTOK;
         }
 
-    if (cf == NULL) cf = comp;
     /* default wert */
+    if (cf == NULL) cf = comp;
 
-    result = TSEARCH(a, &((S_O_S(bt)).ob_charpointer) ,cf);
-    if (*result == (char *)a) 
+    // ignore char* <-> OP type mismatch in comparison function?
+    INT (*charcf)(char*,char*) = (INT (*)(char*,char*))cf;
+
+    result = TSEARCH(a, &((S_O_S(bt)).ob_charpointer), charcf);
+    if (*result == (char *)a)
         return INSERTOK;
                 /* d.h. das element wurde eingefuegt */
     else             /* d.h. es wurde ein gleiches element festgestelt
-                und result ist ein pointer darauf */
+		      * und result ist ein pointer darauf */
         {
-        if (eh != NULL) 
-            (*eh)(a,*result);
+        if (eh != NULL)
+            (*eh)(a,(OP)*result);
         if (EMPTYP((OP)*result)) /* eq-handle hat geloescht */
             {
             OP z = (OP)*result;
             *z = *a;
-            TDELETE(a,&((S_O_S(bt)).ob_charpointer) ,cf);
+            TDELETE(a, &((S_O_S(bt)).ob_charpointer), charcf);
             C_O_K(z,EMPTY);
             FREEALL(z);
             }
         FREEALL(a);
-        
+
         return INSERTEQ;
         }
     ENDR("insert_bintree");
 }
 
 
-
-INT insert_bt_bt(a,bt,eh,cf) OP a,bt; INT (*cf)(), (*eh)();
-/* fuegt a was auch bintree ist in bintree bt ein */
-/* cf ist die vergleichsfunktion
-       eh gibt die operation bei schon vorhandenem
-       gleichen eintrag an */
-/* AK 090189 */ /* AK 210891 V1.3 */
+/* fuegt a was auch bintree ist in bintree bt ein.cf ist die
+ * vergleichsfunktion eh gibt die operation bei schon vorhandenem
+ * gleichen eintrag an.
+ */
+INT insert_bt_bt(OP a, OP bt, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     OBJECTSELF d;
     INT erg = OK;
     CTO(BINTREE,"insert_bt_bt(1)",a);
     CTO(BINTREE,"insert_bt_bt(2)",bt);
-        
+
     d = S_O_S(a);
-    AK_tfree(&d.ob_charpointer,insert_bt_bt_action,bt,eh,cf);
+    // Cast to Node** should be OK since the first member of
+    // a Node struct is a char*?
+    AK_tfree((Node**)&d.ob_charpointer,insert_bt_bt_action,bt,eh,cf);
     C_O_K(a,EMPTY); /* leer setzen */
     erg += freeall(a);
     ENDR("insert_bt_bt");
@@ -251,9 +242,7 @@ INT insert_bt_bt(a,bt,eh,cf) OP a,bt; INT (*cf)(), (*eh)();
 
 
 
-static void insert_bt_bt_action(a,type,bt,eh,cf)OP *a,bt; VISIT type; 
-        INT (*eh)(),(*cf)();
-/* AK 210891 V1.3 */
+static void insert_bt_bt_action(OP *a, VISIT type, OP bt, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     INT insert_erg;
 
@@ -265,8 +254,7 @@ static void insert_bt_bt_action(a,type,bt,eh,cf)OP *a,bt; VISIT type;
 
 
 
-INT copy_bintree(a,b) OP a,b;
-/* AK 210891 V1.3 */
+INT copy_bintree(OP a, OP b)
 {
     OBJECTSELF d;
 
@@ -279,8 +267,7 @@ INT copy_bintree(a,b) OP a,b;
     return OK;
 }
 
-static void copy_bintree_action(a,type,l) OP *a; VISIT type; INT l;
-/* AK 210891 V1.3 */
+static void copy_bintree_action(OP *a, VISIT type, INT l)
 {
     OP bt = (OP) _bt_p1;
     if ((type==postorder)||  (type==leaf))
@@ -292,31 +279,29 @@ static void copy_bintree_action(a,type,l) OP *a; VISIT type; INT l;
 }
 
 
-OP find_user_bintree(a,b,f) OP a,b; INT (*f)();
+OP find_user_bintree(OP a, OP b, INT (*f)(char*,char*))
 {
     char ** result;
-    result = TFIND(a, &((S_O_S(b)).ob_charpointer) ,f);
+    result = TFIND(a, &((S_O_S(b)).ob_charpointer), f);
     if (result == NULL) return NULL;
     return (OP) *result;
 }
 
-OP find_bintree(a,b) OP a,b;
 /* test ob a in b */
-/* AK 050396 */
+OP find_bintree(OP a, OP b)
 {
     char ** result;
-    result = TFIND(a, &((S_O_S(b)).ob_charpointer) ,comp);
+
+    // ignore char* <-> OP type mismatch in comparison function?
+    INT (*charcf)(char*,char*) = (INT (*)(char*,char*))comp;
+
+    result = TFIND(a, &((S_O_S(b)).ob_charpointer), charcf);
     if (result == NULL) return NULL;
     return (OP) *result;
-    
 }
 
 
-
-static Node ** bi_find(k,rootp,compar, parent, c) char *k; 
-    register Node ** rootp; INT (*compar)(); 
-    Node ** parent; INT *c;
-/* AK 210891 V1.3 */
+static Node ** bi_find(char *k, Node ** rootp, INT (*compar)(char*,char*), Node ** parent, INT *c)
 {
     *parent = (Node *) 0;
     if (rootp && *rootp)
@@ -340,9 +325,7 @@ static Node ** bi_find(k,rootp,compar, parent, c) char *k;
 }
 
 
-static char ** AK_tfind(k,rootp,compar) char *k; 
-    register Node ** rootp;
-    INT (*compar)();
+static char ** AK_tfind(char *k, Node **rootp, INT (*compar)(char*,char*))
 {
     Node * parent;
         INT c;
@@ -353,11 +336,9 @@ static char ** AK_tfind(k,rootp,compar) char *k;
 }
 
 
-static char ** AK_tdelete(k,rootp,compar) char *k;
-        register Node ** rootp;
-        INT (*compar)();
-{
 /* Schreiner: UNIX Sprechstude p.248 */
+static char ** AK_tdelete(char *k, Node ** rootp, INT (*compar)(char*,char*))
+{
     register Node *p;
     char **result;
     Node * parent; INT c;
@@ -405,16 +386,13 @@ static char ** AK_tdelete(k,rootp,compar) char *k;
     return result;
 }
 
-static char ** AK_tsearch(k,rootp,compar) char *k; 
-    register Node ** rootp;
-    INT (*compar)();
-/* AK 210891 V1.3 */
+static char ** AK_tsearch(char *k, Node ** rootp, INT (*compar)(char*,char*))
 {
     register Node *p;
     Node * parent;
     INT c;
 
-    if ((rootp = bi_find(k,rootp,compar, &parent, &c)))
+    if ((rootp = bi_find(k,rootp,compar, &parent, &c))) {
         if (*rootp && c == 0)
             return (&KEY(*rootp));
         else if ((p = (Node *) SYM_malloc(sizeof(Node))))
@@ -434,35 +412,33 @@ static char ** AK_tsearch(k,rootp,compar) char *k;
             RTAG(p) = 1;
             return (&KEY(p));
         }
+    }
     return ((char**) 0);
 }
 
 
-static void walk(root,action,l) register Node *root; 
-    void (*action) (); 
-    INT l; 
 /* fuer parameter bei action */
-
-/* AK 210891 V1.3 */
+static void walk(Node *root, void (*action)(OP*,VISIT,INT), INT l)
 {
+    /* ignore OP* <-> char** type mismatch on action function? */
+    void (*charaction)(char**,VISIT,INT) = (void (*)(char**,VISIT,INT))action;
+
     if (! LINKS(root) && RTAG(root))
-        (*action) (&KEY(root), leaf, l);
+        (*charaction) (&KEY(root), leaf, l);
     else
     {
-        (*action) (&KEY(root), preorder, l);
+        (*charaction) (&KEY(root), preorder, l);
         if (LINKS(root))
             walk(LINKS(root), action, l+1L);
-        (*action) (&KEY(root), postorder, l);
+        (*charaction) (&KEY(root), postorder, l);
         if (! RTAG(root))
             walk(RECHTS(root), action, l+1L);
-        (*action) (&KEY(root), endorder, l);
+        (*charaction) (&KEY(root), endorder, l);
 
     }
 }
 
-static INT AK_twalk(root,action) Node *root; 
-    void (*action) (); 
-/* AK 210891 V1.3 */
+static INT AK_twalk(Node *root, void (*action)(OP*,VISIT,INT))
 {
     if (root)
         walk(root,action,0L);
@@ -470,9 +446,11 @@ static INT AK_twalk(root,action) Node *root;
 }
 
 
-static void AK_tfree(rootp,a,bt,eh,cf) Node **rootp; void (*a)();
-    OP bt; INT (*eh)(); INT (*cf)();
-/* AK 210891 V1.3 */
+/* type of "a" inferred from insert_bt_bt which passes in
+ * a = insert_bt_bt_action. Likewise the types of "eh" and "cf"
+ * should match the args of insert_bt_bt_action.
+ */
+static void AK_tfree(Node **rootp, void (*a)(OP *, VISIT, OP, INT (*)(OP,OP), INT (*)(OP,OP)), OP bt, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     register Node *root,*p;
 
@@ -486,31 +464,30 @@ static void AK_tfree(rootp,a,bt,eh,cf) Node **rootp; void (*a)();
         if (RTAG(root))
         {
             if (a)
-                (* a)(&KEY(root), leaf,bt,eh,cf);
+                (* a)((OP*)&KEY(root), leaf,bt,eh,cf);
             do
             {
                 p=RECHTS(root),SYM_free(root),root=p;
                 if (! root)
                     return;
                 if (a)
-                    (* a)(&KEY(root),postorder,bt,eh,cf);
+                    (* a)((OP*)&KEY(root),postorder,bt,eh,cf);
             } while(RTAG(root));
         }
         else
         {
             if (a)
-                (* a)(&KEY(root),postorder,bt,eh,cf);
+                (* a)((OP*)&KEY(root),postorder,bt,eh,cf);
         }
         p=RECHTS(root),SYM_free(root),root=p;
     }
 }
 
 
-INT t_BINTREE_VECTOR(a,b) OP a,b;
-/* input: BINTREE object a
-   output: sorted VECTOR object b with copy of the objects in a as content */
-/* a and b may be equal */
-/* AK V2.0 170298 */
+/* input: BINTREE object a; output: sorted VECTOR object b with copy
+ * of the objects in a as content. a and b may be equal.
+ */
+INT t_BINTREE_VECTOR(OP a, OP b)
 {
     INT erg = OK;
     OP c;
@@ -522,13 +499,11 @@ INT t_BINTREE_VECTOR(a,b) OP a,b;
     ENDR("t_BINTREE_VECTOR");
 }
 
-INT t_BINTREE_LIST(a,b) OP a,b;
-/* wandelt einen BINTREE in ein LIST object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+/* wandelt einen BINTREE in ein LIST object um die liste ist nach den
+ * gleichen vergleich sortiert */
+INT t_BINTREE_LIST(OP a, OP b)
 {
-    void t_BINTREE_LIST_action();
-    INT erg = OK; /* AK 170392 */
+    INT erg = OK;
     OP h, *h2;
     OBJECTSELF d;
 
@@ -538,7 +513,7 @@ INT t_BINTREE_LIST(a,b) OP a,b;
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(LIST,b);    
+        erg += init(LIST,b);
         goto endr_ende;
         }
 
@@ -551,22 +526,21 @@ INT t_BINTREE_LIST(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     erg += TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_LIST_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         erg += b_sn_l(NULL,NULL,b);
 
     C_O_K(S_L_N(h),EMPTY);
     freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    erg += freeall(h); 
+    C_L_N(h,NULL);
+    erg += freeall(h);
     ENDR("t_BINTREE_LIST");
 }
 
 
 
-static void t_BINTREE_LIST_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_LIST_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder) ||  (type==leaf))
         {
@@ -579,11 +553,9 @@ static void t_BINTREE_LIST_action(a,type,l)OP *a;VISIT type;INT l;
 
 
 #ifdef SCHURTRUE
-INT t_BINTREE_SCHUR_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_SCHUR_apply(OP a)
 {
     OP b;
-    void t_BINTREE_SCHUR_action_apply();
     OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
@@ -605,7 +577,7 @@ INT t_BINTREE_SCHUR_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_SCHUR_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 {
@@ -620,16 +592,13 @@ INT t_BINTREE_SCHUR_apply(a) OP a;
     erg += swap(b,a);
     FREEALL(b);
 
-    
     ENDR("t_BINTREE_SCHUR_apply");
 }
 
-INT t_BINTREE_SCHUR(a,b) OP a,b;
-/* wandelt einen BINTREE in ein SCHUR object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+/* wandelt einen BINTREE in ein SCHUR object um die liste ist nach den
+ * gleichen vergleich sortiert */
+INT t_BINTREE_SCHUR(OP a, OP b)
 {
-    void t_BINTREE_SCHUR_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -640,11 +609,11 @@ INT t_BINTREE_SCHUR(a,b) OP a,b;
         erg += t_BINTREE_SCHUR_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(SCHUR,b);    
+        erg += init(SCHUR,b);
         goto endr_ende;
         }
 
@@ -658,9 +627,9 @@ INT t_BINTREE_SCHUR(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_SCHUR_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,SCHUR);
@@ -668,15 +637,14 @@ INT t_BINTREE_SCHUR(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    FREEALL(h); 
+    C_L_N(h,NULL);
+    FREEALL(h);
     ENDR("t_BINTREE_SCHUR");
 }
 
 
 
-static void t_BINTREE_SCHUR_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_SCHUR_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -687,8 +655,7 @@ static void t_BINTREE_SCHUR_action(a,type,l)OP *a;VISIT type;INT l;
         }
 }
 
-static void t_BINTREE_SCHUR_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+static void t_BINTREE_SCHUR_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -699,11 +666,9 @@ static void t_BINTREE_SCHUR_action_apply(a,type,l)OP *a;VISIT type;INT l;
                 }
 }
 
-INT t_BINTREE_POWSYM_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_POWSYM_apply(OP a)
 {
     OP b;
-    void t_BINTREE_POWSYM_action_apply();
     OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
@@ -728,7 +693,7 @@ INT t_BINTREE_POWSYM_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_POWSYM_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 {
@@ -744,16 +709,13 @@ INT t_BINTREE_POWSYM_apply(a) OP a;
     erg += swap(b,a);
     erg += freeall(b);
 
-    
     ENDR("t_BINTREE_POWSYM_apply");
 }
 
-INT t_BINTREE_POWSYM(a,b) OP a,b;
-/* wandelt einen BINTREE in ein POWSYM object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+/* wandelt einen BINTREE in ein POWSYM object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_POWSYM(OP a, OP b)
 {
-    void t_BINTREE_POWSYM_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -763,11 +725,11 @@ INT t_BINTREE_POWSYM(a,b) OP a,b;
         erg += t_BINTREE_POWSYM_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(POWSYM,b);    
+        erg += init(POWSYM,b);
         goto endr_ende;
         }
 
@@ -781,9 +743,9 @@ INT t_BINTREE_POWSYM(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_POWSYM_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,POWSYM);
@@ -791,15 +753,13 @@ INT t_BINTREE_POWSYM(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    erg += freeall(h); 
+    C_L_N(h,NULL);
+    erg += freeall(h);
     ENDR("t_BINTREE_POWSYM");
 }
 
 
-
-static void t_BINTREE_POWSYM_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_POWSYM_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -810,8 +770,7 @@ static void t_BINTREE_POWSYM_action(a,type,l)OP *a;VISIT type;INT l;
         *(OP**)_bt_p1 = & S_L_N(**(OP**)_bt_p1);
         }
 }
-static void t_BINTREE_POWSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+static void t_BINTREE_POWSYM_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -823,11 +782,9 @@ static void t_BINTREE_POWSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
                 }
 }
 
-INT t_BINTREE_ELMSYM_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_ELMSYM_apply(OP a)
 {
     OP b;
-    void t_BINTREE_ELMSYM_action_apply();
     OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
@@ -851,7 +808,7 @@ INT t_BINTREE_ELMSYM_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_ELMSYM_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 {
@@ -867,16 +824,14 @@ INT t_BINTREE_ELMSYM_apply(a) OP a;
     erg += swap(b,a);
     erg += freeall(b);
 
-    
     ENDR("t_BINTREE_ELMSYM_apply");
 }
 
-INT t_BINTREE_ELMSYM(a,b) OP a,b;
-/* wandelt einen BINTREE in ein ELMSYM object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+
+/* wandelt einen BINTREE in ein ELMSYM object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_ELMSYM(OP a, OP b)
 {
-    void t_BINTREE_ELMSYM_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -886,11 +841,11 @@ INT t_BINTREE_ELMSYM(a,b) OP a,b;
         erg += t_BINTREE_ELMSYM_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(ELMSYM,b);    
+        erg += init(ELMSYM,b);
         goto endr_ende;
         }
 
@@ -904,9 +859,9 @@ INT t_BINTREE_ELMSYM(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_ELMSYM_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,ELMSYM);
@@ -914,15 +869,13 @@ INT t_BINTREE_ELMSYM(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    erg += freeall(h); 
+    C_L_N(h,NULL);
+    erg += freeall(h);
     ENDR("t_BINTREE_ELMSYM");
 }
 
 
-
-static void t_BINTREE_ELMSYM_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_ELMSYM_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -933,8 +886,9 @@ static void t_BINTREE_ELMSYM_action(a,type,l)OP *a;VISIT type;INT l;
         *(OP**)_bt_p1 = & S_L_N(**(OP**)_bt_p1);
         }
 }
-static void t_BINTREE_ELMSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+
+
+static void t_BINTREE_ELMSYM_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -946,11 +900,9 @@ static void t_BINTREE_ELMSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
                 }
 }
 
-INT t_BINTREE_HOMSYM_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_HOMSYM_apply(OP a)
 {
     OP b;
-    void t_BINTREE_HOMSYM_action_apply();
     OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
@@ -974,7 +926,7 @@ INT t_BINTREE_HOMSYM_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_HOMSYM_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 {
@@ -990,16 +942,14 @@ INT t_BINTREE_HOMSYM_apply(a) OP a;
     erg += swap(b,a);
     erg += freeall(b);
 
-    
     ENDR("t_BINTREE_HOMSYM_apply");
 }
 
-INT t_BINTREE_HOMSYM(a,b) OP a,b;
-/* wandelt einen BINTREE in ein HOMSYM object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+
+/* wandelt einen BINTREE in ein HOMSYM object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_HOMSYM(OP a, OP b)
 {
-    void t_BINTREE_HOMSYM_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -1009,11 +959,11 @@ INT t_BINTREE_HOMSYM(a,b) OP a,b;
         erg += t_BINTREE_HOMSYM_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(HOMSYM,b);    
+        erg += init(HOMSYM,b);
         goto endr_ende;
         }
 
@@ -1027,9 +977,9 @@ INT t_BINTREE_HOMSYM(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_HOMSYM_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,HOMSYM);
@@ -1037,15 +987,13 @@ INT t_BINTREE_HOMSYM(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    erg += freeall(h); 
+    C_L_N(h,NULL);
+    erg += freeall(h);
     ENDR("t_BINTREE_HOMSYM");
 }
 
 
-
-static void t_BINTREE_HOMSYM_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_HOMSYM_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -1056,8 +1004,9 @@ static void t_BINTREE_HOMSYM_action(a,type,l)OP *a;VISIT type;INT l;
         *(OP**)_bt_p1 = & S_L_N(**(OP**)_bt_p1);
         }
 }
-static void t_BINTREE_HOMSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+
+
+static void t_BINTREE_HOMSYM_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -1072,12 +1021,11 @@ static void t_BINTREE_HOMSYM_action_apply(a,type,l)OP *a;VISIT type;INT l;
 #endif /* SCHURTRUE */
 
 #ifdef SCHUBERTTRUE
-INT t_BINTREE_SCHUBERT(a,b) OP a,b;
-/* wandelt einen BINTREE in ein SCHUBERT object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+
+/* wandelt einen BINTREE in ein SCHUBERT object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_SCHUBERT(OP a, OP b)
 {
-    void t_BINTREE_SCHUBERT_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -1119,8 +1067,7 @@ INT t_BINTREE_SCHUBERT(a,b) OP a,b;
 
 
 
-static void t_BINTREE_SCHUBERT_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_SCHUBERT_action(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -1133,8 +1080,7 @@ static void t_BINTREE_SCHUBERT_action(a,type,l)OP *a;VISIT type;INT l;
 }
 
 #endif /* SCHUBERTTRUE */
-static void t_BINTREE_GRAL_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_GRAL_action(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -1146,12 +1092,11 @@ static void t_BINTREE_GRAL_action(a,type,l)OP *a;VISIT type;INT l;
                 }
 }
 
-INT t_BINTREE_GRAL(a,b) OP a,b;
-/* wandelt einen BINTREE in ein GRAL object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+
+/* wandelt einen BINTREE in ein GRAL object um die liste ist nach den
+ * gleichen vergleich sortiert */
+INT t_BINTREE_GRAL(OP a, OP b)
 {
-        void t_BINTREE_GRAL_action();
         OP *h2,h;
         INT erg = OK;
         OBJECTSELF d;
@@ -1191,38 +1136,10 @@ INT t_BINTREE_GRAL(a,b) OP a,b;
 }
 
 
-INT test_bintree()
-{
-    OP a,b,c;
-    a = callocobject();
-    b = callocobject();
-    c = callocobject();
-    printeingabe("test_bintree:init(BINTREE,a) ");
-    init(BINTREE,a); println(a);
-    printeingabe("test_bintree:insert(5L,a) ");
-    m_i_i(5L,b);insert(b,a,NULL,NULL); println(a);
-    printeingabe("test_bintree:insert(7L,a) ");
-    b = callocobject();
-    m_i_i(7L,b);
-    insert(b,a,NULL,NULL);  println(a);
-    printeingabe("test_bintree:copy(a,c) ");
-    copy(a,c); println(c);
-    printeingabe("test_bintree:insert(9L,c) ");
-    b = callocobject();
-    m_i_i(9L,b);
-    insert(b,c,NULL,NULL); 
-    println(c);
-    freeall(a);
-    freeall(c);
-    return OK;
-}
-
-INT t_BINTREE_MONOMIAL_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_MONOMIAL_apply(OP a)
 {
     OP b;
-    void t_BINTREE_MONOMIAL_action_apply();
-        OP *h2,h;
+    OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
     b = callocobject();
@@ -1244,7 +1161,7 @@ INT t_BINTREE_MONOMIAL_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_MONOMIAL_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 {
@@ -1260,16 +1177,13 @@ INT t_BINTREE_MONOMIAL_apply(a) OP a;
     erg += swap(b,a);
     erg += freeall(b);
 
-    
     ENDR("t_BINTREE_MONOMIAL_apply");
 }
 
-INT t_BINTREE_MONOMIAL(a,b) OP a,b;
-/* wandelt einen BINTREE in ein MONOMIAL object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+/* wandelt einen BINTREE in ein MONOMIAL object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_MONOMIAL(OP a, OP b)
 {
-    void t_BINTREE_MONOMIAL_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -1278,11 +1192,11 @@ INT t_BINTREE_MONOMIAL(a,b) OP a,b;
         erg += t_BINTREE_MONOMIAL_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(MONOMIAL,b);    
+        erg += init(MONOMIAL,b);
         goto endr_ende;
         }
 
@@ -1296,9 +1210,9 @@ INT t_BINTREE_MONOMIAL(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_MONOMIAL_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,MONOMIAL);
@@ -1306,15 +1220,13 @@ INT t_BINTREE_MONOMIAL(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    erg += freeall(h); 
+    C_L_N(h,NULL);
+    erg += freeall(h);
     ENDR("t_BINTREE_MONOMIAL");
 }
 
 
-
-static void t_BINTREE_MONOMIAL_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_MONOMIAL_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -1325,8 +1237,9 @@ static void t_BINTREE_MONOMIAL_action(a,type,l)OP *a;VISIT type;INT l;
         *(OP**)_bt_p1 = & S_L_N(**(OP**)_bt_p1);
         }
 }
-static void t_BINTREE_MONOMIAL_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+
+
+static void t_BINTREE_MONOMIAL_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -1340,11 +1253,9 @@ static void t_BINTREE_MONOMIAL_action_apply(a,type,l)OP *a;VISIT type;INT l;
 
 #endif /* BINTREETRUE */
 #ifdef BINTREETRUE
-INT t_BINTREE_POLYNOM_apply(a) OP a;
-/* AK 010198 V2.0 */
+INT t_BINTREE_POLYNOM_apply(OP a)
 {
     OP b;
-    void t_BINTREE_POLYNOM_action_apply();
     OP *h2,h;
     OBJECTSELF d;
     INT erg = OK;
@@ -1366,7 +1277,7 @@ INT t_BINTREE_POLYNOM_apply(a) OP a;
                 _bt_p3 = (char *)NULL;
         TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_POLYNOM_action_apply);
 
-        if (S_L_N(h) != NULL) 
+        if (S_L_N(h) != NULL)
                 *b = *S_L_N(h);
         else
                 erg += b_sn_po(NULL,NULL,b);
@@ -1379,16 +1290,13 @@ INT t_BINTREE_POLYNOM_apply(a) OP a;
     erg += swap(b,a);
     FREEALL(b);
 
-    
     ENDR("t_BINTREE_POLYNOM_apply");
 }
 
-INT t_BINTREE_POLYNOM(a,b) OP a,b;
-/* wandelt einen BINTREE in ein POLYNOM object um */
-/* die liste ist nach den gleichen vergleich sortiert */
-/* AK 070390 V1.1 */ /* AK 050891 V1.3 */
+/* wandelt einen BINTREE in ein POLYNOM object um die liste ist nach
+ * den gleichen vergleich sortiert */
+INT t_BINTREE_POLYNOM(OP a, OP b)
 {
-    void t_BINTREE_POLYNOM_action();
     OP *h2,h;
     INT erg = OK;
     OBJECTSELF d;
@@ -1399,11 +1307,11 @@ INT t_BINTREE_POLYNOM(a,b) OP a,b;
         erg += t_BINTREE_POLYNOM_apply(a);
         goto endr_ende;
         }
-        
+
     d = S_O_S(a);
     if (d.ob_charpointer == NULL)
         {
-        erg += init(POLYNOM,b);    
+        erg += init(POLYNOM,b);
         goto endr_ende;
         }
 
@@ -1417,9 +1325,9 @@ INT t_BINTREE_POLYNOM(a,b) OP a,b;
         _bt_p3 = (char *)NULL;
     TWALK((S_O_S(a)).ob_charpointer,t_BINTREE_POLYNOM_action);
 
-    if (S_L_N(h) != NULL) 
+    if (S_L_N(h) != NULL)
         *b = *S_L_N(h);
-    else 
+    else
         {
         erg += b_sn_l(NULL,NULL,b);
         C_O_K(b,POLYNOM);
@@ -1427,15 +1335,13 @@ INT t_BINTREE_POLYNOM(a,b) OP a,b;
 
     C_O_K(S_L_N(h),EMPTY);
     erg += freeall(S_L_N(h));
-    C_L_N(h,NULL); 
-    FREEALL(h); 
+    C_L_N(h,NULL);
+    FREEALL(h);
     ENDR("t_BINTREE_POLYNOM");
 }
 
 
-
-static void t_BINTREE_POLYNOM_action(a,type,l)OP *a;VISIT type;INT l;
-/* AK 210891 V1.3 */
+static void t_BINTREE_POLYNOM_action(OP *a, VISIT type, INT l)
 {
     if ((type==postorder)||  (type==leaf))
         {
@@ -1446,8 +1352,8 @@ static void t_BINTREE_POLYNOM_action(a,type,l)OP *a;VISIT type;INT l;
         }
 }
 
-static void t_BINTREE_POLYNOM_action_apply(a,type,l)OP *a;VISIT type;INT l;
-/* AK 080199 V2.0 */
+
+static void t_BINTREE_POLYNOM_action_apply(OP *a, VISIT type, INT l)
 {
         if ((type==postorder)||  (type==leaf))
                 {
@@ -1459,4 +1365,3 @@ static void t_BINTREE_POLYNOM_action_apply(a,type,l)OP *a;VISIT type;INT l;
 }
 
 #endif /* BINTREETRUE */
-
