@@ -24,21 +24,20 @@ OP cons_eins;   /* global INTEGER variable 1 */
 OP cons_negeins;/* global INTEGER variable -1 */
 OP cons_null;   /* global INTEGER variable 0 */
 FILE *texout;   /* global variable for texoutput */
-INT no_banner = TRUE;
-INT no_mem_check=TRUE; /* AK 100893 */
-INT english_tableau=FALSE; /* AK 290995 */
+INT no_mem_check=TRUE;
+INT english_tableau=FALSE;
 
-INT doffset=0L;  /* global for debugprint AK 160393 */
+INT doffset=0L;  /* global for debugprint */
 
 INT freeall_speichersize_max = (INT) 1000000;
-int SYM_free(a) char *a;
+int SYM_free(void *a)
 {
     if (sym_timelimit > 0L) check_time();
     free(a);
     return 0;
 }
 
-char * SYM_malloc(a) int a;
+char* SYM_malloc(int a)
 {
     INT erg = OK;
     char *res;
@@ -58,7 +57,7 @@ sca:
     ENDTYP("SYM_malloc",char *);
 }
 
-char * SYM_calloc(a,b) int a,b;
+char* SYM_calloc(int a, int b)
 {
     char *erg;
     INT err;
@@ -83,19 +82,19 @@ sca:
     if (erg == NULL)
         {
         err=error("SYM_calloc: no memory");
-        if (err==ERROR_RETRY) 
+        if (err==ERROR_RETRY)
             {
             goto sca;
             }
         if (err==ERROR_EXPLAIN) {
-            fprintf(stderr,"I wanted %d pieces of size %d", a,b); 
+            fprintf(stderr,"I wanted %d pieces of size %d", a,b);
             goto sca;
             }
         }
     return erg;
 }
 
-char * SYM_realloc(a,b) char *a; int b;
+char* SYM_realloc(void *a, int b)
 {
     char *erg;
     INT err= -1;
@@ -106,13 +105,13 @@ sca:
     if (erg == NULL)
         {
         err=error("SYM_realloc: no memory");
-        if (err == ERROR_RETRY) 
+        if (err == ERROR_RETRY)
             {
             goto sca;
             }
-        if (err==ERROR_EXPLAIN) 
+        if (err==ERROR_EXPLAIN)
             {
-            fprintf(stderr,"I wanted %d Byte of Memory", b); 
+            fprintf(stderr,"I wanted %d Byte of Memory", b);
             goto sca;
             }
         }
@@ -121,20 +120,11 @@ sca:
 
 
 
-INT anfang() 
-/* AK 070890 V1.1 */ /* AK 210891 V1.3 */
-/* AK 260298 V2.0 */
-/* AK 280705 V3.0 */
+INT anfang(void)
 {
     time_t l;
     INT erg = OK;
-    void srand();
-    if (not no_banner)
-        {
-        printeingabe("SYMMETRICA VERSION 3.0 - STARTING");
-        printeingabe(TITELTEXT);
-        }
-    
+
     time(&l);
     l = l * l * clock();
     srand((unsigned long)l);
@@ -153,52 +143,46 @@ INT anfang()
 #ifdef LONGINTTRUE
     start_longint();
 #endif /* LONGINTTRUE */
-
-    check_time_co = NULL; /* co routine called in check time,
-                may be set by other programms */
     texout = stdout;
 
-#ifdef NUMBERTRUE    /* 291091: TPMcD */
+#ifdef NUMBERTRUE
 /* The third parameter is NULL or the name of a file with cyclotomic data */
     setup_numbers(STD_BASIS,TRUE, NULL);
-    
+
 #endif /* NUMBERTRUE */
 
 #ifdef BRUCHTRUE
-    bruch_anfang(); /* AK 100893 */
+    bruch_anfang();
 #endif /* BRUCHTRUE */
 
 #ifdef VECTORTRUE
-    vec_anfang(); /* AK 100893 */
+    vec_anfang();
 #endif /* VECTORTRUE */
 #ifdef PARTTRUE
-    part_anfang(); /* AK 040903 */
+    part_anfang();
 #endif /* PARTTRUE */
 
 #ifdef TABLEAUXTRUE
-    tab_anfang(); /* AK 100893 */
+    tab_anfang();
 #endif /* TABLEAUXTRUE */
 
 #ifdef PERMTRUE
-    perm_anfang(); /* AK 100893 */
+    perm_anfang();
 #endif /* PERMTRUE */
 
 #ifdef LISTTRUE
-    list_anfang(); /* AK 100893 */
+    list_anfang();
 #endif /* LISTTRUE */
 
 #ifdef POLYTRUE
-    monom_anfang(); /* AK 100893 */
+    monom_anfang();
 #endif /* POLYTRUE */
 #ifdef FFTRUE
-    ff_anfang(); /* AK 011204 */
+    ff_anfang();
 #endif /* FFTRUE */
 #ifdef GRTRUE
-    galois_anfang(); /* AK 271106  */
+    galois_anfang();
 #endif /* GRTRUE */
-#ifdef LOCALTRUE
-    local_anfang(); /* AK 280705 */
-#endif
 
     /* checks on type of constants */
     CTO(INTEGER,"anfang(e1)",cons_zwei);
@@ -210,8 +194,7 @@ INT anfang()
 }
 
 
-INT ende() 
-/* AK 070890 V1.1 */ /* AK 210891 V1.3 */
+INT ende(void)
 {
     INT erg = OK;
     char t[100];
@@ -221,7 +204,7 @@ INT ende()
     schur_ende();
 #endif /* SCHURTRUE */
 
-#ifdef NUMBERTRUE    /* 29.10.91: TPMcD */
+#ifdef NUMBERTRUE
     release_numbers();
 #endif /* NUMBERTRUE */
 
@@ -231,17 +214,17 @@ INT ende()
 
 
 #ifdef TABLEAUXTRUE
-    tab_ende(); /* AK 100893 */
+    tab_ende();
 #endif /* TABLEAUXTRUE */
 
     hash_ende();
 
 #ifdef POLYTRUE
-    monom_ende(); /* AK 100893 */ /* nach schur ende */
+    monom_ende(); /* nach schur ende */
 #endif /* POLYTRUE */
 
 #ifdef BRUCHTRUE
-    bruch_ende(); /* AK 100893 */
+    bruch_ende();
 #endif /* BRUCHTRUE */
 
 #ifdef PARTTRUE
@@ -249,24 +232,21 @@ INT ende()
 #endif /* PARTTRUE */
 
 #ifdef LISTTRUE
-    list_ende(); /* AK 100893 */
+    list_ende();
 #endif /* LISTTRUE */
 
 #ifdef PERMTRUE
-    perm_ende(); /* AK 100893 */
+    perm_ende();
 #endif /* PERMTRUE */
 
 #ifdef FFTRUE
     ff_ende();
 #endif /* FFTRUE */
 #ifdef GRTRUE
-    galois_ende(); /* AK 271106  */
+    galois_ende();
 #endif /* GRTRUE */
 
-#ifdef LOCALTRUE
-    local_ende(); /* AK 280705 */
-#endif
-#ifdef NUMBERTRUE    /* AK 310893 */
+#ifdef NUMBERTRUE
     nb_ende();
 #endif /* NUMBERTRUE */
 
@@ -275,11 +255,11 @@ INT ende()
 #endif /* LONGINTTRUE */
 
 #ifdef VECTORTRUE
-    vec_ende(); /* AK 100893 */
+    vec_ende();
 #endif /* VECTORTRUE */
 
 
-    if  (  /* AK 190194 */
+    if  (
         (S_O_K(cons_drei) != INTEGER) ||
         (S_O_K(cons_null) != INTEGER) ||
         (S_O_K(cons_zwei) != INTEGER) ||
@@ -288,7 +268,7 @@ INT ende()
         (S_I_I(cons_null) != (INT) 0) ||
         (S_I_I(cons_zwei) != (INT) 2) ||
         (S_I_I(cons_eins) != (INT) 1) ||
-        (S_I_I(cons_negeins) != (INT) -1) 
+        (S_I_I(cons_negeins) != (INT) -1)
         )
     erg += error("ende: wrong constant values e.g. cons_null");
     erg += freeall(cons_null);
@@ -302,147 +282,72 @@ INT ende()
 
     memcheck("ende");
 
-    if (not no_banner)
-        {
-        printeingabe("\nSYMMETRICA VERSION 3.0 - ENDING");
-        sprintf(t,"last changed: %s",TITELTEXT); /* AK 181194 */
-        printeingabe(t);
-        }
 
     fflush(stdout);
     fflush(stderr);
     return erg;
 }
-INT runtime(l) long *l;
-/* AK 270689 V1.0 */ /* AK 070890 V1.1 */ /* AK 210891 V1.3 */
+
+
+INT runtime(long *l)
 {
-#ifdef UNDEF
-#ifdef unix
-    struct tms buffer;
-    times(&buffer);
-    *l = (long) buffer.tms_utime;
-#else /* clock ist POSIX */
-    *l = (long) clock()/60; 
-#endif /* unix */
-#endif
     *l = (long) clock()/CLOCKS_PER_SEC;
     return OK;
 }
 
-INT get_time(a) OP a;
-/* AK 160890 V1.1 */ /* AK 210891 V1.3 */
-/* AK 300998 V2.0 */
+INT get_time(OP a)
 {
     long l;
-    runtime(&l); 
+    runtime(&l);
     return m_i_i((INT)l,a);
 }
 
 
-INT print_time()
-/* AK 160890 V1.1 */ /* AK 210891 V1.3 */
+INT print_time(void)
 {
     long l;
-    runtime(&l); 
+    runtime(&l);
     printf("zeit:%ld\n",l);return OK;
 }
 
 
-INT fusedmemory(fn,stelle) FILE *fn; char *stelle;
-/* AK 270689 V1.0 */ /* AK 010290 V1.1 */ /* AK 130691 V1.2 */
-/* AK 210891 V1.3 */
+INT fusedmemory(FILE *fn, char *stelle)
 {
-#ifdef unix
-#ifndef linux
-/*
-    struct mallinfo mallinfo();
-    struct mallinfo ergebnis;
-    free(calloc(1,1));
-    ergebnis = mallinfo();
-    fprintf(fn,"%s: ",stelle);
-    fprintf(fn,"%d ",ergebnis.uordblks);
-    fprintf(fn,"%d\n",ergebnis.usmblks);
-    return(OK);
-*/
-#endif /* linux */
-#endif /* unix */
-#ifdef TURBOC
-/*
-    fprintf(fn,"%s: ",stelle);
-    fprintf(fn,"%ul\n",coreleft());
-    return(OK);
-*/
-#endif /* TURBOC */
     return(OK);
 }
 
-INT mem_small()
 /* anzahl small memory zurueck */
-/* AK 270689 V1.0 */ /* AK 070890 V1.1 */ /* AK 210891 V1.3 */
+INT mem_small(void)
 {
-#ifdef unix
-#ifndef linux
-/*
-    struct mallinfo mallinfo();
-    struct mallinfo ergebnis;
-    ergebnis = mallinfo();
-    return(ergebnis.usmblks);
-*/
-#endif /*linux */
-#endif /* unix */
     return(0);
 }
 
 
-INT memcheck(stelle) char *stelle;
 /* informationen ueber memory 31/10/86 */
-/* AK 270689 V1.0 */ /* AK 010290 V1.1 */ /* AK 210891 V1.3 */
+INT memcheck(char *stelle)
 {
-#ifdef unix
-#ifndef linux
-/*
-    struct mallinfo mallinfo();
-    struct mallinfo ergebnis;
-
-    if (no_mem_check == TRUE) return OK;
-    SYM_free(SYM_calloc(1,1));
-    ergebnis = mallinfo();
-    printf("memory information  %s\n",stelle);
-    printf("total space     %d\n",ergebnis.arena);
-    printf("block number    %d\n",ergebnis.ordblks);
-    printf("small blocks    %d\n",ergebnis.smblks);
-    printf("used blocks     %d\n",ergebnis.uordblks);
-    printf("free blocks     %d\n",ergebnis.fordblks);
-    printf("used sm. blocks %d\n",ergebnis.usmblks);
-    printf("free sm. blocks %d\n",ergebnis.fsmblks);
-    return(OK);
-*/
-#endif /*linux */
-#endif /* unix */
     return(OK);
 }
 
 INT sym_background = 0L;
 INT sym_www = 0L;
 INT sym_timelimit = 0L;
-INT fatal_error(fehlertext) char *fehlertext;
-/* AK 270295 */
+void fatal_error(char *fehlertext)
 {
     fprintf(stderr,"fatal error in function %s\n",fehlertext);
     exit(11);
-    return OK;
 }
-INT error(fehlertext) char *fehlertext;
+
+
 /* if answer == a ==> abort
-   if answer == e ==> explain
-   if answer == g ==> go on
-   if answer == r ==> retry
-   if answer == s ==> go on suppress error texts
-   if answer == f ==> go on forever
-   else               exit */
-/* AK 270689 V1.0 */ /* AK 070890 V1.1 */
-/* AK 070291 V1.2 explanation of possible input */
-/* AK 210891 V1.3 */
+ * if answer == e ==> explain
+ * if answer == g ==> go on
+ * if answer == r ==> retry
+ * if answer == s ==> go on suppress error texts
+ * if answer == f ==> go on forever
+ * else               exit
+ */
+INT error(char *fehlertext)
 {
     char antwort[2];
     static int forever=0;
@@ -455,7 +360,7 @@ INT error(fehlertext) char *fehlertext;
     fflush(stderr);
     fprintf(stderr,
 "\nenter a to abort with core dump, g to go, f to suppress\n");
-    fprintf(stderr, 
+    fprintf(stderr,
 "s to suppress further error text, r to retry,  e to explain, else stop\n");
     fprintf(stderr,"ERROR: %s?: ",fehlertext);
 
@@ -468,7 +373,7 @@ INT error(fehlertext) char *fehlertext;
         }
 
     if (forever==1) return ERROR;
-        
+
     antwort[0]='X';
     scanf("%s",antwort);
     if (antwort[0] == 'a') abort();
@@ -477,33 +382,31 @@ INT error(fehlertext) char *fehlertext;
     if (antwort[0] == 'g') return ERROR;
     if (antwort[0] == 'r') return ERROR_RETRY;
     if (antwort[0] == 'e') return ERROR_EXPLAIN;
-    exit(1); /* AK 121192 */
+    exit(1);
 }
 
 
-INT no_memory()
-/* AK 090792 */
+INT no_memory(void)
 {
     return error("no memory left");
 }
 
-INT debugprint(a) OP a;
-/* AK 260788 */ /* AK 030789 V1.0 */ /* AK 130690 V1.1 */ /* AK 210891 V1.3 */
+INT debugprint(OP a)
 {
     OBJECTKIND kind;
     INT i,j,k;
     char *text=NULL;
     for (i=0L;i<doffset;i++) fprintf(stderr," ");
-    if (a==NULL) { 
-        fprintf(stderr,"NULL\n"); 
-        return(OK); 
+    if (a==NULL) {
+        fprintf(stderr,"NULL\n");
+        return(OK);
     }
     kind = s_o_k(a);
     switch ((int)kind)
     /* abschluss immer mit newline */
     {
     case 0: 
-        fprintf(stderr,"kind:0=empty self=%ld\n",s_o_s(a).ob_INT);
+        fprintf(stderr,"kind:0=empty self=%" PRIdPTR "\n",s_o_s(a).ob_INT);
         break;
     case 1: 
         fprintf(stderr,"kind:1=integer value:");
@@ -512,7 +415,7 @@ INT debugprint(a) OP a;
 #ifdef VECTORTRUE
         case 120199: case 31:
         case 26: case 19: case 15:
-        case 2: 
+        case 2:
         case 211106:
         if (kind == 2) text="vector";
         if (kind == 15) text="integervector";
@@ -520,8 +423,8 @@ INT debugprint(a) OP a;
         if (kind == 26) text="comp";
         if (kind == 31) text="kranz";
         if (kind == 47) text="subset";
-        if (kind == 120199) text="hashtable"; 
-        if (kind == 211106) text="galois ring"; 
+        if (kind == 120199) text="hashtable";
+        if (kind == 211106) text="galois ring";
         fprintf(stderr,"kind:%d=%s length:\n",(int)kind, text);
         doffset += 2L;
         debugprint(s_v_l(a));
@@ -537,8 +440,8 @@ INT debugprint(a) OP a;
         return(OK);
 #endif /* VECTORTRUE */
 #ifdef PARTTRUE
-    case 3: 
-    case 12: 
+    case 3:
+    case 12:
         {
         if (kind == 12) text="augpartition";
         if (kind == 3) text="partition";
@@ -554,7 +457,7 @@ INT debugprint(a) OP a;
         }
 #endif /* PARTTRUE */
 #ifdef BRUCHTRUE
-    case 4: 
+    case 4:
         {
         fprintf(stderr, "kind:4=bruch gekuerzt=%" PRIINT " oben:\n" , s_b_i(a));
         doffset += 2L;
@@ -569,7 +472,7 @@ INT debugprint(a) OP a;
         }
 #endif /* BRUCHTRUE */
 #ifdef PERMTRUE
-    case 6: 
+    case 6:
         {
         fprintf(stderr,"kind:6=permutation kind:%d\n",(int)s_p_k(a));
         for (k=0L;k<doffset;k++) fprintf(stderr," ");
@@ -581,7 +484,7 @@ INT debugprint(a) OP a;
         }
 #endif /* PERMTRUE */
 #ifdef SKEWPARTTRUE
-    case 7: 
+    case 7:
         {
         fprintf(stderr,"kind:7=skewpartition gross:\n");
         doffset += 2L;
@@ -596,7 +499,7 @@ INT debugprint(a) OP a;
         }
 #endif /* SKEWPARTTRUE */
 #ifdef TABLEAUXTRUE
-    case 8: 
+    case 8:
         {
         fprintf(stderr,"kind:8=tableaux self:\n");
         doffset += 2L;
@@ -682,7 +585,7 @@ INT debugprint(a) OP a;
         }
 #endif /* MONOMTRUE */
 #ifdef CHARTRUE
-    case 18: 
+    case 18:
         {
         fprintf(stderr,"kind:18=symchar dim:\n");
         doffset += 2L;
@@ -736,30 +639,16 @@ INT debugprint(a) OP a;
     case 36: return debugprint_reihe(a);
 #endif /* REIHETRUE */
     default: 
-        fprintf(stderr,"kind:%ld unknown\n",s_o_k(a));
+        fprintf(stderr,"kind:%" PRIOBJECTKIND " unknown\n",s_o_k(a));
         break;
     }
     return OK;
 }
 
-int SYM_isdigit(a) char a; /* AK 040194 */
-{ return ((a >= '0') && (a <= '9')); }
-
-int SYM_strlen(a) char *a; /* AK 030294 */
-{ int i=0; while (*a++) i++; return i; }
-
-int SYM_memcmp(a,b,c) char *a,*b; size_t c; /* AK 210294 */
-{ return memcmp(a,b,c); }
-
-int SYM_abs(a) INT a; /* AK 230695 */
-{ return (a>0 ) ? a : -a; }
-
-
-INT mem_size(a) OP a;
-/* AK 150295 */
+INT mem_size(OP a)
 {
     INT erg = OK;
-    if (a == NULL)        
+    if (a == NULL)
                 return 0;
     switch(S_O_K(a))
         {
@@ -768,7 +657,7 @@ INT mem_size(a) OP a;
         case MATRIX:
         case INTEGERMATRIX:
         case KOSTKA:    return mem_size_matrix(a);
-        case LONGINT:   return mem_size_longint(a); /* AK 080903 */
+        case LONGINT:   return mem_size_longint(a);
         case COMPOSITION:
         case WORD:
         case SUBSET:
@@ -776,7 +665,7 @@ INT mem_size(a) OP a;
         case VECTOR:    return mem_size_vector(a);
         case HASHTABLE:    return mem_size_hashtable(a);
         default:
-            erg += WTO("mem_size",a);goto endr_ende;
+            WTO("mem_size",a);goto endr_ende;
         }
     ENDR("mem_size");
 }
