@@ -2,8 +2,6 @@
 #include "macro.h"
 
 
-INT all_points_phg();
-
 INT scan_galois(OP v)
 {
 	OP d=callocobject();
@@ -30,7 +28,7 @@ INT add_galois(OP p1,OP p2, OP p3) //p3 = p2+p1
 		{
 		M_I_I((S_V_II(p1,i)+S_V_II(p2,i))%S_GR_CI(p3), S_V_I(p3,i)) ;
 		}
-	
+
 	ENDR("add_galois");
 }
 
@@ -69,7 +67,7 @@ INT get_galois_irred(OP g, OP ip) // irreduzible zu galois ring
 		&&
 		(not EMPTYP(mgg_pl))
 	   ) {
-		copy(mgg_pl,ip); 
+		copy(mgg_pl,ip);
 		goto endr_ende;
 	     }
 	v=callocobject();
@@ -91,7 +89,7 @@ INT t_polynom_galois(OP p ,INT c, INT d, OP g)
 	m_i_i(c,S_V_I(g,1));
 
 	if (S_L_S(z) == NULL) goto endr_ende;
-	
+
 	while (z!=NULL)
 		{
 		M_I_I(  S_I_I(S_PO_K(z)),
@@ -132,7 +130,7 @@ INT init_galois_global( OP charac, OP deg )
 }
 
 
-INT galois_anfang()
+INT galois_anfang(void)
 {
 	INT erg =OK;
 	CALLOCOBJECT4(mgg_c,mgg_d,mgg_mt,mgg_pl);
@@ -141,7 +139,7 @@ INT galois_anfang()
 	mgg_change_counter=0;
 	ENDR("galois_anfang");
 }
-INT galois_ende()
+INT galois_ende(void)
 {
 	INT erg =OK;
 	if (S_I_I(mgg_c) != 0) // previously different galois ring
@@ -173,17 +171,17 @@ INT mult_galois_galois(OP p1, OP p2, OP p3)
 	SYMCHECK(S_GR_DI(p1)!=S_GR_DI(p2),"mult_galois_galois:different degrees");
 	{
 	OP poly1,poly2,poly3,poly4,irred,diverg;
-	if (S_GR_DI(p1)==1) { 
-		copy(p1,p3); 
+	if (S_GR_DI(p1)==1) {
+		copy(p1,p3);
 		M_I_I((S_V_II(p1,2)*S_V_II(p2,2))%S_GR_CI(p1), S_V_I(p3,2));
 		goto endr_ende;
 		}
 	if (
 		(S_GR_CI(p1)!=S_I_I(mgg_c))  ||      (S_GR_DI(p1)!=S_I_I(mgg_d))
-	   )     
+	   )
 		init_galois_global(S_GR_C(p1),S_GR_D(p1)); // initialize irred polynomial and mult_table
 
-	if (not EMPTYP(mgg_mt)) // check if result available 
+	if (not EMPTYP(mgg_mt)) // check if result available
 		{
 		p1i=index_galois(p1);
 		p2i=index_galois(p2);
@@ -197,20 +195,20 @@ INT mult_galois_galois(OP p1, OP p2, OP p3)
 		}
 
 	CALLOCOBJECT6(poly1,poly2,poly3,poly4,irred,diverg);
-	t_galois_polynom(p1,poly1); 
+	t_galois_polynom(p1,poly1);
 	t_galois_polynom(p2,poly2);
 	mult(poly1,poly2,poly3);
 	mod(poly3,S_GR_C(p1),poly3);
 	get_galois_irred(p1,irred);
 	quores(poly3,irred,diverg,poly4);
 	mod(poly4,S_GR_C(p1),poly4);
-	t_polynom_galois(poly4,S_GR_CI(p1),S_GR_DI(p1),p3); 
+	t_polynom_galois(poly4,S_GR_CI(p1),S_GR_DI(p1),p3);
 	FREEALL6(poly1,poly2,poly3,poly4,irred,diverg);
 
-	if (not EMPTYP(mgg_mt)) // check if result available 
+	if (not EMPTYP(mgg_mt)) // check if result available
 		{
 		mgg_change_counter++;
-		copy(p3,S_M_IJ(mgg_mt,p1i,p2i)); 
+		copy(p3,S_M_IJ(mgg_mt,p1i,p2i));
 		}
 
 	}
@@ -252,7 +250,6 @@ INT unitp_galois(OP g)
 }
 
 INT nullp_galois(OP g)
-/* AK 131206 V3.1 */
 {
 	INT erg = OK;
 	INT i;
@@ -317,7 +314,7 @@ INT eins_galois(OP a,OP b)
 	ENDR("eins_galois");
 }
 
-INT invers_galois(a,b) OP a,b;
+INT invers_galois(OP a, OP b)
 {
 	INT erg = OK;
 	CE2(a,b,invers_galois);
@@ -326,7 +323,7 @@ INT invers_galois(a,b) OP a,b;
 	c=CALLOCOBJECT();
 	copy(a,c);
 	copy(a,b);
-	while (! einsp_galois(c)) 
+	while (! einsp_galois(c))
 		{
 		SWAP(b,c);
 		mult_galois(a,b,c);
@@ -337,7 +334,6 @@ INT invers_galois(a,b) OP a,b;
 }
 
 INT addinvers_apply_galois(OP a)
-/* AK 200307 */
 {
 	INT erg =OK,i,ai;
 	CTO(GALOISRING,"addinvers_apply_galois(1)",a);
@@ -352,13 +348,13 @@ INT addinvers_apply_galois(OP a)
 	ENDR("addinvers_apply_galois");
 }
 
-INT random_gr_given_c_d(c,d,b) OP c,d; OP b;
+INT random_gr_given_c_d(OP c, OP d, OP b)
 {
     INT erg = OK;
     CTO(INTEGER,"random_gr_given_c_d(1)",c);
     CTO(INTEGER,"random_gr_given_c_d(2)",d);
     SYMCHECK(prime_power_p(c) ==FALSE,"random_gr_given_c_d:c no prime power");
-    {	
+    {
     INT i;
     m_il_v(S_I_I(d)+2,b); C_O_K(b,GALOISRING);
     m_i_i(S_I_I(d),S_V_I(b,0));
@@ -372,7 +368,6 @@ INT random_gr_given_c_d(c,d,b) OP c,d; OP b;
 
 
 INT next_apply_gr(OP gr1)
-/* AK 150307 */
 {
 	INT erg =OK,i,j,c;
 	CTO(GALOISRING,"next_apply_gr(1)",gr1);
@@ -392,24 +387,14 @@ INT next_gr(OP gr1, OP gr2)
 {
 	INT erg =OK,i,j,c;
 	CTO(GALOISRING,"next_gr(1)",gr1);
-	if (gr1!=gr2) copy(gr1,gr2); 
+	if (gr1!=gr2) copy(gr1,gr2);
 	return next_apply_gr(gr2);
-/*
-	c=S_V_II(gr2,1);
-	for (i=S_V_LI(gr2)-1; i>=2;i--)
-		if (S_V_II(gr2,i) < c-1) { 
-			INC_INTEGER(S_V_I(gr2,i));
-			for (j=i+1;j<S_V_LI(gr2);j++) M_I_I(0,S_V_I(gr2,j));
-			return OK;
-			}
-	return LAST_FF;
-*/
 	ENDR("next_gr");
 }
 
 
-INT vectorofzerodivisors_galois(OP c, OP d, OP v)
 /* vector with all non unit elements */
+INT vectorofzerodivisors_galois(OP c, OP d, OP v)
 {
 	INT erg =OK;
 	OP sl=callocobject();
@@ -422,8 +407,8 @@ INT vectorofzerodivisors_galois(OP c, OP d, OP v)
 }
 
 
-INT random_subgroup_glk_grcd_smaller_k(k,c,d,a) OP k,c,d,a;
 /* erzeuger fuer kleinere glnk-1 */
+INT random_subgroup_glk_grcd_smaller_k(OP k, OP c, OP d, OP a)
 {
     INT erg = OK;
     CTO(INTEGER,"random_subgroup_glk_grcd_smaller_k(1)",k);
@@ -457,9 +442,8 @@ INT random_subgroup_glk_grcd_smaller_k(k,c,d,a) OP k,c,d,a;
 }
 
 
-INT random_subgroup_glk_grcd_diagonal(k,c,d,a) OP k,c,d,a;
 /* subgroup generated by diagonal matrix */
-/* AK 110804 */
+INT random_subgroup_glk_grcd_diagonal(OP k, OP c, OP d, OP a)
 {
     INT erg = OK;
     CTO(INTEGER,"random_subgroup_glk_grcd_diagonal(1)",k);
@@ -490,8 +474,7 @@ INT random_subgroup_glk_grcd_diagonal(k,c,d,a) OP k,c,d,a;
 }
 
 
-INT random_subgroup_glk_grcd_2gen(k,c,d,a) OP k,d,c,a;
-/* AK 170407 V3.1 */
+INT random_subgroup_glk_grcd_2gen(OP k, OP c, OP d, OP a)
 {
 	INT erg =OK;
     CTO(INTEGER,"random_subgroup_glk_grcd_2gen(1)",k);
@@ -508,10 +491,10 @@ INT random_subgroup_glk_grcd_2gen(k,c,d,a) OP k,d,c,a;
     ENDR("random_subgroup_glk_grcd_2gen");
 }
 
-INT random_subgroup_glk_grcd_cyclic(k,c,d,a) OP k,d,c,a;
-/* findet zufllige erzeuger einer zyklischen
-   untergruppe von glk  ueber GR characteristik c und degree d */
-/* AK 241106 V3.1 */
+
+/* findet zufllige erzeuger einer zyklischen untergruppe von glk
+ * ueber GR characteristik c und degree d */
+INT random_subgroup_glk_grcd_cyclic(OP k, OP c, OP d, OP a)
 {
     INT erg = OK;
     CTO(INTEGER,"random_subgroup_glk_grcd_cyclic(1)",k);
@@ -531,11 +514,9 @@ INT random_subgroup_glk_grcd_cyclic(k,c,d,a) OP k,d,c,a;
 
         {
           OP d;
-	  d=CALLOCOBJECT(); 
+	  d=CALLOCOBJECT();
 	  det_mat_imm(mat,d);  printf("det=");println(d);
           if (! unitp_galois(d))   { freeall(d); goto ag; }
-
-          //order(mat,d); printf("ordnung:"); println(d);
           FREEALL(d);
         }
 
@@ -544,27 +525,24 @@ INT random_subgroup_glk_grcd_cyclic(k,c,d,a) OP k,d,c,a;
     ENDR("random_subgroup_glk_grcd_cyclic");
 }
 
-static INT multscal_221106(mat,point,res) OP mat,point,res;
+static INT multscal_221106(OP mat, OP point, OP res)
 {
    INT i; INT erg = OK;
    OP inv;
-        //println(point);
    inv = CALLOCOBJECT();
    MULT(mat,point,res);
    for (i=0;i<S_V_LI(res);i++) if (unitp_galois(S_V_I(res,i))) break;
-      // bei i eintrag != null
+   // bei i eintrag != null
    if (i==S_V_LI(res)) { println(res); error("no unit found"); }
-   INVERS(S_V_I(res,i),inv); // printf("break bei %d, mult mit:",i);println(inv);
+   INVERS(S_V_I(res,i),inv);
    MULT_APPLY(inv,res);
    FREEALL(inv);
-        //println(res);
    ENDR("multscal_151104");
 }
 
-INT random_subgroup_glk_grcd_stabilizer(k,phgc,phgd,a) OP k,phgc,phgd,a;
-/* subgroup generated as stabilizer of operation on 1-dim subspaces over Galoisring *
-/
-/* AK 281106 */
+/* subgroup generated as stabilizer of operation on 1-dim subspaces
+ * over Galoisring */
+INT random_subgroup_glk_grcd_stabilizer(OP k, OP phgc, OP phgd, OP a)
 {
     INT erg = OK;
     CTO(INTEGER,"random_subgroup_glk_grcd_stabilizer(1)",k);
@@ -580,12 +558,9 @@ INT random_subgroup_glk_grcd_stabilizer(k,phgc,phgd,a) OP k,phgc,phgd,a;
     all_points_phg(k,phgc,phgd,z);
     i = rand()%S_V_LI(z);
     v = S_V_I(z,i);
-    // println(v);
-        /* jetzt ist v ein kanonischer 1-dim subspace */
+    /* jetzt ist v ein kanonischer 1-dim subspace */
 
     /* orbit mit stabilizer */
-
-
         {
         OP g = callocobject();
         OP res = callocobject();
@@ -606,7 +581,7 @@ nochmal:
 }
 
 
-INT random_subgroup_glk_grcd(k,c,d,a) OP k,d,c,a;
+INT random_subgroup_glk_grcd(OP k, OP c, OP d, OP a)
 {
 	INT erg = OK;
         CTO(INTEGER,"random_subgroup_glk_grcd(1)",k);
@@ -616,13 +591,13 @@ INT random_subgroup_glk_grcd(k,c,d,a) OP k,d,c,a;
 	INT i;
 	i = rand();
 	i = i%6;
-	if (i==0) 
+	if (i==0)
 		return random_subgroup_glk_grcd_diagonal(k,c,d,a);
-	else if (i==1) 
+	else if (i==1)
 		return random_subgroup_glk_grcd_smaller_k(k,c,d,a);
-	else if (i==2) 
+	else if (i==2)
 		return random_subgroup_glk_grcd_stabilizer(k,c,d,a);
-	else if (i==3) 
+	else if (i==3)
 		return random_subgroup_glk_grcd_2gen(k,c,d,a);
 	else
 		return random_subgroup_glk_grcd_cyclic(k,c,d,a);
@@ -643,7 +618,6 @@ INT get_incidence_phg(OP k,OP phg_c, OP phg_d,OP erz,OP matrix,OP bahnsizes,
         all_points_phg(k,phg_c,phg_d,eindim);
         printf("anzahl punkte:"); println(S_V_L(eindim));
         all_orbits(eindim,erz,eindimbahnen,NULL,multscal_221106); // f bahnen von 1dim uvr nummeriert 1,2,...
-        //println(eindimbahnen);
 
         erg +=max(eindimbahnen,anzbahn); // c ist anzahl bahnen
         printf("anzahl der bahnen = "); println(anzbahn);
@@ -655,7 +629,7 @@ INT get_incidence_phg(OP k,OP phg_c, OP phg_d,OP erz,OP matrix,OP bahnsizes,
         if (hyper!=NULL) copy(eindim,hyper);
         else hyper=eindim;
         all_orbits(hyper,transerz,hyperbahnen,NULL,multscal_221106); // f bahnen von 1dim uvr nummeriert 1,2,...
-        //printf("bahnen der hyperebenen:");println(hyperbahnen);
+
         max(hyperbahnen,c);
         printf("anzahl der hyperbahnen = "); println(c);
         m_l_v(c,hyprep); // vektor fr reprsentanten der hyperebenen
@@ -663,14 +637,15 @@ INT get_incidence_phg(OP k,OP phg_c, OP phg_d,OP erz,OP matrix,OP bahnsizes,
         println(hyprep);
         for (j=0;j<S_V_LI(eindimbahnen);j++)
                   {
-                  for (i=0;i<S_V_LI(hyprep);i++)
-                      {
+                  for (i=0;i<S_V_LI(hyprep);i++) {
                       OP y,x;
                       x = S_V_I(eindim,S_V_II(hyprep,i));
                       y = S_V_I(eindim,j);
                       erg +=scalarproduct(x,y,c);
-                      if (NULLP(c)) INC(S_M_IJ(matrix,i,S_V_II(eindimbahnen,j)-1));
+                      if (NULLP(c)) {
+                          INC(S_M_IJ(matrix,i,S_V_II(eindimbahnen,j)-1));
                       }
+                  }
 
                   INC(S_V_I(bahnsizes,S_V_II(eindimbahnen,j)-1));
                   }
@@ -679,10 +654,9 @@ INT get_incidence_phg(OP k,OP phg_c, OP phg_d,OP erz,OP matrix,OP bahnsizes,
         ENDR("get_incidence_phg");
 }
 
-INT all_points_phg(k,phg_c,phg_d,res) OP k,phg_c,phg_d,res;
-/* alle 1 dimensionalen uvr von GR(c,d)^k */
-/* in sortierter folge */
-/* AK 211106 */
+
+/* alle 1 dimensionalen uvr von GR(c,d)^k in sortierter folge */
+INT all_points_phg(OP k, OP phg_c, OP phg_d, OP res)
 {
     INT erg = OK;
     CTO(INTEGER,"all_points_phg(1)",k);
@@ -694,7 +668,7 @@ INT all_points_phg(k,phg_c,phg_d,res) OP k,phg_c,phg_d,res;
     INT i,j; OP z,h,v,nv;
     CALLOCOBJECT2(v,nv);
     vectorofzerodivisors_galois(phg_c, phg_d, nv);
-    //printf("nullteiler sind:");println(nv);
+
     m_il_v(0,res);
     for (i=0;i<S_I_I(k);i++)
         {
@@ -729,8 +703,9 @@ INT all_points_phg(k,phg_c,phg_d,res) OP k,phg_c,phg_d,res;
                   }
               }
         FREEALL(h);
-        /* v ist jetzt der vektor mit 0'en bis platz i 
-           jetzt mssen davor alle mglichen nullteiler in allen permutationen kommen */
+        /* v ist jetzt der vektor mit 0'en bis platz i jetzt mssen
+         * davor alle mglichen nullteiler in allen permutationen
+         * kommen */
 	append_apply(res,v); // v an res anhngen
         if ((S_V_LI(nv)>1)&&(i>0)) {
 		OP lv;
@@ -739,7 +714,7 @@ INT all_points_phg(k,phg_c,phg_d,res) OP k,phg_c,phg_d,res;
 nn:
 		for (j=S_V_LI(lv)-1;j>=0;j--)
 			{
-			if (S_V_II(lv,j)+1 < S_V_LI(nv)) { inc(S_V_I(lv,j)); 
+			if (S_V_II(lv,j)+1 < S_V_LI(nv)) { inc(S_V_I(lv,j));
 						           for (++j;j<S_V_LI(lv);j++) M_I_I(0,S_V_I(lv,j));
 							// lv hat jetzt die indices der nullteiler
 							   for (j=0;j<S_V_LI(v);j++)
@@ -749,18 +724,16 @@ nn:
 									copy(S_V_I(nv,S_V_II(lv,k)), S_V_I(S_V_I(v,j),k));
 								}
 							    append_apply(res,v); // v an res anhngen
-							// println(lv);
 							    goto nn;
                                                           }
 			// das war die letzte nullteiler verteilung
 			}
-		FREEALL(lv);	
+		FREEALL(lv);
 		}
         }
     FREEALL2(v,nv);
     SYM_sort(res);
     }
     S3R(k,phg_c,phg_d,"all_points_phg_store",res);
-    ENDR("all_points");
+    ENDR("all_points_phg");
 }
-
