@@ -1,14 +1,13 @@
 #include "def.h"
 #include "macro.h"
 
-static INT hash1();
-static INT eq1();
+static INT hash1(OP);
+static INT eq1(OP,OP);
 static OP lookup2=NULL;
 static OP lookup1=NULL;
 
-INT t_HASHTABLE_POLYNOM_apply();
 
-INT hash_ende()
+INT hash_ende(void)
 {
     INT erg = OK;
     if (lookup2 != NULL) {
@@ -28,8 +27,7 @@ INT hash_ende()
     ENDR("hash_ende");
 }
 
-INT copy_hashtable(a,b) OP a,b;
-/* AK 011101 */
+INT copy_hashtable(OP a, OP b)
 {
     INT erg = OK;
     INT i;
@@ -52,8 +50,7 @@ INT copy_hashtable(a,b) OP a,b;
     ENDR("copy_hashtable");
 }
 
-INT mem_size_hashtable(a) OP a;
-/* AK 080903 */
+INT mem_size_hashtable(OP a)
 {
     INT erg = OK, res = 0;
     CTO(HASHTABLE,"mem_size_hashtable(1)",a);
@@ -63,8 +60,7 @@ INT mem_size_hashtable(a) OP a;
     ENDR("mem_size_hashtable");
 }
 
-INT mult_apply_scalar_hashtable(a,b) OP a,b;
-/* AK 171001 */
+INT mult_apply_scalar_hashtable(OP a, OP b)
 {
     INT erg = OK;
     OP z;
@@ -79,82 +75,77 @@ INT mult_apply_scalar_hashtable(a,b) OP a,b;
     ENDR("mult_apply_scalar_hashtable");
 }
 
-INT mult_apply_integer_hashtable(a,b) OP a,b;
-/* AK 171001 */
+INT mult_apply_integer_hashtable(OP a, OP b)
 {
     INT erg = OK;
     OP z;
- 
+
     CTO(HASHTABLE,"mult_apply_integer_hashtable(2)",b);
     CTO(INTEGER,"mult_apply_integer_hashtable(1)",a);
- 
+
     FORALL(z,b, {
         MULT_APPLY_INTEGER(a,z);
         } );
- 
+
     ENDR("mult_apply_integer_hashtable");
 }
 
-INT mult_integer_hashtable(a,b,c) OP a,b,c;
-/* AK 310102 */
+INT mult_integer_hashtable(OP a, OP b, OP c)
 {
     INT erg = OK;
     OP z;
- 
+
     CTO(HASHTABLE,"mult_integer_hashtable(2)",b);
     CTO(INTEGER,"mult_integer_hashtable(1)",a);
     CTO(EMPTY,"mult_integer_hashtable(3)",c);
 
     erg += copy_hashtable(b,c);
- 
+
     FORALL(z,c, {
         MULT_APPLY_INTEGER(a,z);
         } );
- 
+
     ENDR("mult_integer_hashtable");
 }
 
-INT mult_bruch_hashtable(a,b,c) OP a,b,c;
-/* AK 310102 */
+INT mult_bruch_hashtable(OP a, OP b, OP c)
 {
     INT erg = OK;
     OP z;
- 
+
     CTO(HASHTABLE,"mult_bruch_hashtable(2)",b);
     CTO(BRUCH,"mult_bruch_hashtable(1)",a);
     CTO(EMPTY,"mult_bruch_hashtable(3)",c);
- 
+
     erg += copy_hashtable(b,c);
- 
+
     FORALL(z,c, {
         MULT_APPLY_BRUCH(a,z);
         } );
- 
+
     ENDR("mult_bruch_hashtable");
 }
 
 
 
-INT mult_apply_bruch_hashtable(a,b) OP a,b;
-/* AK 171001 */
+INT mult_apply_bruch_hashtable(OP a, OP b)
 {
     INT erg = OK;
     OP z;
- 
+
     CTO(HASHTABLE,"mult_apply_bruch_hashtable(2)",b);
     CTO(BRUCH,"mult_apply_bruch_hashtable(1)",a);
- 
+
     FORALL(z,b, {
         MULT_APPLY_BRUCH(a,z);
         } );
- 
+
     ENDR("mult_apply_bruch_hashtable");
 }
 
 
 
-INT addinvers_apply_hashtable(a) OP a;
-/* AK 231001 */
+INT addinvers_apply_hashtable(OP a)
 {
     INT erg = OK;
     OP z;
@@ -168,10 +159,9 @@ INT addinvers_apply_hashtable(a) OP a;
 }
 
 
-INT add_apply_hashtable(a,b,eh,ef,hf) OP a,b; INT (*ef)();INT (*hf)(); INT (*eh)();
-/* AK 141101 */
-/* first lookup a in b, if not yet here it inserts a copy, else
-   it applys the eh function */
+/* first lookup a in b, if not yet here it inserts a copy, else it
+ * applies the eh function */
+INT add_apply_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*ef)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     OP z;
@@ -200,10 +190,10 @@ INT add_apply_hashtable(a,b,eh,ef,hf) OP a,b; INT (*ef)();INT (*hf)(); INT (*eh)
 }
 
 
-OP find_hashtable(a,b,ef,hf) OP a,b; INT (*ef)();INT (*hf)();
-/* AK 281097 */
-/* find a object in hashtable b */
-/* return s NULL if not find, else returns OP pointer */
+/* find a object in hashtable b
+ * return s NULL if not find, else returns OP pointer
+ */
+OP find_hashtable(OP a, OP b, INT (*ef)(OP,OP), INT (*hf)(OP))
 {
     OP z,z1;
     INT i,hi,hh,hhh;
@@ -216,22 +206,21 @@ OP find_hashtable(a,b,ef,hf) OP a,b; INT (*ef)();INT (*hf)();
         hh = HASH_MONOMPARTITION(a);
     else if (hf == hash)
         hh = HASH(a);
-    else if (hf == hash1) 
+    else if (hf == hash1)
         hh = HASH(S_V_I(a,0));
-    else 
+    else
         hh = (*hf)(a);
 
     hi = hh % S_V_LI(b);
-    if (hi < 0) 
+    if (hi < 0)
          hi += S_V_LI(b);
-    
-    
+
     z = S_V_I(b,hi);
 
     if (EMPTYP(z)) return NULL;
 
     for (i=0,z1 = S_V_S(z) ;i<S_V_LI(z);i++,z1++)
-        if (not EMPTYP(z1)) 
+        if (not EMPTYP(z1))
             {
             if (hf == hash)
                 hhh = HASH(z1);
@@ -244,13 +233,13 @@ OP find_hashtable(a,b,ef,hf) OP a,b; INT (*ef)();INT (*hf)();
 
             if (hh == hhh)
                 {
-                if (ef == NULL) 
+                if (ef == NULL)
                     hhh = EQ(a,z1);
-                else if (ef == eq_monomsymfunc) 
+                else if (ef == eq_monomsymfunc)
                     hhh = eq_partition_partition(S_MO_S(a),S_MO_S(z1));
                 else if (ef == eq1)
                     hhh = EQ(S_V_I(a,0),S_V_I(z1,0));
-                else 
+                else
                     hhh = (*ef)(a,z1);
 
                 if (hhh == TRUE) return z1;
@@ -262,8 +251,7 @@ OP find_hashtable(a,b,ef,hf) OP a,b; INT (*ef)();INT (*hf)();
 }
 
 
-INT fprint_hashtable(f,h) FILE *f; OP h;
-/* AK 131101 */
+INT fprint_hashtable(FILE *f, OP h)
 {
     INT erg = OK;
     OP z;
@@ -282,8 +270,7 @@ INT fprint_hashtable(f,h) FILE *f; OP h;
     ENDR("fprint_hashtable");
 }
 
-INT objectread_hashtable(fp, h) FILE *fp; OP h;
-/* AK 100307 */
+INT objectread_hashtable(FILE *fp, OP h)
 {
 	INT erg = OK,i,j=-1,k;
 	erg += objectread_vector(fp,h);
@@ -297,22 +284,16 @@ INT objectread_hashtable(fp, h) FILE *fp; OP h;
 				C_I_I(S_V_I(h,j),i);
 			}
 		}
-	// printf("j=%d i=%d\n",j,i);
+
 	for (j++;j<i;j++)
 		C_I_I(S_V_I(h,j),-1);
 	M_I_I(S_V_LI(h)+1,S_V_L(h));
-/*
-	for (i=0;i<S_V_LI(h);i++) if (not EMPTYP(S_V_I(h,i))) println(S_V_I(h,i));
-				  else printf("%d\n",S_V_II(h,i));
-*/
 	M_I_I(S_V_LI(h)-1,S_V_L(h));
 	C_O_K(h,HASHTABLE);
-	// println(h);
 	ENDR("objectread_hashtable");
 }
 
-INT objectwrite_hashtable(fp, h) FILE *fp; OP h;
-/* AK 100307 */
+INT objectwrite_hashtable(FILE *fp, OP h)
 {
         INT erg = OK;
         M_I_I(S_V_LI(h)+1,S_V_L(h));
@@ -334,9 +315,8 @@ do { \
     M_I_I(0,S_V_I(a,i)); \
 } while(0)
 
-INT init_hashtable(a) OP a;
-/* AK 281097 */
 /* initialize a hashtable */
+INT init_hashtable(OP a)
     {
     INT erg = OK;
     CTO(EMPTY,"init_hashtable(1)",a);
@@ -345,7 +325,7 @@ INT init_hashtable(a) OP a;
     }
 
 
-INT init_size_hashtable(a,b) OP a; INT b;
+INT init_size_hashtable(OP a, INT b)
     {
     OP c;
     INT erg = OK;
@@ -358,7 +338,7 @@ INT init_size_hashtable(a,b) OP a; INT b;
     ENDR("init_size_hashtable");
     }
 
-INT clone_size_hashtable(a,b) OP a; INT b;
+INT clone_size_hashtable(OP a, INT b)
     {
     INT erg = OK;
     CTO(EMPTY,"clone_size_hashtable(1)",a);
@@ -369,7 +349,7 @@ INT clone_size_hashtable(a,b) OP a; INT b;
 
 
 
-INT insert_hashtable_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
+INT insert_hashtable_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     OP z;
@@ -401,8 +381,7 @@ do {OP z; \
     FREEALL(a); \
     } while(0)
 
-INT insert_monomial_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 131101 */
+INT insert_monomial_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(MONOMIAL,"insert_monomial_hashtable(1)",a);
@@ -411,8 +390,7 @@ INT insert_monomial_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf
     ENDR("insert_monomial_hashtable");
 }
 
-INT insert_schur_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 131101 */
+INT insert_schur_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(SCHUR,"insert_schur_hashtable(1)",a);
@@ -421,8 +399,7 @@ INT insert_schur_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)()
     ENDR("insert_schur_hashtable");
 }
 
-INT insert_homsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 131101 */
+INT insert_homsym_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(HOMSYM,"insert_homsym_hashtable(1)",a);
@@ -430,9 +407,8 @@ INT insert_homsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)(
     INSERT_SF_HASHTABLE(a,b,eh , cf,hf);
     ENDR("insert_homsym_hashtable");
 }
- 
-INT insert_powsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 131101 */
+
+INT insert_powsym_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(POWSYM,"insert_powsym_hashtable(1)",a);
@@ -441,8 +417,7 @@ INT insert_powsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)(
     ENDR("insert_powsym_hashtable");
 }
 
-INT insert_elmsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 131101 */
+INT insert_elmsym_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(ELMSYM,"insert_elmsym_hashtable(1)",a);
@@ -450,13 +425,10 @@ INT insert_elmsym_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)(
     INSERT_SF_HASHTABLE(a,b,eh , cf,hf);
     ENDR("insert_elmsym_hashtable");
 }
- 
 
 
-INT insert_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
-/* AK 281097 */
 /* insert into a hashtable */
-/* AK 131101 */
+INT insert_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*cf)(OP,OP), INT (*hf)(OP))
 {
     INT erg = OK;
     CTO(HASHTABLE,"insert_hashtable(2)",b);
@@ -473,15 +445,13 @@ INT insert_hashtable(a,b,eh , cf,hf) OP a,b; INT (*eh)(), (*cf)(), (*hf)();
         erg += insert_homsym_hashtable(a,b,eh,cf,hf);
     else if (S_O_K(a) == POWSYM)
         erg += insert_powsym_hashtable(a,b,eh,cf,hf);
-    else 
+    else
         erg += insert_scalar_hashtable(a,b,eh,cf,hf);
-        
+
     ENDR("insert_hashtable");
 }
 
-INT insert_scalar_hashtable(a,b,eh,ef,hf)  OP a,b; INT (*eh)(), (*ef)(), (*hf)();
-/* AK 281097 */
-/* AK 131101 */
+INT insert_scalar_hashtable(OP a, OP b, INT (*eh)(OP,OP), INT (*ef)(OP,OP), INT (*hf)(OP))
 {
     INT i,index,freeindex=-1,hv,hvv;
     INT erg = OK;
@@ -490,7 +460,6 @@ INT insert_scalar_hashtable(a,b,eh,ef,hf)  OP a,b; INT (*eh)(), (*ef)(), (*hf)()
     COP("insert_scalar_hashtable(1)",a);
     CTO(HASHTABLE,"insert_scalar_hashtable(2)",b);
     /* einfach einfuegen */
-    
 
     if (hf == NULL) hf = hash;
     if (hf == hash)
@@ -517,7 +486,7 @@ INT insert_scalar_hashtable(a,b,eh,ef,hf)  OP a,b; INT (*eh)(), (*ef)(), (*hf)()
         if (ef == NULL) ef = eq;
         for (zz= S_V_I(z,S_V_LI(z)-1),i=S_V_LI(z)-1;i>=0;i--,zz--)
             {
-            if (EMPTYP(zz)) 
+            if (EMPTYP(zz))
                 freeindex = i;
             else {
                  if (hf == hash)
@@ -526,9 +495,9 @@ INT insert_scalar_hashtable(a,b,eh,ef,hf)  OP a,b; INT (*eh)(), (*ef)(), (*hf)()
                      hvv=HASH_MONOMPARTITION(zz);
                  else
                      hvv=(*hf)(zz);
-                 if ( 
-                     (hv == hvv) 
-                     && 
+                 if (
+                     (hv == hvv)
+                     &&
                      ((*ef)(a,zz) == TRUE)
                     )
                     {
@@ -549,16 +518,14 @@ INT insert_scalar_hashtable(a,b,eh,ef,hf)  OP a,b; INT (*eh)(), (*ef)(), (*hf)()
         /* nicht da */
         if (freeindex < 0) { freeindex = S_V_LI(z); inc_vector_co(z,3); }
 
-            
         INC_INTEGER(S_V_I(b,S_V_LI(b))); /* counter++ */
         SWAP(a,S_V_I(z,freeindex));
         FREEALL(a);
         }
 
-    /* AK 240901 */
-    /* if the table is full, i.e. number of entires > length
-       increase the size by factor 2 */
-    if ( 
+    /* if the table is full, i.e. number of entries > length
+     * increase the size by factor 2 */
+    if (
         (S_V_LI(b) < WEIGHT_HASHTABLE(b))
        )
         erg += double_hashtable(b,hf);
@@ -567,33 +534,19 @@ ende:
     ENDR("insert_scalar_hashtable");
     }
 
-#ifdef UNDEF
-    INT double_hashtable_pre091101(b,hf) OP b; INT (*hf)();
-{
-    INT erg = OK;
-    OP d;
-    CTO(HASHTABLE,"double_hashtable(1)",b);
-    d = CALLOCOBJECT();
-    SWAP(b,d);
-    erg += init_size_hashtable(b,S_V_LI(d)*2);
-    insert_hashtable_hashtable(d,b,NULL,NULL,hf);
-    ENDR("double_hashtable");
-}
-#endif
 
-INT print_stat_hashtable(a) OP a;
-/* AK 0602002 */
+INT print_stat_hashtable(OP a)
 {
     INT i;
-    printf("entries = %ld size = %ld\n",S_V_II(a,S_V_LI(a)),S_V_LI(a));
-    printf("entires per slot (>1 == collision)\n");
+    printf("entries = %" PRIdPTR " size = %" PRIdPTR "\n",S_V_II(a,S_V_LI(a)),S_V_LI(a));
+    printf("entries per slot (>1 == collision)\n");
     for (i=0;i<S_V_LI(a);i++)
-        printf(" %ld ",(EMPTYP(S_V_I(a,i)) ? -S_V_II(a,i) : S_V_LI(S_V_I(a,i)) ) );
+        printf(" %" PRIdPTR " ",(EMPTYP(S_V_I(a,i)) ? -S_V_II(a,i) : S_V_LI(S_V_I(a,i)) ) );
     printf("\n");
     return OK;
 }
 
-INT double_hashtable(b,hf) OP b; INT (*hf)();
+INT double_hashtable(OP b, INT (*hf)(OP))
 {
     INT erg = OK;
     INT i,l,j,hh,index,k;
@@ -604,7 +557,6 @@ INT double_hashtable(b,hf) OP b; INT (*hf)();
     C_O_K(S_V_I(b,l),EMPTY);
     inc_vector_co(b,l+1);
     M_I_I(S_V_LI(b)-1,S_V_L(b));
-    
 
     M_I_I(i,S_V_I(b,S_V_LI(b)));
     /* die anzahl der eintraege ist o.k. */
@@ -618,7 +570,7 @@ INT double_hashtable(b,hf) OP b; INT (*hf)();
                 if (not EMPTYP(S_V_I(z,j)))
                     {
                     /* schauen ob der eintrag in die zweite haelfte muss */
-                    if (hf == hash_monompartition) 
+                    if (hf == hash_monompartition)
                         hh = HASH_MONOMPARTITION(S_V_I(z,j));
                     else if (hf == hash)
 		        hh = HASH(S_V_I(z,j));
@@ -627,10 +579,10 @@ INT double_hashtable(b,hf) OP b; INT (*hf)();
                     index = hh % S_V_LI(b);
                     if (index < 0) index += S_V_LI(b);
                     if (index == i) ;
-                    else if (index == (i+l) ) 
+                    else if (index == (i+l) )
                         {
                         /* muss in die zweite haelfte */
-                        if (EMPTYP(S_V_I(b,index))) { 
+                        if (EMPTYP(S_V_I(b,index))) {
                             erg += m_il_v(1,S_V_I(b,index));
                             SWAP(S_V_I(z,j), S_V_I(S_V_I(b,index),0));
                             }
@@ -639,7 +591,7 @@ INT double_hashtable(b,hf) OP b; INT (*hf)();
                             SWAP(S_V_I(z,j), S_V_I(S_V_I(b,index),S_V_LI(S_V_I(b,index))-1 ) );
                             }
                         }
-                    else 
+                    else
                         {
                         erg += error("double_hashtable(i)");
                         goto ende;
@@ -655,7 +607,6 @@ ende:
         else k = i;
     for (;i>=0;i--,z--)
         if (EMPTYP(z)) {
-            /* SYMCHECK(S_I_I(z) != -1,"double_hashtable:e2"); */
             C_I_I(z,k);
             }
         else
@@ -665,8 +616,7 @@ ende:
     ENDR("double_hashtable");
 }
 
-INT split_hashtable(a,b,c) OP a,b,c;
-/* AK 201201 */
+INT split_hashtable(OP a, OP b, OP c)
 {
     INT i,t=0,h=0,erg = OK;
     OP z;
@@ -687,7 +637,7 @@ INT split_hashtable(a,b,c) OP a,b,c;
            }
         }
 
-    if (t == 1) /* only entires at one adress, split them */
+    if (t == 1) /* only entries at one address, split them */
         {
         m_il_v(S_V_LI(S_V_I(c,h)), S_V_I(b,h));
         for (i=0;i<S_V_LI(S_V_I(c,h));i++)
@@ -696,17 +646,14 @@ INT split_hashtable(a,b,c) OP a,b,c;
 
     t = 0; FORALL(z,b, { t++; } ); M_I_I(t,S_V_I(b, S_V_LI(b)));
     h = 0; FORALL(z,c, { h++; } ); M_I_I(h,S_V_I(c, S_V_LI(c)));
-    SYMCHECK( h+t != WEIGHT_HASHTABLE(a) ,"split_hashtable:weight doesnt add");
+    SYMCHECK( h+t != WEIGHT_HASHTABLE(a) ,"split_hashtable:weight does not add");
     CTO(HASHTABLE,"split_hashtable(2-res)",b);
     CTO(HASHTABLE,"split_hashtable(3-res)",c);
     ENDR("split_hashtable");
 }
 
 
-
-
-INT hash_partition(a) OP a;
-/* AK 261001 */
+INT hash_partition(OP a)
 {
     INT erg = OK,i;
     CTO(PARTITION,"hash_partition(1)",a);
@@ -714,7 +661,7 @@ INT hash_partition(a) OP a;
         {
         i = hash(S_PA_S(a));
         C_PA_HASH(a,i);
-        return i; 
+        return i;
         }
     else
         return S_PA_HASH(a);
@@ -722,54 +669,53 @@ INT hash_partition(a) OP a;
     ENDR("hash_partition");
 }
 
-INT hash_monompartition(a) OP a;
-/* AK 261001 */
+
+INT hash_monompartition(OP a)
 {
     INT erg = OK,res;
     CTO(MONOM,"hash_monompartition(1)",a);
     CTO(PARTITION,"hash_monompartition(1)",S_MO_S(a));
-    if (S_PA_HASH(S_MO_S(a)) == -1) 
+    if (S_PA_HASH(S_MO_S(a)) == -1)
         {
         HASH_INTEGERVECTOR(S_PA_S(S_MO_S(a)),res);
         C_PA_HASH(S_MO_S(a),res);
-        return res; 
+        return res;
         }
     else
         return S_PA_HASH(S_MO_S(a));
- 
+
     ENDR("hash_monompartition");
 }
 
-INT hash_integervector(a) OP a;
-/* AK 261001 */
+INT hash_integervector(OP a)
 {
     INT res;
     HASH_INTEGERVECTOR(a,res);
     return res;
 }
 
-INT hash(a) OP a;
+
 /* returns hash-number unsigned 32 bit */
-/* AK 281097 */
+INT hash(OP a)
 {
     INT i,erg=OK;
     COP("hash(1)",a);
     again:
     switch(S_O_K(a))
         {
-        case EMPTY: 
+        case EMPTY:
             return 0;
-        case INTEGER: 
+        case INTEGER:
             return S_I_I(a);
-        case MONOM: 
+        case MONOM:
             a=S_MO_S(a);
             goto again;
-        case POLYNOM: 
-        case LIST: 
+        case POLYNOM:
+        case LIST:
             return hash_list(a);
-        case SKEWPARTITION: 
+        case SKEWPARTITION:
             return hash_skewpartition(a);
-        case PARTITION: 
+        case PARTITION:
             return hash_partition(a);
         case PERMUTATION: a=S_P_S(a);goto again;
         case SUBSET:
@@ -784,20 +730,20 @@ INT hash(a) OP a;
         case INTEGERMATRIX:
         case KRANZTYPUS:
             return hash_matrix(a);
-        case VECTOR: 
+        case VECTOR:
             {
             INT res;
-            if (S_V_LI(a) == 0) return 4711; /* AK 300802 4711 instead of 11 */
+            if (S_V_LI(a) == 0) return 4711; /* 4711 instead of 11 */
             res = hash(S_V_I(a,0));
             for (i=1;i<S_V_LI(a);i++)
                 {
-                res *= 4711;   /* AK 300802 4711 instead of 11 */
+                res *= 4711; /* 4711 instead of 11 */
                 res += hash(S_V_I(a,i));
                 }
             return res;
             }
         default:
-            erg += WTO("hash(1)",a);
+            WTO("hash(1)",a);
             break;
         }
     ENDR("hash");
@@ -808,7 +754,7 @@ do {\
     OP z;\
     if (a == b)  { erg += (*af)(a); goto ende; }\
    \
-    if (WEIGHT_HASHTABLE(a) > 30 ) /* more then 30 entries *//* AK 260901 */\
+    if (WEIGHT_HASHTABLE(a) > 30 ) /* more then 30 entries */\
          erg += init(BINTREE,b);\
     else\
          erg += init(t,b);\
@@ -833,8 +779,7 @@ do {\
     if (S_O_K(b) == BINTREE) erg += (*tf)(b,b);\
 } while(0)
 
-INT t_HASHTABLE_SCHUR(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_SCHUR(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_SCHUR(1)",a);
@@ -845,8 +790,7 @@ ende:
     ENDR("t_HASHTABLE_SCHUR");
 }
 
-INT t_HASHTABLE_MONOMIAL(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_MONOMIAL(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_MONOMIAL(1)",a);
@@ -857,8 +801,7 @@ ende:
     ENDR("t_HASHTABLE_MONOMIAL");
 }
 
-INT t_HASHTABLE_HOMSYM(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_HOMSYM(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_HOMSYM(1)",a);
@@ -869,8 +812,7 @@ ende:
     ENDR("t_HASHTABLE_HOMSYM");
 }
 
-INT t_HASHTABLE_ELMSYM(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_ELMSYM(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_ELMSYM(1)",a);
@@ -881,8 +823,7 @@ ende:
     ENDR("t_HASHTABLE_ELMSYM");
 }
 
-INT t_HASHTABLE_POWSYM(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_POWSYM(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_POWSYM(1)",a);
@@ -893,8 +834,7 @@ ende:
     ENDR("t_HASHTABLE_POWSYM");
 }
 
-INT t_HASHTABLE_POLYNOM(a,b) OP a,b;
-/* AK 240901 */
+INT t_HASHTABLE_POLYNOM(OP a, OP b)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_POLYNOM(1)",a);
@@ -912,29 +852,28 @@ ende:
     INT i,j;\
     OP z;\
     b = CALLOCOBJECT();\
-    if (WEIGHT_HASHTABLE(a) > 30 ) /* more then 30 entries *//* AK 260901 */\
+    if (WEIGHT_HASHTABLE(a) > 30 ) /* more then 30 entries */ \
          erg += init_bintree(b);\
     else\
          erg += init(typ,b);\
 \
-    for (i=0;i<S_V_LI(a);i++)\
-    {\
-    z = S_V_I(a,i);\
-    if (not EMPTYP(z))\
-        {\
-        for (j=0;j<S_V_LI(z);j++)\
-        if (not EMPTYP(S_V_I(z,j)))\
-        if (not NULLP(S_MO_K(S_V_I(z,j))))\
-            {\
-            OP d;\
-            d = CALLOCOBJECT();\
-            erg += b_sn_l(CALLOCOBJECT(),NULL,d);\
-            SWAP(S_L_S(d),S_V_I(z,j));\
-            C_O_K(d,typ);\
-            INSERT(d,b,NULL,cf);\
-            }\
-        else {\
-            FREESELF(S_V_I(z,j));\
+    for (i=0;i<S_V_LI(a);i++) {\
+        z = S_V_I(a,i);\
+        if (not EMPTYP(z)) {\
+            for (j=0;j<S_V_LI(z);j++) {\
+                if (not EMPTYP(S_V_I(z,j))) {\
+                    if (not NULLP(S_MO_K(S_V_I(z,j)))) {\
+                        OP d;\
+                        d = CALLOCOBJECT();\
+                        erg += b_sn_l(CALLOCOBJECT(),NULL,d);\
+                        SWAP(S_L_S(d),S_V_I(z,j));\
+                        C_O_K(d,typ);\
+                        INSERT(d,b,NULL,cf);\
+                    }\
+                    else {\
+                        FREESELF(S_V_I(z,j));\
+                    }\
+                }\
             }\
         }\
     }\
@@ -947,8 +886,7 @@ ende:
     FREEALL(b);\
 }
 
-INT t_HASHTABLE_POLYNOM_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_POLYNOM_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_POLYNOM_apply(1)",a);
@@ -956,8 +894,7 @@ INT t_HASHTABLE_POLYNOM_apply(a) OP a;
     ENDR("t_HASHTABLE_POLYNOM_apply");
 }
 
-INT t_HASHTABLE_SCHUR_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_SCHUR_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_SCHUR_apply(1)",a);
@@ -965,8 +902,7 @@ INT t_HASHTABLE_SCHUR_apply(a) OP a;
     ENDR("t_HASHTABLE_SCHUR_apply");
 }
 
-INT t_HASHTABLE_POWSYM_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_POWSYM_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_POWSYM_apply(1)",a);
@@ -974,8 +910,7 @@ INT t_HASHTABLE_POWSYM_apply(a) OP a;
     ENDR("t_HASHTABLE_POWSYM_apply");
 }
 
-INT t_HASHTABLE_HOMSYM_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_HOMSYM_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_HOMSYM_apply(1)",a);
@@ -984,8 +919,7 @@ INT t_HASHTABLE_HOMSYM_apply(a) OP a;
 }
 
 
-INT t_HASHTABLE_ELMSYM_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_ELMSYM_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_ELMSYM_apply(1)",a);
@@ -995,8 +929,7 @@ INT t_HASHTABLE_ELMSYM_apply(a) OP a;
 
 
 
-INT t_HASHTABLE_MONOMIAL_apply(a) OP a;
-/* AK 240901 */
+INT t_HASHTABLE_MONOMIAL_apply(OP a)
 {
     INT erg = OK;
     CTO(HASHTABLE,"t_HASHTABLE_MONOMIAL_apply(1)",a);
@@ -1005,8 +938,7 @@ INT t_HASHTABLE_MONOMIAL_apply(a) OP a;
 }
 
 
-INT t_POWSYM_HASHTABLE(a,b) OP a,b;
-/* AK 171001 */
+INT t_POWSYM_HASHTABLE(OP a, OP b)
 {
     OP z;
     INT erg = OK;
@@ -1019,8 +951,7 @@ INT t_POWSYM_HASHTABLE(a,b) OP a,b;
     ENDR("t_POWSYM_HASHTABLE");
 }
 
-INT t_HOMSYM_HASHTABLE(a,b) OP a,b;
-/* AK 171001 */
+INT t_HOMSYM_HASHTABLE(OP a, OP b)
 {
     OP z;
     INT erg = OK;
@@ -1033,8 +964,7 @@ INT t_HOMSYM_HASHTABLE(a,b) OP a,b;
     ENDR("t_HOMSYM_HASHTABLE");
 }
 
-INT t_SCHUR_HASHTABLE(a,b) OP a,b;
-/* AK 171001 */
+INT t_SCHUR_HASHTABLE(OP a, OP b)
 {
     OP z;
     INT erg = OK;
@@ -1048,9 +978,7 @@ INT t_SCHUR_HASHTABLE(a,b) OP a,b;
 }
 
 
-
-INT t_ELMSYM_HASHTABLE(a,b) OP a,b;
-/* AK 171001 */
+INT t_ELMSYM_HASHTABLE(OP a, OP b)
 {
     OP z;
     INT erg = OK;
@@ -1064,16 +992,14 @@ INT t_ELMSYM_HASHTABLE(a,b) OP a,b;
 }
 
 
-
-INT t_MONOMIAL_HASHTABLE(a,b) OP a,b;
-/* AK 171001 */
+INT t_MONOMIAL_HASHTABLE(OP a, OP b)
 {
     OP z;
     INT erg = OK;
     CTO(MONOMIAL,"t_MONOMIAL_HASHTABLE(1)",a);
     CE2(a,b,t_MONOMIAL_HASHTABLE);
     erg += init(HASHTABLE,b);
-    FORALL(z,a,{ 
+    FORALL(z,a,{
              OP d = CALLOCOBJECT();
              COPY(z,d);
              INSERT_HASHTABLE(d,b,NULL,eq_monomsymfunc,hash_monompartition); } );
@@ -1081,7 +1007,7 @@ INT t_MONOMIAL_HASHTABLE(a,b) OP a,b;
     ENDR("t_MONOMIAL_HASHTABLE");
 }
 
-static INT hash2(a) OP a;
+static INT hash2(OP a)
 {
     INT erg = OK;
     INT res;
@@ -1092,7 +1018,9 @@ static INT hash2(a) OP a;
     return res;
     ENDR("hash2");
 }
-static INT hash1(a) OP a;
+
+
+static INT hash1(OP a)
 {
     INT erg = OK;
     INT res;
@@ -1104,7 +1032,7 @@ static INT hash1(a) OP a;
 }
 
 
-static INT eq2(a,b) OP a,b;
+static INT eq2(OP a, OP b)
 {
     INT erg = OK;
     INT res;
@@ -1120,48 +1048,39 @@ static INT eq2(a,b) OP a,b;
     ENDR("eq2");
 }
 
-static INT eq1(a,b) OP a,b;
+static INT eq1(OP a, OP b)
 {
     INT erg = OK;
     INT res;
     CTO(VECTOR,"eq1(1)",a);
- 
-/*
-    M_I_I(1,S_V_L(a));
-    M_I_I(1,S_V_L(b));
-    res = EQ(a,b);
-    M_I_I(2,S_V_L(a));
-    M_I_I(2,S_V_L(b));
-    return res;
-*/
-    return EQ(S_V_I(a,0), S_V_I(b,0)); 
+
+    return EQ(S_V_I(a,0), S_V_I(b,0));
     ENDR("eq1");
 }
- 
 
 
-OP find_1result_hashtable(a,h) OP a,h;
+OP find_1result_hashtable(OP a, OP h)
 {
     INT erg = OK;
     OP res,v;
     CTO(ANYTYPE,"find_1result_hashtable(1)",a);
     CTO(HASHTABLE,"find_1result_hashtable(2)",h);
- 
+
     if (lookup1 == NULL)
         NEW_VECTOR(lookup1,2);
     C_V_I(lookup1,0,a);
     res = find_hashtable(lookup1,h,eq1,hash1);
-    
+
     if (res == NULL) return res;
- 
+
     res = S_V_I(res,1);
-    
+
     return res;
- 
+
     ENDO("find_1result_hashtable");
 }
 
-OP find_2result_hashtable(a,b,h) OP a,b,h;
+OP find_2result_hashtable(OP a, OP b, OP h)
 {
     INT erg = OK;
     OP res,v;
@@ -1177,13 +1096,13 @@ OP find_2result_hashtable(a,b,h) OP a,b,h;
     if (res == NULL) return res;
 
     res = S_V_I(res,2);
-    
+
     return res;
 
     ENDO("find_2result_hashtable");
 }
 
-INT move_2result_hashtable(a,b,c,h) OP a,b,c,h;
+INT move_2result_hashtable(OP a, OP b, OP c, OP h)
 {
     INT erg = OK;
     OP v;
@@ -1202,7 +1121,7 @@ INT move_2result_hashtable(a,b,c,h) OP a,b,c,h;
     ENDR("move_2result_hashtable");
 }
 
-INT move_1result_hashtable(a,c,h) OP a,c,h;
+INT move_1result_hashtable(OP a, OP c, OP h)
 {
     INT erg = OK;
     OP v;
@@ -1219,9 +1138,9 @@ INT move_1result_hashtable(a,c,h) OP a,c,h;
     ENDR("move_1result_hashtable");
 }
 
-INT filter_apply_hashtable(a,f) OP a; INT (*f)();
-/* AK 130603 */
-/* if f return true the elemnts stay in the hashtable */
+
+/* if f return true the elements stay in the hashtable */
+INT filter_apply_hashtable(OP a, INT (*f)(OP))
 {
     OP z;
     INT erg = OK;
@@ -1233,11 +1152,10 @@ INT filter_apply_hashtable(a,f) OP a; INT (*f)();
             DEC_INTEGER(S_V_I(a,S_V_LI(a))); /* counter-- */
             }
         });
-    ENDR("filter_apply_hashtable");          
+    ENDR("filter_apply_hashtable");
 }
 
-INT t_HASHTABLE_VECTOR(a,v) OP a,v;
-/* AK 040803 */
+INT t_HASHTABLE_VECTOR(OP a, OP v)
 {
     INT erg =OK;INT i=0;
     OP z;
