@@ -1,11 +1,8 @@
-
 #include "def.h"
 #include "macro.h"
 
-static INT ausgabe_koeff();
-static INT write_polynom();
-
-
+static INT ausgabe_koeff(OP);
+static INT write_polynom(OP);
 
 
 /* global variables for output */
@@ -13,13 +10,11 @@ static INT write_polynom();
     INT texposition;
     INT texmath_yn; /* 1 in mathmode */ /* 0 not in mathmode */
     INT scanoutput_yn; /* 1 no output */ /* 0 bitte output */
-    INT row_length = 70; 
-    INT tex_row_length = 70; 
+    INT row_length = 70;
+    INT tex_row_length = 70;
     INT integer_format = 0; /* no format */
 
-INT print_type(a) OBJECTKIND a;
-/* AK 280294 */
-/* AK 240398 V2.0 */
+INT print_type(OBJECTKIND a)
 {
     OP b;
     INT erg = OK;
@@ -33,18 +28,16 @@ INT print_type(a) OBJECTKIND a;
     ENDR("print_type");
 }
 
-INT printobjectkind(a) OP a;
-/* AK 270689 V1.0 */ /* AK 020290 V1.1 */ /* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
+INT printobjectkind(OP a)
     {
     INT erg = OK;
-    if (a == NULL) 
+    if (a == NULL)
         {
         fprintf(stderr,"object is NULL object\n");
-        goto endr_ende; 
+        goto endr_ende;
         }
     fprintf(stderr,"kind of object is ");
-    
+
     switch(S_O_K(a))
         {
     case AUG_PART: fprintf(stderr,"augpart\n");break;
@@ -89,17 +82,14 @@ INT printobjectkind(a) OP a;
     case HASHTABLE: fprintf(stderr,"hashtable\n");break;
     case INTEGERVECTOR: fprintf(stderr,"integervector\n");break;
     case (OBJECTKIND) 0: fprintf(stderr,"empty-object\n");break;
-    default: fprintf(stderr," %ld ",S_O_K(a));
+    default: fprintf(stderr," %" PRIOBJECTKIND " ",S_O_K(a));
         fprintf(stderr,"unknown\n");
         break;
         };
     ENDR("printobjectkind");
     }
 
-INT ferrers(obj) OP obj;
-/* AK 290986 */ /* AK 010889 V1.0 */ /* AK 020290 V1.1 */
-/* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
+INT ferrers(OP obj)
     {
     INT erg = OK;
     COP("ferrers(1)",obj);
@@ -112,15 +102,11 @@ INT ferrers(obj) OP obj;
         case SKEWPARTITION: erg +=  ferrers_skewpartition(obj); break;
 #endif /* SKEWPARTTRUE */
         default:  
-            erg += WTO("ferrers",obj); break;
+            WTO("ferrers",obj); break;
         }
     ENDR("ferrers");
     }
-
-
-INT scan_printeingabe(text) char *text;
-/* AK 250194 */
-/* AK 240398 V2.0 */
+INT scan_printeingabe(char *text)
     {
     extern INT scanoutput_yn; /* 1 no output */ /* 0 bitte output */
     if (scanoutput_yn == (INT) 0)
@@ -128,20 +114,14 @@ INT scan_printeingabe(text) char *text;
     return OK;
     }
 
-INT printeingabe(text) char *text;
-/* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 070291 V1.2 prints to stderr instead to stdout , returns OK */
-/* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
-    { 
-    fprintf(stderr,"%s\n",text); 
+INT printeingabe(char *text)
+    {
+    fprintf(stderr,"%s\n",text);
     return OK;
     }
 
-INT sprint(string, obj) char *string; OP obj;
-/* AK 020195 */
 /* to get length of string use strlen */
-/* AK 240398 V2.0 */
+INT sprint(char *string, OP obj)
 {
     INT erg = OK;
     COP("sprint(2)",obj);
@@ -154,19 +134,19 @@ INT sprint(string, obj) char *string; OP obj;
             erg+= sprint_ff(string,obj);
             goto spe;
 #endif
-        case INTEGER: 
+        case INTEGER:
             erg+= sprint_integer(string,obj);
             goto spe;
 #ifdef LONGINTTRUE
-        case LONGINT: 
+        case LONGINT:
             erg+= sprint_longint(string,obj);
             goto spe;
 #endif /* LONGINTTRUE */
 #ifdef PARTTRUE
-        case SKEWPARTITION: 
+        case SKEWPARTITION:
             erg+= sprint_skewpartition(string,obj);
             goto spe;
-        case PARTITION: 
+        case PARTITION:
             erg+= sprint_partition(string,obj);
             goto spe;
 #endif /* PARTTRUE */
@@ -176,26 +156,23 @@ INT sprint(string, obj) char *string; OP obj;
             goto spe;
 #endif /* PERMTRUE */
 #ifdef VECTORTRUE
-        case INTEGERVECTOR: 
+        case INTEGERVECTOR:
             erg+= sprint_integervector(string,obj);
             goto spe;
-        case VECTOR: 
+        case VECTOR:
             erg+= sprint_vector(string,obj);
             goto spe;
 #endif /* VECTORTRUE */
 
-        default: 
-            WTO("sprint(1)",obj); 
+        default:
+            WTO("sprint(1)",obj);
             goto spe;
         }
 spe:
     ENDR("sprint");
 }
 
-INT fprint(of,obj) FILE    *of; OP obj;
-/* AK 211186 */ /* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 050891 V1.3 */
-/* AK 240398 V2.0 */
+INT fprint(FILE *of, OP obj)
     {
     INT erg = OK;
     COP("fprint(1)",of);
@@ -204,7 +181,7 @@ INT fprint(of,obj) FILE    *of; OP obj;
     switch(S_O_K(obj))
         {
 #ifdef PARTTRUE
-        case AUG_PART: 
+        case AUG_PART:
         case PARTITION:  erg += fprint_partition(of,obj);break;
 #endif /* PARTTRUE */
 #ifdef BINTREETRUE
@@ -222,7 +199,7 @@ INT fprint(of,obj) FILE    *of; OP obj;
 #ifdef LISTTRUE
         case ELM_SYM: case MONOMIAL: case HOM_SYM: case POW_SYM:
         case GRAL: case MONOPOLY: case POLYNOM: case SCHUBERT:
-        case SCHUR: case LIST:  
+        case SCHUR: case LIST:
             erg += fprint_list(of,obj);break;
 #endif /* LISTTRUE */
 #ifdef LONGINTTRUE
@@ -246,15 +223,15 @@ INT fprint(of,obj) FILE    *of; OP obj;
                 break;
 #endif /* REIHETRUE */
 #ifdef SKEWPARTTRUE
-        case SKEWPARTITION: /*020488 */
+        case SKEWPARTITION:
              erg += fprint_skewpartition(of,obj);break;
 #endif /* SKEWPARTTRUE */
 #ifdef CHARTRUE
-        case SYMCHAR: /*110488 */
+        case SYMCHAR:
              erg += fprint_symchar(of,obj);break;
 #endif /* CHARTRUE */
 #ifdef TABLEAUXTRUE
-        case TABLEAUX: /*020488 */
+        case TABLEAUX:
              erg += fprint_tableaux(of,obj);break;
 #endif /* TABLEAUXTRUE */
 #ifdef VECTORTRUE
@@ -276,23 +253,19 @@ INT fprint(of,obj) FILE    *of; OP obj;
         case SQ_RADICAL:
         case CYCLOTOMIC:  erg += fprint_number(of,obj);break;
 #endif /* NUMBERTRUE */
-        case 0:     
+        case 0:
             fprintf(of,"#");
-            /* AK 310889 */
             if (of == stdout) 
                 zeilenposition++;
              break;
-        default: erg += WTO("fprint",obj); 
+        default: WTO("fprint",obj); 
             break;
         };
 
     ENDR("fprint");
     }
 
-INT display(obj) OP obj;
-/* AK 271087 */ /* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
+INT display(OP obj)
     {
     INT erg = OK;
     COP("display(1)",obj);
@@ -300,37 +273,32 @@ INT display(obj) OP obj;
     switch(S_O_K(obj))
         {
 #ifdef SCHUBERTTRUE
-        case SCHUBERT: 
+        case SCHUBERT:
             erg += display_schubert(obj);
             break;
 #endif /* SCHUBERTTRUE */
         default: 
-            erg += WTO("display(1)",obj);
+            WTO("display(1)",obj);
             break;
         };
     ENDR("display");
     }
- 
-INT fprintln(f,obj) FILE *f; OP obj;
-/* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 130891 V1.3 */ /* AK 240398 V2.0 */
-/* AK 201204 V3.0 */
+
+INT fprintln(FILE *f, OP obj)
     {
     INT erg = OK;
     COP("fprintln(1)",f);
     COP("fprintln(2)",obj);
 
-    erg += fprint(f,obj); 
+    erg += fprint(f,obj);
     putc('\n',f);
     if (f == stdout) zeilenposition = 0;
     ENDR("fprintln");
     }
 
-INT check_zeilenposition(f) FILE *f;
-/* AK 201204 */
+INT check_zeilenposition(FILE *f)
     {
     if (f==stdout) {
-        /* printf("(zp=%d)",zeilenposition); */
         if (zeilenposition > row_length) { putchar('\n'); zeilenposition=0; }
         }
     return OK;
@@ -338,10 +306,7 @@ INT check_zeilenposition(f) FILE *f;
 
 
 
-INT print(obj) OP obj;
-/* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 130891 V1.3 */ /* AK 240398 V2.0 */ 
-/* AK 201204 V3.0 */
+INT print(OP obj)
     {
     INT erg = OK;
     COP("print(1)",obj);
@@ -352,21 +317,17 @@ INT print(obj) OP obj;
 
 
 
-INT println(obj) OP obj;
-/* AK 270689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
+INT println(OP obj)
 {
     INT erg = OK;
     COP("println(1)",obj);
-    erg += print(obj); 
+    erg += print(obj);
     putchar('\n'); zeilenposition = 0;
     ENDR("println");
 }
 
 
-INT skip_comment()
-/* AK 240398 V2.0 */
+INT skip_comment(void)
 {
     int i;
 /* here we insert code to implement comments *//* AK 210395 */
@@ -386,14 +347,12 @@ sa:
 }
 
 
-INT scan(kind,obj) OBJECTKIND kind; OP obj;
-/* AK 270787 */ /* AK 280689 V1.0 */ /* AK 020290 V1.1 */ /* AK 050891 V1.3 */
-/* AK 240298 V2.0 */
+INT scan(OBJECTKIND kind, OP obj)
 {
     INT erg = OK;
     COP("scan(2)",obj);
 
-    if (not EMPTYP(obj)) 
+    if (not EMPTYP(obj))
         erg += freeself(obj);
 
     switch(kind)
@@ -458,9 +417,9 @@ INT scan(kind,obj) OBJECTKIND kind; OP obj;
         case MONOPOLY: erg += scan_monopoly(obj); break;
 #endif /* MONOPOLYTRUE */
 #ifdef PARTTRUE
-        case REVERSEPARTITION: erg += scan_reversepartition(obj); 
+        case REVERSEPARTITION: erg += scan_reversepartition(obj);
             break;
-        case EXPONENTPARTITION: erg += scan_exponentpartition(obj); 
+        case EXPONENTPARTITION: erg += scan_exponentpartition(obj);
             break;
         case PARTITION: erg += scan_partition(obj); break;
 #endif /* PARTTRUE */
@@ -494,22 +453,22 @@ INT scan(kind,obj) OBJECTKIND kind; OP obj;
         case SYMCHAR: erg += scan_symchar(obj); break;
 #endif /* CHARTRUE */
 #ifdef TABLEAUXTRUE
-        case PARTTABLEAUX: 
-            erg += scan_parttableaux(obj); 
+        case PARTTABLEAUX:
+            erg += scan_parttableaux(obj);
             break;
-        case SKEWTABLEAUX: 
-            erg += scan_skewtableaux(obj); 
+        case SKEWTABLEAUX:
+            erg += scan_skewtableaux(obj);
             break;
-        case TABLEAUX: 
-            erg += scan_tableaux(obj); 
+        case TABLEAUX:
+            erg += scan_tableaux(obj);
             break;
 #endif /* TABLEAUXTRUE */
 #ifdef VECTORTRUE
-        case VECTOR: 
+        case VECTOR:
             erg += scan_vector(obj); break;
-        case BITVECTOR: 
+        case BITVECTOR:
             erg += scan_bitvector(obj); break;
-        case PERMUTATIONVECTOR: 
+        case PERMUTATIONVECTOR:
             erg += scan_permvector(obj); break;
 #endif /* VECTORTRUE */
 #ifdef WORDTRUE
@@ -517,7 +476,7 @@ INT scan(kind,obj) OBJECTKIND kind; OP obj;
 #endif /* WORDTRUE */
         default:
             {
-            fprintf(stderr,"kind = %ld\n",kind);
+            fprintf(stderr,"kind = %" PRIOBJECTKIND "\n",kind);
             erg += error("scan:wrong type");
             goto endr_ende;
             }
@@ -525,9 +484,8 @@ INT scan(kind,obj) OBJECTKIND kind; OP obj;
     ENDR("scan");
     }
 
-INT skip(t,kind) char *t; OBJECTKIND kind;
-/* AK 300998 */
 /* return >= 0 gives the offset in t after the given object */
+INT skip(char *t, OBJECTKIND kind)
     {
     INT erg = OK;
     COP("skip(1)",t);
@@ -541,7 +499,7 @@ INT skip(t,kind) char *t; OBJECTKIND kind;
             }
         default:
             {
-            fprintf(stderr,"kind = %ld\n",kind);
+            fprintf(stderr,"kind = %" PRIOBJECTKIND "\n",kind);
             erg += error("skip:wrong type");
             goto endr_ende;
             }
@@ -549,14 +507,13 @@ INT skip(t,kind) char *t; OBJECTKIND kind;
     ENDR("skip");
     }
 
-INT sscan(t,kind,obj) char *t; OBJECTKIND kind; OP obj;
-/* AK 301293 */
+INT sscan( char *t, OBJECTKIND kind, OP obj)
     {
     INT erg = OK;
     COP("sscan(1)",t);
     COP("sscan(3)",obj);
 
-    if (not EMPTYP(obj)) 
+    if (not EMPTYP(obj))
         erg += freeself(obj);
     switch(kind)
         {
@@ -572,11 +529,11 @@ INT sscan(t,kind,obj) char *t; OBJECTKIND kind; OP obj;
         case LONGINT: erg += sscan_longint(t,obj); break;
 #endif /* LONGINTTRUE */
 #ifdef PARTTRUE
-        case PARTITION: 
-            erg += sscan_partition(t,obj); 
+        case PARTITION:
+            erg += sscan_partition(t,obj);
             break;
-        case REVERSEPARTITION: 
-            erg += sscan_reversepartition(t,obj); 
+        case REVERSEPARTITION:
+            erg += sscan_reversepartition(t,obj);
             break;
 #endif /* PARTTRUE */
 #ifdef PERMTRUE
@@ -595,7 +552,7 @@ INT sscan(t,kind,obj) char *t; OBJECTKIND kind; OP obj;
 
         default:
             {
-            fprintf(stderr,"kind = %ld\n",kind);
+            fprintf(stderr,"kind = %" PRIOBJECTKIND "\n",kind);
             error("sscan:wrong type");
             return(ERROR);
             }
@@ -603,130 +560,126 @@ INT sscan(t,kind,obj) char *t; OBJECTKIND kind; OP obj;
     ENDR("sscan");
     }
 
-OBJECTKIND scanobjectkind()
-/* routine zum einlesen des objecttyps 160787 */
-/* AK 280689 V1.0 */ /* AK 020290 V1.1 */
-/* AK 070291 V1.2 works with stderr instead of stdin */
-/* AK 130891 V1.3 */
-/* AK 240398 V2.0 */
+/* routine zum einlesen des objecttyps */
+OBJECTKIND scanobjectkind(void)
     {
     INT erg;
     INT i = 0L;
-    
+
     printeingabe("enter kind of object");
     /* hier sind neue objecttypen einzufuegen */
-    
+
 #ifdef INTEGERTRUE
-    fprintf(stderr,"integer     [1]"); 
+    fprintf(stderr,"integer     [1]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* INTEGERTRUE */
 #ifdef VECTORTRUE
-    fprintf(stderr,"vector      [2]"); 
+    fprintf(stderr,"vector      [2]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* VECTORTRUE */
 #ifdef PARTTRUE
-    fprintf(stderr,"partition   [3]"); 
+    fprintf(stderr,"partition   [3]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* PARTTRUE */
 #ifdef BRUCHTRUE
-    fprintf(stderr,"bruch       [4]"); 
+    fprintf(stderr,"bruch       [4]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* BRUCHTRUE */
 #ifdef PERMTRUE
-    fprintf(stderr,"permutation [6]"); 
+    fprintf(stderr,"permutation [6]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* PERMTRUE */
 #ifdef SKEWPARTTRUE
-    fprintf(stderr,"skewpart    [7]"); 
+    fprintf(stderr,"skewpart    [7]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* SKEWPARTTRUE */
 #ifdef TABLEAUXTRUE
-    fprintf(stderr,"tableaux    [8]"); 
+    fprintf(stderr,"tableaux    [8]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* TABLEAUXTRUE */
 #ifdef POLYTRUE
-    fprintf(stderr,"polynom     [9]"); 
+    fprintf(stderr,"polynom     [9]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* POLYTRUE */
 #ifdef SCHURTRUE
-    fprintf(stderr,"schurfunk  [10]"); 
+    fprintf(stderr,"schurfunk  [10]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* SCHURTRUE */
 #ifdef MATRIXTRUE
-    fprintf(stderr,"matrix     [11]"); 
+    fprintf(stderr,"matrix     [11]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* MATRIXTRUE */
 #ifdef HOMSYMTRUE
-    fprintf(stderr,"homsym     [13]"); 
+    fprintf(stderr,"homsym     [13]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* HOMSYMTRUE */
 #ifdef SCHUBERTTRUE
-    fprintf(stderr,"schubert   [14]"); 
+    fprintf(stderr,"schubert   [14]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* SCHUBERTTRUE */
 #ifdef KOSTKATRUE
-    fprintf(stderr,"kostka     [16]"); 
+    fprintf(stderr,"kostka     [16]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* KOSTKATRUE */
 #ifdef CHARTRUE
-    fprintf(stderr,"symchar    [18]"); 
+    fprintf(stderr,"symchar    [18]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* CHARTRUE */
 #ifdef WORDTRUE
-    fprintf(stderr,"word       [19]"); 
+    fprintf(stderr,"word       [19]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* WORDTRUE */
 #ifdef LISTTRUE
-    fprintf(stderr,"list       [20]"); 
+    fprintf(stderr,"list       [20]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* LISTTRUE */
 #ifdef LONGINTTRUE
-    fprintf(stderr,"longint    [22]"); 
+    fprintf(stderr,"longint    [22]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* LONGINTTRUE */
 #ifdef POWSYMTRUE
-    fprintf(stderr,"powersum   [28]"); 
+    fprintf(stderr,"powersum   [28]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* POWSYMTRUE */
 #ifdef MONOMIALTRUE
-    fprintf(stderr,"mon. sym.  [29]"); 
+    fprintf(stderr,"mon. sym.  [29]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* MONOMIALTRUE */
 #ifdef GRALTRUE
-    fprintf(stderr,"groupalg.  [32]"); 
+    fprintf(stderr,"groupalg.  [32]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* GRALTRUE */
 #ifdef ELMSYMTRUE
-    fprintf(stderr,"elm. sym.  [33]"); 
+    fprintf(stderr,"elm. sym.  [33]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* ELMSYMTRUE */
 #ifdef FFTRUE
-    fprintf(stderr,"fin. field [35]"); 
+    fprintf(stderr,"fin. field [35]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* FFTRUE */
 #ifdef REIHETRUE
-    fprintf(stderr,"reihe      [36]"); 
+    fprintf(stderr,"reihe      [36]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* REIHETRUE */
 #ifdef CYCLOTRUE
-    fprintf(stderr,"cyclotomic [41]"); 
+    fprintf(stderr,"cyclotomic [41]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* CYCLOTRUE */
 #ifdef MONOPOLYTRUE
-    fprintf(stderr,"monopoly   [42]"); 
+    fprintf(stderr,"monopoly   [42]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* MONOPOLYTRUE */
 #ifdef SQRADTRUE
-    fprintf(stderr,"radical    [43]"); 
+    fprintf(stderr,"radical    [43]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* SQRADTRUE */
-    fprintf(stderr,"bitvector  [44]"); 
+    fprintf(stderr,"bitvector  [44]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #ifdef LAURENTTRUE
-    fprintf(stderr,"laurent    [45]"); 
+    fprintf(stderr,"laurent    [45]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 #endif /* LAURENTTRUE */
-    fprintf(stderr,"barperm    [46]"); 
+    fprintf(stderr,"barperm    [46]");
     if (i++ == 4L)fprintf(stderr,"\n"),i=0L;
 
     fprintf(stderr,"\nwhat kind:? ");
@@ -735,10 +688,7 @@ OBJECTKIND scanobjectkind()
     return (OBJECTKIND)erg;
     }
 
-INT objectread(f,obj) FILE *f; OP obj;
-/* AK 131086 */ /* AK 280689 V1.0 */ /* AK 160190 V1.1 */ /* AK 020591 V1.2 */
-/* AK 090891 V1.3 */
-/* AK 240398 V2.0 */
+INT objectread(FILE *f, OP obj)
     {
     OBJECTKIND kind;
     INT c,erg=OK,i;
@@ -751,77 +701,77 @@ INT objectread(f,obj) FILE *f; OP obj;
     kind = (OBJECTKIND)c;
     switch(kind)
         {
-        case (OBJECTKIND)0:    
+        case (OBJECTKIND)0:
             break;
 #ifdef BRUCHTRUE
-        case BRUCH: 
+        case BRUCH:
             erg += objectread_bruch(f,obj);
             break;
 #endif /* BRUCHTRUE */
 #ifdef FFTRUE
-        case FF: 
+        case FF:
             erg += objectread_ff(f,obj);
             break;
 #endif /* FFTRUE */
 #ifdef INTEGERTRUE
-        case INTEGER: 
+        case INTEGER:
             erg += objectread_integer(f,obj);
             break;
 #endif /* INTEGERTRUE */
 #ifdef LISTTRUE
         case GRAL: case HOM_SYM: case POW_SYM: case MONOMIAL:
         case ELM_SYM: case SCHUR: case MONOPOLY: case POLYNOM:
-        case SCHUBERT: case LIST:     
+        case SCHUBERT: case LIST:
             erg += objectread_list(f,obj);
-            C_O_K(obj,kind); 
+            C_O_K(obj,kind);
             break;
 #endif /* LISTTRUE */
 #ifdef LONGINTTRUE
-        case LONGINT: 
+        case LONGINT:
             erg += objectread_longint(f,obj);
             break;
 #endif /* LONGINTTRUE */
 #ifdef MATRIXTRUE
-        case MATRIX: 
+        case MATRIX:
             erg += objectread_matrix(f,obj);
             break;
 #endif /* MATRIXTRUE */
 #ifdef MONOMTRUE
-        case MONOM: 
+        case MONOM:
             erg += objectread_monom(f,obj);
             break;
 #endif /* MONOMTRUE */
 #ifdef    NUMBERTRUE
-        case SQ_RADICAL: 
+        case SQ_RADICAL:
             erg += OBJECTREAD_SQRAD(f,obj);
             break;
-        case CYCLOTOMIC: 
+        case CYCLOTOMIC:
             erg += OBJECTREAD_CYCLO(f,obj);
             break;
 #endif /* NUMBERTRUE */
 #ifdef PARTTRUE
-        case PARTITION: 
+        case PARTITION:
             erg += objectread_partition(f,obj);
             break;
 #endif /* PARTTRUE */
 #ifdef PERMTRUE
-        case PERMUTATION: 
+        case PERMUTATION:
             erg += objectread_permutation(f,obj);
             break;
 #endif /* PERMTRUE */
 #ifdef CHARTRUE
-        case SYMCHAR: 
+        case SYMCHAR:
             erg += objectread_symchar(f,obj);
             break;
 #endif /* CHARTRUE */
 #ifdef SKEWPARTTRUE
-        case SKEWPARTITION: 
+        case SKEWPARTITION:
             erg += objectread_skewpartition(f,obj);
             break;
 #endif /* SKEWPARTTRUE */
 #ifdef TABLEAUXTRUE
-        case TABLEAUX: 
-            erg += objectread_tableaux(f,obj); 
+        case TABLEAUX:
+            erg += objectread_tableaux(f,obj);
             break;
 #endif /* TABLEAUXTRUE */
 #ifdef VECTORTRUE
@@ -830,17 +780,17 @@ INT objectread(f,obj) FILE *f; OP obj;
 	   break;
         case COMPOSITION:
         case INTEGERVECTOR:
-        case VECTOR: 
+        case VECTOR:
 	case GALOISRING:
-            erg += objectread_vector(f,obj); 
+            erg += objectread_vector(f,obj);
             C_O_K(obj,c);
             break;
-        case BITVECTOR: 
-            erg += objectread_bv(f,obj); 
+        case BITVECTOR:
+            erg += objectread_bv(f,obj);
             break;
 #endif /* VECTORTRUE */
         default:  
-            fprintf(stderr,"kind = %ld\n",kind);
+            fprintf(stderr,"kind = %" PRIOBJECTKIND "\n",kind);
             erg += error("objectread:wrong type"); 
             goto oe;
         };
@@ -848,10 +798,7 @@ oe:
     ENDR("objectread");
     }
 
-INT objectwrite(f,obj) FILE *f; OP obj;
-/* AK 131086 */ /* AK 280689 V1.0 */ /* AK 160190 V1.1 */
-/* AK 090891 V1.3 */
-/* AK 240398 V2.0 */
+INT objectwrite(FILE *f, OP obj)
     {
     INT erg = OK;
     COP("objectwrite(1)",f);
@@ -872,7 +819,7 @@ INT objectwrite(f,obj) FILE *f; OP obj;
 #ifdef LISTTRUE
         case GRAL: case HOM_SYM: case POW_SYM:
         case ELM_SYM: case MONOMIAL: case SCHUR: case MONOPOLY:
-        case POLYNOM: case SCHUBERT: case LIST: 
+        case POLYNOM: case SCHUBERT: case LIST:
             erg += objectwrite_list(f,obj);
             break;
 #endif /* LISTTRUE */
@@ -926,11 +873,8 @@ INT objectwrite(f,obj) FILE *f; OP obj;
     }
 
 
-INT tex(obj) OP obj;
 /* tex-output of the object obj */
-/* AK 101187 */ /* AK 060789 V1.0 */ /* AK 020290 V1.1 */
-/* AK 300791 V1.3 */    
-/* AK 260298 V2.0 */
+INT tex(OP obj)
     {
     INT erg = OK;
     /* es folgen zwei sonderfaelle */
@@ -973,7 +917,7 @@ INT tex(obj) OP obj;
 #ifdef MATRIXTRUE
         case KOSTKA:
         case MATRIX: erg += tex_matrix(obj);break;
-            
+
 #endif /* MATRIXTRUE */
 #ifdef MONOMTRUE
         case MONOM: erg += tex_monom(obj);break;
@@ -1010,20 +954,17 @@ INT tex(obj) OP obj;
     }
 
 
-#ifdef MATRIXTRUE 
+#ifdef MATRIXTRUE
 #ifdef POLYTRUE
-INT latex_glm_dar(M) OP    M;
-/* RH */
-/* AK 280192 output to texout */
-/* AK 240398 V2.0 */
+INT latex_glm_dar(OP M)
 {
     INT    i;
     INT    j;
     INT    k;
     INT    var = 1L;
 
-    OP     moddy    =    callocobject();    
-    OP     rest    =    callocobject();    
+    OP     moddy    =    callocobject();
+    OP     rest    =    callocobject();
     OP    vier    =    callocobject();
 
     if(S_M_LI(M) >= 10) var = 1L;
@@ -1038,7 +979,7 @@ INT latex_glm_dar(M) OP    M;
     fprintf(texout,"\\left[\n");
     for(i=0L;i<S_I_I(moddy);++i)
     {
-            if(i != 0L)    
+            if(i != 0L)
             {
                 fprintf(texout,"$$\n");
                 fprintf(texout,"\\left.\n");
@@ -1052,10 +993,10 @@ INT latex_glm_dar(M) OP    M;
                 {
                     write_polynom(S_M_IJ(M,j,var*i+k));
                     if(k != var-1L) fprintf(texout," & ");
-                    else 
-                            if(j != S_M_HI(M)-1L) 
+                    else
+                            if(j != S_M_HI(M)-1L)
                                 fprintf(texout,"\\\\\\hline\n");
-                            else    
+                            else
                                 fprintf(texout,"\\\\\n");
                 }
             }
@@ -1099,7 +1040,7 @@ INT latex_glm_dar(M) OP    M;
         {
             write_polynom(S_M_IJ(M,j,var*S_I_I(moddy)+k));
             if(k != S_I_I(rest)-1L) fprintf(texout," & ");
-            else 
+            else
                 if(j != S_M_HI(M)-1L) fprintf(texout,"\\\\\\hline\n");
                 else    fprintf(texout,"\\\\\n");
         }
@@ -1118,29 +1059,28 @@ INT latex_glm_dar(M) OP    M;
 #endif /* MATRIXTRUE */
 
 #ifdef POLYTRUE
-static INT write_polynom(poly) OP    poly;
-/* AK 280192 output to texout */
-/* AK 240398 V2.0 */
+
+static INT write_polynom(OP poly)
 {
     INT    k,l;
     OP    z = poly;
 
     while(z != NULL)
     {
-        if(!nullp(s_po_k(z)) && !emptyp(s_po_k(z)))    
+        if(!nullp(s_po_k(z)) && !emptyp(s_po_k(z)))
         {
             ausgabe_koeff(s_po_k(z));
             for(k=0L;k<S_M_HI(s_po_s(z));++k)
             {
                 for(l=0L;l<S_M_LI(s_po_s(z));++l)
-                    if(S_M_IJI(s_po_s(z),k,l) > 0L)
-
+                    if(S_M_IJI(s_po_s(z),k,l) > 0L) {
                         if(S_M_IJI(s_po_s(z),k,l) == 1L)
                             fprintf(texout,"x_{%ld %ld} ",k+1L,l+1L);
                         else
-                            fprintf(texout,"x_{%ld %ld}^{%ld} ",k+1L,l+1L,S_M_IJI(s_po_s(z),k,l));
+                            fprintf(texout,"x_{%ld %ld}^{%" PRIdPTR "} ",k+1L,l+1L,S_M_IJI(s_po_s(z),k,l));
+                    }
             }
-            if(S_PO_N(z) != NULL)    
+            if(S_PO_N(z) != NULL)
             {
                 fprintf(texout,"+");
             }
@@ -1151,13 +1091,11 @@ static INT write_polynom(poly) OP    poly;
 }
 #endif /* POLYTRUE */
 
-static INT ausgabe_koeff(k) OP    k;
-/* AK 280192 output to texout */
-/* AK 240398 V2.0 */
+static INT ausgabe_koeff(OP k)
 {
             switch(S_O_K(k))
-            { 
-                case INTEGER: 
+            {
+                case INTEGER:
                 {
                     if(S_I_I(k) == 1L)
                         break;
@@ -1171,7 +1109,7 @@ static INT ausgabe_koeff(k) OP    k;
                     break;
                 }
 #ifdef BRUCHTRUE
-                case BRUCH: 
+                case BRUCH:
                 {
                     kuerzen(k);
                     fprintf(texout,"\\frac{");
@@ -1183,7 +1121,7 @@ static INT ausgabe_koeff(k) OP    k;
                 }
 #endif /* BRUCHTRUE */
 #ifdef NUMBERTRUE
-                case SQ_RADICAL: 
+                case SQ_RADICAL:
                 {
                     OP    ptr = S_N_S(k);
                     while(ptr != NULL)
