@@ -2,40 +2,26 @@
 #include "def.h"
 #include "macro.h"
 
-static struct list * calloc_list();
-static INT free_list();
+static struct list * calloc_list(void);
+static INT free_list(struct list *);
 
 static INT mem_counter_list;
-static int list_speicherindex=-1; /* AK 290102 */
-static int list_speichersize=0; /* AK 290102 */
-static struct list **list_speicher=NULL; /* AK 290102 */
+static int list_speicherindex=-1;
+static int list_speichersize=0;
+static struct list **list_speicher=NULL;
 
 
 #ifdef LISTTRUE
-INT list_anfang()
-/* AK 100893 */
+INT list_anfang(void)
     {
     mem_counter_list=0L;
     return OK;
     }
 
-
-
-
-
-INT list_ende()
-/* AK 100893 */
+INT list_ende(void)
     {
     INT erg = OK;
 
-    if (no_banner != TRUE)
-    if (mem_counter_list != 0L)
-        {
-        fprintf(stderr, "mem_counter_list = %" PRIINT "\n" ,mem_counter_list);
-        erg += error("list memory not freed");
-        goto endr_ende;
-        }
-
     if (list_speicher!=NULL)
         {
         INT i;
@@ -43,7 +29,7 @@ INT list_ende()
             SYM_free(list_speicher[i]);
         SYM_free(list_speicher);
         }
- 
+
     list_speicher=NULL;
     list_speicherindex=-1;
     list_speichersize=0;
@@ -52,73 +38,67 @@ INT list_ende()
     }
 
 
-INT empty_listp(a) OP a; 
-/* true falls es sich um eine leere liste handelt
-d.h. self == NULL */
-/* AK 130690 V1.1 */ /* AK 060891 V1.3 */
-{ 
-    if (not listp(a)) 
+/* true falls es sich um eine leere liste handelt d.h. self == NULL */
+INT empty_listp(OP a)
+{
+    if (not listp(a))
         return FALSE;
-    if (S_L_S(a) != NULL) 
+    if (S_L_S(a) != NULL)
         return FALSE;
     return TRUE;
 }
 
 
-
-INT fprint_list(f,list) FILE *f; OP list;
-/* ausgabe eines list-objects
-ausgabe bis einschliesslich next == NULL */
-/* AK 210688 */ /* AK 030789 V1.0 */ /* AK 281289 V1.1 */
-/* AK 060891 V1.3 */
+/* ausgabe eines list-objects ausgabe bis einschliesslich next == NULL */
+INT fprint_list(FILE *f, OP list)
 {
     INT erg = OK;
     OP zeiger = list;
-    OBJECTSELF d; /* AK 141091 */
+    OBJECTSELF d;
 
     COP("fprint_list(1)",f);
-    
-    if (list == NULL) /* AK 141091 */
+
+    if (list == NULL)
         {
         erg +=  NOP("fprint_list");
         goto fple;
         }
-    d = S_O_S(list); /* AK 141091 */
-    if (d.ob_list == NULL) /* AK 141091 */
+    d = S_O_S(list);
+    if (d.ob_list == NULL)
         return error("fprint_list:s_o_s == NULL");
 
     if     ((S_L_S(list) == NULL)&&(S_L_N(list)==NULL))
-    /* AK 030389 */
+
     /* so wird ein list object initialisiert mit b_sn_l(NULL,NULL,obj) */
         {
         fprintf(f,"empty list");
-        if (f == stdout) 
+        if (f == stdout)
             {
             zeilenposition += 10L;
             if (zeilenposition >row_length)
-                { 
-                fprintf(stdout,"\n"); 
-                zeilenposition = 0L; 
+                {
+                fprintf(stdout,"\n");
+                zeilenposition = 0L;
                 }
             }
         }
     else
-        while (zeiger != NULL) 
+        while (zeiger != NULL)
         {
             if (not LISTP(zeiger))
                 {
-                erg += WTO("fprint_list:internal",zeiger);
+                WTO("fprint_list:internal",zeiger);
                 goto fple;
                 }
             erg += fprint(f,S_L_S(zeiger));
             fprintf(f,"  ");
-            if (f == stdout) 
+            if (f == stdout)
             {
                 zeilenposition += 2L;
                 if (zeilenposition >row_length)
-                { 
-                fprintf(stdout,"\n"); 
-                zeilenposition = 0L; 
+                {
+                fprintf(stdout,"\n");
+                zeilenposition = 0L;
                 }
             }
             zeiger=S_L_N(zeiger);
@@ -130,17 +110,15 @@ fple:
 
 
 
-INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
-/* fuegt das object von in die liste nach ein AK 220688 */
-/* AK 030789 V1.0 */ /* AK 201289 V1.1 */
-/* AK 060891 V1.3 */
-/* moegliche faelle:
-    a)zwei listen
-    b)von ist ein scalar und kann in das entsprechende list object umgewandelt werden 
-    c)a ist hashtable und die objecte werden eingefuegt
-    d)a ist monom und wird in das entsprechende LIST object umgewandelt
+/* fuegt das object von in die liste nach ein
+ * moegliche faelle:
+ *  a) zwei listen
+ *  b) von ist ein scalar und kann in das entsprechende list object
+ *     umgewandelt werden
+ *  c) a ist hashtable und die objecte werden eingefuegt
+ *  d) a ist monom und wird in das entsprechende LIST object umgewandelt
 */
-  
+INT insert_list(OP von, OP nach, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     OP c;
     INT erg = OK;
@@ -186,13 +164,10 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
         goto endr_ende;
         }
 
-    
-
-
 
     if (S_O_K(nach) == POLYNOM)
         {
-        if (scalarp(von)) 
+        if (scalarp(von))
             {
             c = CALLOCOBJECT();
             erg += b_skn_po(CALLOCOBJECT(),von,NULL,c);
@@ -208,8 +183,8 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             C_O_K(c,POLYNOM);
             }
         else
-            { 
-            erg += WTT("insert_list(1,2)",von,nach);
+            {
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
@@ -217,10 +192,10 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
 #ifdef SCHURTRUE
     else if (S_O_K(nach) == SCHUR)
         {
-        if (scalarp(von)) 
-            { 
+        if (scalarp(von))
+            {
             c = CALLOCOBJECT();
-            erg += b_scalar_schur(von,c); 
+            erg += b_scalar_schur(von,c);
             }
         else if (S_O_K(von) == MONOM)
             {
@@ -229,8 +204,8 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             erg += b_sn_s(von,NULL,c);
             }
         else
-            { 
-            erg += WTT("insert_list(1,2)",von,nach);
+            {
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
@@ -248,8 +223,8 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             erg += b_scalar_homsym(von,c);
             }
         else
-            {
-            erg += WTT("insert_list(1,2)",von,nach);
+            { 
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
@@ -268,11 +243,11 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             }
         else
             {
-            erg += WTT("insert_list(1,2)",von,nach);
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
- 
+
     else if (S_O_K(nach) == ELMSYM)
         {
         if (S_O_K(von) == MONOM)
@@ -288,12 +263,11 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             }
         else
             {
-            erg += WTT("insert_list(1,2)",von,nach);
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
  
- 
     else if (S_O_K(nach) == POWSYM)
         {
         if (scalarp(von))
@@ -309,17 +283,17 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             }
         else
             {
-            erg += WTT("insert_list(1,2)",von,nach);
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
 
 #endif /* SCHURTRUE */
 
-#ifdef SCHUBERTTRUE 
+#ifdef SCHUBERTTRUE
     else if (S_O_K(nach) == SCHUBERT)
         {
-        if (scalarp(von)) 
+        if (scalarp(von))
             {
             c = CALLOCOBJECT();
             erg += b_skn_sch(CALLOCOBJECT(),von,NULL,c);
@@ -335,8 +309,8 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             C_O_K(c,SCHUBERT);
             }
         else
-            { 
-            erg += WTT("insert_list(1,2)",von,nach);
+            {
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
@@ -350,7 +324,7 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
             C_O_K(c,MONOPOLY);
             }
         else {
-            erg += WTT("insert_list(1,2)",von,nach);
+            WTT("insert_list(1,2)",von,nach);
             goto endr_ende;
             }
         }
@@ -365,10 +339,9 @@ INT insert_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
 
 
 #ifdef LISTTRUE
-INT copy_list(von,nach) OP von, nach;
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */ /* AK 060891 V1.3 */
+INT copy_list(OP von, OP nach)
 {
-    OBJECTSELF d; /* AK 141091 */
+    OBJECTSELF d;
     d= S_O_S(von);
     if (d.ob_list == NULL)
         return error("copy_list:sos = NULL");
@@ -377,9 +350,7 @@ INT copy_list(von,nach) OP von, nach;
 
 
 
-INT lastp_list(list) OP list;
-/* AK 210688 */ /* AK 290689 V1.0 */ /* AK 281289 V1.1 */
-/* AK 060891 V1.3 */
+INT lastp_list(OP list)
 {
     return(S_L_N(list) == NULL);
     /* das letzte element falls das naechste==NULL */
@@ -387,45 +358,26 @@ INT lastp_list(list) OP list;
 
 
 
-static struct list * calloc_list()
-/* AK 210688 */ /* AK 290689 V1.0 */ /* AK 281289 V1.1 */
-/* AK 060891 V1.3 */
+static struct list * calloc_list(void)
 {
-/*
-    struct list *a = 
-        (struct list *) SYM_MALLOC(sizeof(struct list));
-
-    mem_counter_list++;
-    return a;
-*/
     struct list *ergebnis;
- 
     mem_counter_list++;
- 
- 
-    if (list_speicherindex >= 0) /* AK 301001 */
+
+    if (list_speicherindex >= 0)
         return list_speicher[list_speicherindex--];
- 
- 
- 
-    ergebnis = (struct list *)
-        SYM_malloc( sizeof(struct list));
- 
+
+    ergebnis = (struct list *)SYM_malloc( sizeof(struct list));
+
     if (ergebnis == NULL) no_memory();
- 
     return ergebnis;
 
 }
 
-static INT free_list(a) struct list *a;
-/* AK 300197 */
+static INT free_list(struct list *a)
 {
     INT erg = OK;
     COP("free_list(1)",a);
-/*
-    mem_counter_list--;
-    erg += SYM_free(a);
-*/
+
     if (list_speicherindex+1 == list_speichersize) {
        if (list_speichersize == 0) {
            list_speicher = (struct list **) SYM_malloc(100 * sizeof(struct list *));
@@ -445,131 +397,123 @@ static INT free_list(a) struct list *a;
            list_speichersize = 2 * list_speichersize;
            }
        }
- 
+
     mem_counter_list--;
- 
     list_speicher[++list_speicherindex] = a;
- 
     ENDR("free_list");
 }
 
 
-
-
-INT m_sn_l(self,nx,a) OP self,nx,a;
-/* AK 290590 V1.1 */ /* AK 050891 V1.3 */
+INT m_sn_l(OP self, OP nx, OP a)
 {
     OP s = NULL,n = NULL;
     INT erg = OK;
     COP("m_sn_l(3)",a);
-    if (self != NULL) 
-        { 
-        s = CALLOCOBJECT(); 
-        erg += copy(self,s); 
+    if (self != NULL)
+        {
+        s = CALLOCOBJECT();
+        erg += copy(self,s);
         }
-    if (nx != NULL) 
-        { 
-        n = CALLOCOBJECT(); 
-        erg += copy(nx,n); 
+    if (nx != NULL)
+        {
+        n = CALLOCOBJECT();
+        erg += copy(nx,n);
         }
     erg += b_sn_l(s,n,a);
     ENDR("m_sn_l");
 }
 
 
-INT b_sn_l(self,nx,a) OP self,nx,a;
-/* build_self next_list AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+/* build_self next_list */
+INT b_sn_l(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_l",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(LIST,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(LIST,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_l");
 }
 
-INT b_sn_e(self,nx,a) OP self,nx,a;
-/* build_self next_elmsym AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+
+/* build_self next_elmsym */
+INT b_sn_e(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_e",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(ELMSYM,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(ELMSYM,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_e");
 }
 
-INT b_sn_s(self,nx,a) OP self,nx,a;
-/* build_self next_schur AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+
+/* build_self next_schur */
+INT b_sn_s(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_s",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(SCHUR,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(SCHUR,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_s");
 }
 
-INT b_sn_ps(self,nx,a) OP self,nx,a;
-/* build_self next_powsym AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+
+/* build_self next_powsym */
+INT b_sn_ps(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_ps",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(POWSYM,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(POWSYM,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_ps");
 }
 
-INT b_sn_h(self,nx,a) OP self,nx,a;
-/* build_self next_homsym AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+/* build_self next_homsym */
+INT b_sn_h(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_h",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(HOMSYM,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(HOMSYM,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_h");
 }
 
-INT b_sn_mon(self,nx,a) OP self,nx,a;
-/* build_self next_monomial AK 210688 */
-/* AK 290689 V1.0 */ /* AK 281289 V1.1 */  /* AK 050891 V1.3 */
+/* build_self next_monomial */
+INT b_sn_mon(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
 
     COP("b_sn_mon",a);
     d.ob_list = calloc_list();
-    erg += b_ks_o(MONOMIAL,d,a); 
-    C_L_S(a,self); 
+    erg += b_ks_o(MONOMIAL,d,a);
+    C_L_S(a,self);
     C_L_N(a,nx);
     ENDR("b_sn_mon");
 }
 
 
-INT b_sn_po(self,nx,a) OP self,nx,a;
-/* build_self next_polynom AK 230703 */
+/* build_self next_polynom */
+INT b_sn_po(OP self, OP nx, OP a)
 {
     INT erg =OK;
     OBJECTSELF d;
@@ -583,9 +527,7 @@ INT b_sn_po(self,nx,a) OP self,nx,a;
 }
 
 
-
-INT hash_list(list) OP list;
-/* AK 170304 */
+INT hash_list(OP list)
 {
     INT erg = 1257;
     OP z;
@@ -593,21 +535,20 @@ INT hash_list(list) OP list;
     return erg;
 }
 
-INT length_list(list,res) OP list,res;
-/* AK 220688 */ /* AK 290689 V1.0 */ /* AK 281289 V1.1 */
-/* AK 060891 V1.3 */
+
+INT length_list(OP list, OP res)
 {
     OP zeiger = list;
     INT erg = OK;
         CTO(EMPTY,"length_list",res);
     M_I_I(0L,res);
 
-    if (empty_listp(list)) 
+    if (empty_listp(list))
         goto endr_ende;
 
     while (zeiger != NULL) /* abbruch bedingung */
     {
-        INC_INTEGER(res); 
+        INC_INTEGER(res);
         zeiger = S_L_N(zeiger);
     }
 
@@ -615,8 +556,7 @@ INT length_list(list,res) OP list,res;
 }
 
 
-INT filter_list(a,b,tf) OP a,b; INT (*tf)();
-/* AK 020394 */
+INT filter_list(OP a, OP b, INT (*tf)(OP))
 {
     OP z,zb=b;
     INT erg = OK, f = 0;
@@ -640,7 +580,6 @@ INT filter_list(a,b,tf) OP a,b; INT (*tf)();
                 zb = S_L_N(zb);
                 C_O_K(zb,S_O_K(a));
                 }
-            
             }
         z = S_L_N(z);
         }
@@ -648,10 +587,7 @@ INT filter_list(a,b,tf) OP a,b; INT (*tf)();
 
 }
 
-INT transform_apply_list(von,tf) OP von; INT (*tf)();
-/* AK 201289 V1.1 */
-/* AK 060891 V1.3 */
-/* AK 210498 V2.0 */
+INT transform_apply_list(OP von, INT (*tf)(OP))
 {
     OP zeiger = von;
     INT erg = OK;
@@ -662,17 +598,15 @@ INT transform_apply_list(von,tf) OP von; INT (*tf)();
     ENDR("transform_apply_list");
 }
 
-INT transformlist(von,nach,tf) OP von, nach;INT (*tf)();
-/* AK 270688 */ /* AK 030789 V1.0 */ /* AK 010890 V1.1 */ /* AK 060891 V1.3 */
-/* AK 210498 V2.0 */
+INT transformlist(OP von, OP nach, INT (*tf)(OP,OP))
 {
     OP zeiger = von;
     OP nachzeiger = nach;
     OBJECTSELF d;
-    INT erg = OK; /* AK 100893 */
+    INT erg = OK;
     COP("transformlist(3)",tf);
 
-    if (not EMPTYP(nach)) 
+    if (not EMPTYP(nach))
         erg += freeself(nach);
     while (zeiger != NULL)
     {
@@ -682,34 +616,33 @@ INT transformlist(von,nach,tf) OP von, nach;INT (*tf)();
         if (S_L_S(zeiger) != NULL)
             {
             erg += b_sn_l(CALLOCOBJECT(),NULL,nachzeiger);
-            /* AK 100789 b_sn_l() statt init() */
+            /* b_sn_l() statt init() */
             C_O_K(nachzeiger,S_O_K(zeiger));
-            /* AK 107089 fuer faelle wie polynom etc */
+            /* fuer faelle wie polynom etc */
             erg += (*tf)(S_L_S(zeiger),S_L_S(nachzeiger));
             }
-        else 
+        else
             {
             erg += b_sn_l(NULL,NULL,nachzeiger);
             C_O_K(nachzeiger,S_O_K(zeiger));
             }
-        if (not lastp(zeiger)) 
+        if (not lastp(zeiger))
             C_L_N(nachzeiger,CALLOCOBJECT());
-    
+
         zeiger = S_L_N(zeiger);
         nachzeiger = S_L_N(nachzeiger);
     }
     ENDR("transformlist");
 }
 
-INT trans2formlist(ve,vz,nach,tf) OP ve,vz,nach; INT (*tf)();
-/* AK 270688 *//* ve ist konstante , vz ist liste */
-/* AK 030789 V1.0 */ /* AK 211289 V1.1 */ /* AK 060891 V1.3 */
+
+/* ve ist konstante , vz ist liste */
+INT trans2formlist(OP ve, OP vz, OP nach, INT (*tf)(OP,OP,OP))
 {
     OP zeiger = vz;
     OP nachzeiger = nach;
     INT erg = OK;
     COP("trans2formlist(4)",tf);
-    
 
     while (zeiger != NULL)
     {
@@ -717,34 +650,32 @@ INT trans2formlist(ve,vz,nach,tf) OP ve,vz,nach; INT (*tf)();
         C_O_K(nachzeiger,S_O_K(vz));
         erg += (*tf)(ve,S_L_S(zeiger),S_L_S(nachzeiger));
         if (not lastp(zeiger))
-        { 
+        {
             C_L_N(nachzeiger,CALLOCOBJECT());
-            nachzeiger = S_L_N(nachzeiger); 
+            nachzeiger = S_L_N(nachzeiger);
         }
         zeiger = S_L_N(zeiger);
     }
-    ENDR("transformlist");
+    ENDR("trans2formlist");
 }
 #endif /* LISTTRUE */
 
-INT comp_list(a,b) OP a,b;
+INT comp_list(OP a, OP b)
 {
     if ((S_L_S(b) == NULL) && (S_L_S(a) == NULL))
         return 0;
-    else if (S_L_S(a) == NULL) 
+    else if (S_L_S(a) == NULL)
         return -1;
     else if (S_L_S(b) == NULL)
         return 1;
-    else 
+    else
         return comp_list_co(a,b,comp);
 }
 
-INT comp_list_co(a,b,cf) OP a,b; INT (*cf)();
-/* vergleich zweier listen, z.b. 1,1,3  < 1,2,2 z.b. 2,2,3  > 2/3   AK 140788 */
-/* AK 030789 V1.0 */ /* AK 010890 V1.1 */
-/* AK 060891 V1.3 */
-/* self parts are non null */
 
+/* vergleich zweier listen, z.b. 1,1,3  < 1,2,2 z.b. 2,2,3  > 2/3.
+ * self parts are non null */
+INT comp_list_co(OP a, OP b, INT (*cf)(OP,OP))
 {
     INT erg;
     SYMCHECK(S_L_S(a) == NULL,"comp_list_co:self(1) == NULL");
@@ -771,58 +702,49 @@ cla:
 }
 
 #ifdef LISTTRUE
-OP s_l_s(a) OP a;
-/* AK 010890 V1.1 */ /* AK 060891 V1.3 */
-{ 
-    OBJECTSELF c; 
-    if (a == NULL) 
+OP s_l_s(OP a)
+{
+    OBJECTSELF c;
+    if (a == NULL)
         return error("s_l_s: a == NULL"),(OP)NULL;
-    if (not listp(a)) 
+    if (not listp(a))
         return error("s_l_s: a not list"),(OP)NULL;
-    c = s_o_s(a); 
-    return(c.ob_list->l_self); 
+    c = s_o_s(a);
+    return(c.ob_list->l_self);
 }
 
-OP s_l_n(a) OP a;
-/* AK 010890 V1.1 */ /* AK 060891 V1.3 */
-{ 
-    OBJECTSELF c; 
-    if (a == NULL) 
+OP s_l_n(OP a)
+{
+    OBJECTSELF c;
+    if (a == NULL)
         return error("s_l_n: a == NULL"),(OP)NULL;
-    if (not listp(a)) 
+    if (not listp(a))
         return error("s_l_n: a not list"),(OP)NULL;
-    c = s_o_s(a); 
-    return(c.ob_list->l_next); 
+    c = s_o_s(a);
+    return(c.ob_list->l_next);
 }
 
-INT c_l_n(a,b) OP a,b;
-/* AK 010890 V1.1 */ /* AK 060891 V1.3 */
-
-{ 
-    OBJECTSELF c; 
-    c = s_o_s(a); 
-    c.ob_list->l_next = b; 
+INT c_l_n(OP a, OP b)
+{
+    OBJECTSELF c;
+    c = s_o_s(a);
+    c.ob_list->l_next = b;
     return(OK); }
 
-INT c_l_s(a,b) OP a,b;
-/* AK 010890 V1.1 */ /* AK 060891 V1.3 */
-{ 
-    OBJECTSELF c; 
-    c = s_o_s(a); 
-    c.ob_list->l_self = b; 
+INT c_l_s(OP a, OP b)
+{
+    OBJECTSELF c;
+    c = s_o_s(a);
+    c.ob_list->l_self = b;
     return(OK); 
 }
 
 
-
-INT freeself_list(obj) OP obj;
-/* AK 290689 V1.0 */ /* AK 211189 V1.1 */ /* AK 170591 V1.2 */
-/* AK 060891 V1.3 */
+INT freeself_list(OP obj)
 {
     INT erg = OK;
     OP z = obj,za=NULL;
 
-
     z = S_L_N(obj);
     while (z != NULL)
         {
@@ -844,12 +766,8 @@ INT freeself_list(obj) OP obj;
 }
 
 
-
-
-INT scan_list(a,givenkind) OP a; OBJECTKIND givenkind;
 /* genaue art der liste */
-/* AK 210688 */ /* AK 030789 V1.0 */ /* AK 010890 V1.1 */
-/* AK 060891 V1.3 */
+INT scan_list(OP a, OBJECTKIND givenkind)
 {
     char antwort[2];
     INT erg;
@@ -881,7 +799,7 @@ INT scan_list(a,givenkind) OP a; OBJECTKIND givenkind;
     }
 
     printeingabe("one more listelement y/n");
-    skip_comment(); /* AK 210395 */
+    skip_comment();
     scanf("%s",antwort);
     if (antwort[0]  == 'y')
     {
@@ -895,20 +813,20 @@ INT scan_list(a,givenkind) OP a; OBJECTKIND givenkind;
 
 #ifdef VECTORTRUE
 #ifdef LISTTRUE
-INT t_LIST_VECTOR(a,b) OP a,b;
-/* AK 090889 wandelt eine Liste in einen Vektor um */
-/* die daten werden dabei kopiert */
-/* AK 090889 V1.1 */ /* AK 060891 V1.3 */
+
+/* wandelt eine Liste in einen Vektor um die daten werden dabei
+ * kopiert */
+INT t_LIST_VECTOR(OP a, OP b)
 {
     INT i;
     INT erg = OK;
     OP l;
 
-    if (not LISTP(a)) 
+    if (not LISTP(a))
         WTO("t_LIST_VECTOR",a);
     CE2(a,b,t_LIST_VECTOR);
     l = callocobject();
-    erg += length(a,l); 
+    erg += length(a,l);
     erg += b_l_v(l,b); 
     for(i=0L;i<S_I_I(l);i++,a=S_L_N(a))
         erg += copy(S_L_S(a),S_V_I(b,i));
@@ -916,7 +834,6 @@ INT t_LIST_VECTOR(a,b) OP a,b;
 }
 
 #define T_VECTOR_LIST_CO(a,b,t)\
-/* AK 140802 */\
     {\
     INT i;\
     for(i=0L;b != NULL;)\
@@ -929,22 +846,21 @@ INT t_LIST_VECTOR(a,b) OP a,b;
     }  \
     }
 
-INT t_VECTOR_LIST(a,b) OP a,b;
-/* AK 090889 change from vector to list */
-/* the order will be the same, data will be copied */
-/* AK 090889 V1.1 */ /* AK 130591 V1.2 */ /* AK 060891 V1.3 */
+
+/* change from vector to list the order will be the same, data will be
+ * copied */
+INT t_VECTOR_LIST(OP a, OP b)
 {
     INT i,erg=OK;
 
-    if (not VECTORP(a)) 
+    if (not VECTORP(a))
         WTO("t_VECTOR_LIST",a);
     CE2(a,b,t_VECTOR_LIST);
     T_VECTOR_LIST_CO(a,b,LIST);
     ENDR("t_VECTOR_LIST");
 }
 
-INT t_VECTOR_POLYNOM(a,b) OP a,b;
-/* AK 140802 */
+INT t_VECTOR_POLYNOM(OP a, OP b)
 {
     INT erg = OK;
     CTO(VECTOR,"t_VECTOR_POLYNOM(1)",a);
@@ -956,8 +872,7 @@ INT t_VECTOR_POLYNOM(a,b) OP a,b;
 #endif /* VECTORTRUE */
 
 
-INT test_list() 
-/* AK 010890 V1.1 */ /* AK 060891 V1.3 */
+INT test_list(void)
 {
     OP a= callocobject();
     OP b= callocobject();
@@ -976,17 +891,15 @@ INT test_list()
 
 
 #ifdef LISTTRUE
-INT tex_list(list) OP list;
+
 /* zur ausgabe einer liste */
-/* AK 210688 */ /* AK 290689 V1.0 */ /* AK 191289 V1.1 */
-/* AK 070291 V1.2 texout instead of stdout for output */
-/* AK 060891 V1.3 */
+INT tex_list(OP list)
 {
     OP zeiger = list;
     while (zeiger != NULL) /* abbruch bedingung */
     {
         tex(S_L_S(zeiger));
-        fprintf(texout,"\\ "); 
+        fprintf(texout,"\\ ");
         texposition += 3L;
         zeiger = S_L_N(zeiger);
     }
@@ -995,17 +908,14 @@ INT tex_list(list) OP list;
 #endif /* LISTTRUE */
 
 
-INT insert_list_list_2(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
-/* for compability */
+/* for compatibility */
+INT insert_list_list_2(OP von, OP nach, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     return insert_list_list(von,nach,eh,cf);
 }
 
-INT insert_list_list(von,nach,eh,cf) OP von,nach; INT (*eh)(), (*cf)();
-/* programmiert nach
-christopher J. van Wyk : Data  structures and c programs */
-/* AK 201289 V1.1 */ /* AK 130591 V1.2 */
-/* AK 060891 V1.3 */
+/* programmiert nach christopher J. van Wyk : Data  structures and c programs */
+INT insert_list_list(OP von, OP nach, INT (*eh)(OP,OP), INT (*cf)(OP,OP))
 {
     struct object dummy;
     struct list dummy_list;
@@ -1015,25 +925,22 @@ christopher J. van Wyk : Data  structures and c programs */
     OBJECTKIND kind=S_O_K(von);
     OP nn,altnext;
 
-
-    
     if (nach == NULL) {
         error("insert_list_list:nach == NULL");
         /* darf nicht vorkommen, nach muss initialisiert sein */
         goto ende;
     }
 
-    if (EMPTYP(nach)) 
+    if (EMPTYP(nach))
         init(kind,nach);
 
-
     if (S_L_S(nach) == NULL)
     {
-        C_L_S(nach,S_L_S(von)); 
+        C_L_S(nach,S_L_S(von));
         C_L_N(nach,S_L_N(von));
-        C_L_S(von,NULL); /* AK 300197 */
-        C_L_N(von,NULL); /* AK 300197 */
-        FREEALL(von); /* AK 300197 */
+        C_L_S(von,NULL);
+        C_L_N(von,NULL);
+        FREEALL(von);
         goto ende;
     }
 
@@ -1062,7 +969,7 @@ christopher J. van Wyk : Data  structures and c programs */
     while((von != NULL) && (nn != NULL))
     {
         res = (* cf)(S_L_S(von),S_L_S(nn));
-        if (res < 0L) { 
+        if (res < 0L) {
             C_L_N(p,von);
             von = S_L_N(von);
             p = S_L_N(p);
@@ -1074,7 +981,7 @@ christopher J. van Wyk : Data  structures and c programs */
         }
         else {
             if (eh == NULL);
-            else if (eh == add_koeff) /* AK 011101 */
+            else if (eh == add_koeff)
                 {
                 ADD_KOEFF(S_L_S(von),S_L_S(nn));
                 }
@@ -1088,32 +995,32 @@ christopher J. van Wyk : Data  structures and c programs */
             else {
                 FREEALL(S_L_S(nn));
                 altnext=S_L_N(nn);
-                C_L_N(nn,NULL); /* AK 300197 */
-                C_L_S(nn,NULL); /* AK 300197 */
-                FREEALL(nn); /* AK 300197 */
+                C_L_N(nn,NULL);
+                C_L_S(nn,NULL);
+                FREEALL(nn);
                 nn = altnext;
             }
 
             FREEALL(S_L_S(von));
             altnext=S_L_N(von);
-            C_L_N(von,NULL); /* AK 300197 */
-            C_L_S(von,NULL); /* AK 300197 */
-            FREEALL(von); /* AK 300197 */
+            C_L_N(von,NULL);
+            C_L_S(von,NULL);
+            FREEALL(von);
             von = altnext;
         }
     }
 
     C_L_N(p,NULL);
-    if (von == NULL) 
+    if (von == NULL)
         von = nn;
-    if (von != NULL) 
+    if (von != NULL)
         C_L_N(p,von);
-    if (S_L_N(&dummy) == NULL) 
+    if (S_L_N(&dummy) == NULL)
         {
-        C_O_K(nach,EMPTY); 
+        C_O_K(nach,EMPTY);
         init (kind,nach);
         }
-    else     { 
+    else     {
         *nach = *(S_L_N(&dummy));
         C_O_K(S_L_N(&dummy),EMPTY);
         FREEALL(S_L_N(&dummy));
@@ -1123,12 +1030,11 @@ ende:
 }
 
 #ifdef LISTTRUE
-INT objectwrite_list(f,a) FILE *f; OP a;
-/* AK 210690 V1.1 */ /* AK 100591 V1.2 */
-/* AK 060891 V1.3 */
+INT objectwrite_list(FILE *f, OP a)
+
 {
     fprintf(f, "%" PRIINT " " , (INT)S_O_K(a));
-    if (S_L_S(a) == NULL) /* 100591 */
+    if (S_L_S(a) == NULL)
         fprintf(f,"%ld\n",0L);
     else    {
         fprintf(f,"%ld\n",1L);
@@ -1146,9 +1052,7 @@ INT objectwrite_list(f,a) FILE *f; OP a;
 }
 
 
-INT objectread_list(f,a) FILE *f; OP a;
-/* AK 210690 V1.1 */ /* AK 100591 V1.2 */
-/* AK 060891 V1.3 */
+INT objectread_list(FILE *f, OP a)
 {
     INT i;
     fscanf(f, "%" SCNINT ,&i);
@@ -1167,24 +1071,23 @@ INT objectread_list(f,a) FILE *f; OP a;
     else if (i == 1L)
         {
         C_L_N(a,callocobject());
-        return objectread(f,S_L_N(a)); 
+        return objectread(f,S_L_N(a));
         }
     else
         return error("objectread_list: wrong format (2) ");
 }
 
 
-INT filter_apply_list(a,tf) OP a; INT (*tf)();
-/* AK 020394 */
-/* if tf return true the elements stays in the list */
-/* error beseitigt am 110397 */
-/* tf takes a list element as input */
+/* if tf return true the elements stays in the list error beseitigt
+ * am. tf takes a list element as input
+ */
+INT filter_apply_list(OP a, INT (*tf)(OP))
 {
     OP z,zb,vorg=NULL;
     INT erg = OK;
     OBJECTKIND typ = S_O_K(a);
     z = a;
-    if (S_L_S(a) == NULL) 
+    if (S_L_S(a) == NULL)
         goto endr_ende;
     while (z != NULL)
         {
@@ -1206,9 +1109,9 @@ INT filter_apply_list(a,tf) OP a; INT (*tf)();
                 vorg = a;
                 }
             else
-                vorg = zb; 
+                vorg = zb;
             }
-        else    
+        else
             /* remove from the list */
             {
             zb = z;
@@ -1220,7 +1123,7 @@ INT filter_apply_list(a,tf) OP a; INT (*tf)();
         } /* end while z!=NULL */
     if (vorg == NULL)
         erg += init(typ,a);
-        
+
     ENDR("filter_apply_list");
 }
 #endif /* LISTTRUE */
