@@ -1,32 +1,27 @@
-/*mod_dg_sbd.c
-  berechnet eine darstellende matrix,
-  nach basisaenderung der bideterminanten
-  modular
-  um die bliche bezeichnung zu bekommen, wird die
-  conjugierte partition genommen
-  */
-/* es wird nur die erste standard bi determinant ausgerechnet, die brigen mit operate
-   perm 
-   dabei wird die permutation genommen die von SYT 0 zu SYT i fhrt */
-
-/* es wird keine ff arithmetik verwendet */
-
+/*
+ * berechnet eine darstellende matrix, nach basisaenderung der
+ * bideterminanten modular um die bliche bezeichnung zu bekommen,
+ * wird die conjugierte partition genommen.  es wird nur die erste
+ * standard bi determinant ausgerechnet, die brigen mit operate perm
+ * dabei wird die permutation genommen die von SYT 0 zu SYT i fhrt.
+ * es wird keine ff arithmetik verwendet
+ */
 #include "def.h"
 #include "macro.h"
 
 /* standard bideterminanten */
 /* polynom indiziert mit integer matrix */
-/* */
 /* basis fuer specht modul mit sbd */
 
 static OP zero_one_matrices = NULL;
 static INT init_zero_one(OP part);
 static INT close_zero_one();
 
-static INT operate_perm_spaltenmatrix_new(a,b,c) OP a,b,c;
-/* vertausch spalten gemaess der permutation */
-/* spalte 0 nur wenn permutation auch 0 enthaelt */
-/* AK 080802 */
+
+/* vertausch spalten gemaess der permutation, spalte 0 nur wenn
+ * permutation auch 0 enthaelt
+ */
+static INT operate_perm_spaltenmatrix_new(OP a, OP b, OP c)
 {
     INT erg = OK;
     INT i,j;
@@ -42,38 +37,20 @@ static INT operate_perm_spaltenmatrix_new(a,b,c) OP a,b,c;
 
     CTTO(INTEGERMATRIX,MATRIX,"operate_perm_spaltenmatrix(e-3)",c);
     ENDR("operate_perm_spaltenmatrix");
-}                                                                                             
-
-static INT println_bid(a) OP a;
-{
-    OP z;
-    INT i,j;
-    if (NULLP(a)) { printf("empty bideterminant"); }
-    else{
-        FORALL(z,a,{
-           print(S_MO_K(z)); printf(" [");
-           for (i=1;i<S_M_HI(S_MO_S(z));i++) 
-           for (j=1;j<S_M_LI(S_MO_S(z));j++) 
-                print(S_M_IJ(S_MO_S(z),i,j));
-           printf("] ");
-        });
-    }
-    
-    printf("\n");zeilenposition=0;
 }
 
-static INT make_basis(e,prim,v) OP e; OP prim;
-/* the matrix e will be transformed into a basis mod prim using
-   row transformations 
-   the number of rows (= dimension ) may be smaller  at the end
+
+/* the matrix e will be transformed into a basis mod prim using row
+ * transformations the number of rows (= dimension ) may be smaller at
+ * the end vector mit zeilen nummern der original matrix die in die
+ * basis gehen
 */
-    OP v; /* vector mit zeilen nummern der original matrix
-             die in die basis gehen   AK 210703 */
+static INT make_basis(OP e, OP prim, OP v)
 {
     INT i,j,k,l;
     INT erg = OK;
     OP d,c;
-    
+
     CTO(MATRIX,"make_basis(1)",e);
     d = CALLOCOBJECT();
     c = CALLOCOBJECT();
@@ -85,30 +62,29 @@ static INT make_basis(e,prim,v) OP e; OP prim;
     /* v initialized to 0.1.2.3.... */
     }
 
-    if (S_M_HI(e) < 2) 
+    if (S_M_HI(e) < 2)
         {
         if (NULLP(e)) k=0; else k=1;
         goto a3;
         }
-    
-    
+
     j=0; k = 0;
 a2:
-    if (j == S_M_LI(e)) goto a3; 
+    if (j == S_M_LI(e)) goto a3;
     for (i=k;i<S_M_HI(e);i++)
         if (not NULLP(S_M_IJ(e,i,j))) break;
     if (i== S_M_HI(e))  /* in spalte j kein eintrag != 0 */
         { j++; goto a2; }
     change_row_ij(e,i,k);
     if (v!=NULL) SWAP(S_V_I(v,i),S_V_I(v,k)); /*AK 210703*/
-    
+
     /* am platz k,j ist jetzt ein eintrag != 0 */
     /* in den zeilen drunter eine null an den platz in der spalte j */
-    
+
     for (i=k+1;i<S_M_HI(e); i++)
         {
         if (NULLP(S_M_IJ(e,i,j))) continue;
-    
+
 nochmal:
         for (l=j;l<S_M_LI(e);l++)
             {
@@ -117,7 +93,7 @@ nochmal:
             }
         if (! NULLP(S_M_IJ(e,i,j))) goto nochmal;
         }
-    
+
     k++; j++; goto a2;
 a3:
     /* k ist laenge der basis = dimension */
@@ -126,20 +102,20 @@ a3:
         FREESELF(S_M_IJ(e,i,j));
     M_I_I(k,S_M_H(e));
     if (v!=NULL) M_I_I(k,S_V_L(v)); /*AK 210703*/
-    
+
     FREEALL(c);
     FREEALL(d);
     ENDR("make_basis");
 }
 
-static INT decompose_matrix(in,basis,mat,prim) OP in,basis,mat;OP prim;
+
+static INT decompose_matrix(OP in, OP basis, OP mat, OP prim)
 {
     INT erg =  OK,i,j,k;
     CTO(VECTOR,"decompose_matrix(1)",in);
     CTO(MATRIX,"decompose_matrix(2)",basis);
-    
-    /* basis ist obere dreiecksmatrix */
 
+    /* basis ist obere dreiecksmatrix */
     m_ilih_nm(S_V_LI(in),S_V_LI(in),mat);
     for (i=0;i<S_V_LI(in);i++)
         {
@@ -152,23 +128,23 @@ static INT decompose_matrix(in,basis,mat,prim) OP in,basis,mat;OP prim;
 aa:
         for (;j<S_V_LI(p);j++)
             if (not NULLP(S_V_I(p,j))) break;
-        if (j==S_V_LI(p)) goto ee; 
-    
-    /* an der stelle j ist ein eintrag != null, es muss ein basis 
-       element k geben was als ersten eintrag != 0 was an der stelle j hat */
+        if (j==S_V_LI(p)) goto ee;
+
+	/* an der stelle j ist ein eintrag != null, es muss ein basis
+	 * element k geben was als ersten eintrag != 0 was an der stelle j
+	 * hat */
 
 bb:
         if (k == S_M_HI(basis))  error("decompose_matrix: could not decompose");
         if (NULLP(S_M_IJ(basis,k,j))) { k++; goto bb; }
-        for (l=0;l<j;l++) 
-            if (not NULLP(S_M_IJ(basis,k,l))) { k++; goto bb; } 
-    
-    /* der basis vektor k geht ins ergenis */
+        for (l=0;l<j;l++)
+            if (not NULLP(S_M_IJ(basis,k,l))) { k++; goto bb; }
 
+	/* der basis vektor k geht ins ergenis */
         t = CALLOCOBJECT();
         ko = CALLOCOBJECT();
         select_row(basis,k,t);
-    
+
         M_I_I(1,ko);
         while ( (S_I_I(ko) * S_M_IJI(basis,k,j) )%S_I_I(prim) != S_V_II(p,j))
             INC_INTEGER(ko);
@@ -194,16 +170,15 @@ ee:
 }
 
 
-
-static INT get_dg(b,e,c,prim) OP b,e,c;OP prim;
-/* berechnet die modulare darstellung */
-/* dabei ist b die permutation, e die basis des moduls
-   c wird matrix */
+/* berechnet die modulare darstellung. dabei ist b die permutation, e
+ * die basis des moduls c wird matrix.
+ */
+static INT get_dg(OP b, OP e, OP c, OP prim)
 {
     OP d,a;
     INT erg = OK;
     INT i,j;
-    
+
     if (S_M_HI(e) == 0) {
         /* z.b. part = 11....111 */
         m_ilih_m(0,0,c);
@@ -218,7 +193,7 @@ static INT get_dg(b,e,c,prim) OP b,e,c;OP prim;
     m_il_v(S_M_LI(e),a);
     for (j=0;j<S_V_LI(a);j++)
          b_sk_mo(CALLOCOBJECT(),CALLOCOBJECT(),S_V_I(a,j));
-     
+
     for (i=0;i<S_V_LI(d);i++)
         {
         for (j=0;j<S_V_LI(a);j++)
@@ -231,23 +206,23 @@ static INT get_dg(b,e,c,prim) OP b,e,c;OP prim;
         for (j=0;j<S_V_LI(a);j++)
             COPY(S_MO_K(S_V_I(a,j)), S_V_I(S_V_I(d,i),j));
         }
- 
-/* im vector d stehen die bideterminanten nach anwendung der permutation
-   diese jetzt zerlegen in der basis in e
-   dies ergibt die zeilen der darstellenden matrix
-*/
+
+    /* im vector d stehen die bideterminanten nach anwendung der
+     * permutation diese jetzt zerlegen in der basis in e dies ergibt
+     * die zeilen der darstellenden matrix
+     */
 
     FREEALL(a);
-    decompose_matrix(d,e,c,prim);   
+    decompose_matrix(d,e,c,prim);
     FREEALL(d);
     ENDR("get_dg");
 }
 
-static INT specht_basis_mod_p(e,p) OP e,p;
-/* die basis des specht moduls wird mod p gerechnet,
-   die koeff sind nun FF 
 
-   und es ist normaleweise keine basis mehr */
+/* die basis des specht moduls wird mod p gerechnet,
+ * die koeff sind nun FF. und es ist normaleweise keine basis mehr.
+ */
+static INT specht_basis_mod_p(OP e, OP p)
 {
     INT i,j,erg =OK;
 
@@ -256,17 +231,18 @@ static INT specht_basis_mod_p(e,p) OP e,p;
         {
         INT eintrag ;
         eintrag = S_M_IJI(e,i,j) % S_I_I(p);
-        if (eintrag < 0) eintrag += S_I_I(p); 
+        if (eintrag < 0) eintrag += S_I_I(p);
         M_I_I(eintrag, S_M_IJ(e,i,j));
         }
     ENDR("specht_basis_mod_p");
 }
 
-static INT get_specht_basis_of_sbd(a,e)  OP a,e;
-/* basis des specht moduls aus 
-   P-symmetrizied sbd */
-/* koeff sind INTEGER, e is matrix zeilenweise sortiert wie in zero_one_matrices */
-/* input is partition */
+
+/* basis des specht moduls aus P-symmetrizied sbd. koeff sind INTEGER,
+ * e is matrix zeilenweise sortiert wie in zero_one_matrices. input
+ * is partition.
+ */
+static INT get_specht_basis_of_sbd(OP a, OP e)
 {
     OP bb,cc,aa,z,dd;
     OP c,d;
@@ -274,17 +250,17 @@ static INT get_specht_basis_of_sbd(a,e)  OP a,e;
     INT erg = OK;
     CTO(PARTITION,"get_specht_basis_of_sbd(1)",a);
     CALLOCOBJECT5(cc,c,d,bb,dd);
-    
+
     makevectorofSYT(a,cc);
     m_lh_nm(S_V_L(zero_one_matrices),S_V_L(cc),e);
-     
+
     m_u_t(a,bb);
     for (i=0;i<S_PA_LI(a);i++)
     for (j=0;j<S_PA_II(a,S_PA_LI(a)-1-i);j++)
         M_I_I(i+1,S_T_IJ(bb,i,j));
-     
+
     P_symmetrized_bideterminant(bb,S_V_I(cc,0),d);
-    
+
     k=0;
     FORALL(z,d,{
     m_ilih_m(S_M_LI(S_MO_S(z))-1,S_M_HI(S_MO_S(z))-1,dd);
@@ -296,10 +272,9 @@ static INT get_specht_basis_of_sbd(a,e)  OP a,e;
     while (not EQ(S_MO_S(z),S_V_I(zero_one_matrices,k))) k++;
     COPY(S_MO_K(z),S_M_IJ(e,0,k));
     });
-    
+
     t_LIST_VECTOR(d,d);
-    
-     
+
     copy(d,dd);
     for (i=1;i<S_M_HI(e);i++)
         {
@@ -313,41 +288,38 @@ static INT get_specht_basis_of_sbd(a,e)  OP a,e;
         for (ii=0;ii<S_T_HI(aa);ii++)
         for (j=0;j<=zeilenende(aa,ii);j++)
             M_I_I(S_T_IJI(aaa,ii,j),S_P_I(ddd,S_T_IJI(aa,ii,j)-1));
-     
+
         /* ddd is permutation to go from SYT at place 0 to SYT at place i in vector e */
-        
         for (j=0;j<S_V_LI(d);j++)
             {
             copy(S_MO_K(S_V_I(d,j)), S_MO_K(S_V_I(dd,j)));
             operate_perm_spaltenmatrix_new(ddd,S_MO_S(S_V_I(d,j)),S_MO_S(S_V_I(dd,j)));
             }
-     
+
         freeall(ddd);
         qsort_vector(dd);
-    
+
         k=0;
         for (j=0;j<S_V_LI(dd);j++)
             {
             while (not EQ(S_MO_S(S_V_I(dd,j)),S_V_I(zero_one_matrices,k))) k++;
             COPY(S_MO_K(S_V_I(dd,j)),S_M_IJ(e,i,k));
-            }                            
+            }
         }
     FREEALL5(cc,bb,dd,c,d);
     ENDR("get_specht_basis_of_sbd");
 }
 
-INT basis_mod_dg(prim,part,e) OP part,prim,e;
-/* computes the basis e of the modular irreducible sn-module labeled by part */
-/* AK 270503 */
-/* AK 070704 V3.0 */
+
+/* computes the basis e of the modular irreducible sn-module labeled
+ * by part */
+INT basis_mod_dg(OP prim, OP part, OP e)
 {
     INT erg = OK;
     CTO(INTEGER,"basis_mod_dg(1)",prim);
     CTO(PARTITION,"basis_mod_dg(2)",part);
     CE3(prim,part,e,basis_mod_dg);
 
-
-
     {
     OP a;
     init_zero_one(part);
@@ -356,19 +328,17 @@ INT basis_mod_dg(prim,part,e) OP part,prim,e;
     get_specht_basis_of_sbd(a,e);
     FREEALL(a);
 
-
-    specht_basis_mod_p(e,prim); /*entires are now mod p*/
+    specht_basis_mod_p(e,prim); /*entries are now mod p*/
     make_basis(e,prim,NULL);
     }
-    
+
     ENDR("basis_mod_dg");
 }
 
 
-INT kk_280604 (part,e,prim) OP part,e,prim;
-/* computes the matrix e
-   whose rows are basis of the irreducible sn-module labeled by part */
-/* AK 270604 */
+/* computes the matrix e whose rows are basis of the irreducible
+ * sn-module labeled by part */
+INT kk_280604(OP part, OP e, OP prim)
 {
     INT i,j,erg =OK;
     OP a,temp;
@@ -387,11 +357,13 @@ INT kk_280604 (part,e,prim) OP part,e,prim;
         }
         freeall(a);
     close_zero_one();
+    ENDR("kk_280604");
 }
 
 
+/* qsort comparison function */
 static INT ss; /*size*/
-static INT mycmp(a,b) OP a,b;
+static int mycmp(OP a, OP b)
 {
 INT i;
 for (i=0;i<ss;i++) if (S_I_I(a+i) < S_I_I(b+i)) return 1;
@@ -400,10 +372,10 @@ for (i=0;i<ss;i++) if (S_I_I(a+i) < S_I_I(b+i)) return 1;
 return 0;
 }
 
-static INT get_symm_specht_poly(a,i,c) OP a,c; INT i;
-/* AK 210703 */
-/* ite reihe von a ist symmetrized specht polynom 
-   write it as object of type POLYNOM */
+
+/* ite reihe von a ist symmetrized specht polynom write it as object
+ * of type POLYNOM */
+static INT get_symm_specht_poly(OP a, INT i, OP c)
 {
     INT j,erg = OK;
     init(HASHTABLE,c);
@@ -430,9 +402,11 @@ static INT get_symm_specht_poly(a,i,c) OP a,c; INT i;
     ENDR("get_symm_specht_poly");
 }
 
-static INT init_zero_one(part) OP part;
-/* this vector of zero one matrices are the possible exponent in the 
-   sbd */
+
+/* this vector of zero one matrices are the possible exponent in the
+ * sbd
+ */
+static INT init_zero_one(OP part)
 {
     OP a,b,c,d;INT erg=OK;
     zero_one_matrices=callocobject(); /*global*/
@@ -446,18 +420,21 @@ static INT init_zero_one(part) OP part;
     qsort_vector(zero_one_matrices);
     ENDR("internal:init_zero_one");
 }
-static INT close_zero_one()
+
+
+static INT close_zero_one(void)
 {
     INT erg =OK;
     erg+=freeall(zero_one_matrices); zero_one_matrices=NULL;
     ENDR("internal:close_zero_one");
 }
-INT makevectorofsymspecht_poly(part,v) OP part,v;
-/* AK 300703 */
-/* produces a vector of symmetrized specht polynomials
-   these are basis of the ordinary specht module
-   and generator of the modular specht module
-*/
+
+
+/* produces a vector of symmetrized specht polynomials. these are basis
+ * of the ordinary specht module and generator of the modular specht
+ * module.
+ */
+INT makevectorofsymspecht_poly(OP part, OP v)
 {
     INT erg = OK;
     CTO(PARTITION,"makevectorofsymspecht_poly(1)",part);
@@ -466,23 +443,24 @@ INT makevectorofsymspecht_poly(part,v) OP part,v;
     init_zero_one(part);
     CALLOCOBJECT2(a,e);
     conjugate_partition(part,a);
-    get_specht_basis_of_sbd(a,e); 
+    get_specht_basis_of_sbd(a,e);
     m_l_v(S_M_H(e),v);
     for (i=0;i<S_M_HI(e);i++)
         get_symm_specht_poly(e,i,S_V_I(v,i));
-    
+
     FREEALL2(a,e);
     close_zero_one();
     }
     ENDR("makevectorofsymspecht_poly");
 }
 
-INT code_mod_into_ord(prim,part,f) OP prim,part,f;
-/* AK 210703 embedding of the mod into ord spect module
-      compute mod basis, take the original symmetrized specht 
-      polynomials which become bases, write them in the basis
-      of the non symmetrized specht polynomials
-      read it as coeff in N, get code */
+
+/* embedding of the mod into ord spect module compute mod basis, take
+ * the original symmetrized specht polynomials which become bases,
+ * write them in the basis of the non symmetrized specht polynomials
+ * read it as coeff in N, get code
+ */
+INT code_mod_into_ord(OP prim, OP part, OP f)
 {
     INT erg = OK,i,j,k;
     OP a,b,c,d,e,v;
@@ -497,7 +475,7 @@ INT code_mod_into_ord(prim,part,f) OP prim,part,f;
     get_specht_basis_of_sbd(a,e);
     copy(e,a);
 
-    specht_basis_mod_p(e,prim); /*entires are mod p*/
+    specht_basis_mod_p(e,prim); /*entries are mod p*/
     make_basis(e,prim,v);  /* v is vector 1=in basis of mod */
 
     CALLOCOBJECT2(c,d);
@@ -505,8 +483,8 @@ INT code_mod_into_ord(prim,part,f) OP prim,part,f;
     m_ilih_nm(S_M_HI(a),S_V_LI(v),f);
     conjugate(part,e);
     makevectorofspecht_poly(e,d);
-    /* compute the specht polynomials according to the rows 
-       indexed in v */
+    /* compute the specht polynomials according to the rows
+     * indexed in v */
     for (i=0;i<S_M_HI(f);i++)
         {
         INT j;
@@ -529,16 +507,17 @@ aaa:
     FREEALL4(e,d,c,v);
     erg+=freeall(zero_one_matrices); zero_one_matrices=NULL;
     ENDR("code_mod_into_ord");
-} 
+}
 
-INT code_mod_into_ord2(prim,part,f) OP prim,part,f;
-/* AK 300703 embedding of the mod into ord specht module
-      compute mod basis, take this basis
-       write the in basis
-      of the non symmetrized specht polynomials
-      read it as coeff in N, get code */
-/* as we take the same subspace the minimal distance in code_mod_into_ord2
-and code_mod_into_ord are equal !! */
+
+/* Embedding of the mod into ord specht module compute mod basis, take
+ * this basis write the in basis of the non symmetrized specht
+ * polynomials read it as coeff in N, get code.
+ *
+ * As we take the same subspace the minimal distance in
+ * code_mod_into_ord2 and code_mod_into_ord are equal !!
+ */
+INT code_mod_into_ord2(OP prim, OP part, OP f)
 {
     INT erg = OK,i,j,k;
     OP a,b,c,d,e,v;
@@ -553,14 +532,14 @@ and code_mod_into_ord are equal !! */
     get_specht_basis_of_sbd(a,e);
     copy(e,a);
 
-    specht_basis_mod_p(e,prim); /*entires are mod p*/
+    specht_basis_mod_p(e,prim); /*entries are mod p*/
     make_basis(e,prim,v);  /* v is vector 1=in basis of mod*/
     CALLOCOBJECT2(c,d);
 
     m_ilih_nm(S_M_HI(a),S_V_LI(v),f);conjugate(part,d);
     makevectorofspecht_poly(d,d);
-    /* compute the specht polynomials according to the rows
-       in e */
+    /* compute the Specht polynomials according to the rows
+     * in e */
     for (i=0;i<S_M_HI(f);i++)
         {
         INT j;
@@ -586,12 +565,11 @@ aaa:
 }
 
 
-INT embedding_mod_into_ord(prim,part,f) OP prim,part,f;
-/* for the embedding of modular irreducible 
-   into irreducible of ordinary */
-/* the modular symmetrized specht polynomials are written in the basis */
-/* of the symmetrized specht polynomials */
-/* AK 170703 for arbitrary prime */
+/* for the embedding of modular irreducible into irreducible of
+ * ordinary. the modular symmetrized Specht polynomials are written
+ * in the basis of the symmetrized Specht polynomials.
+ */
+INT embedding_mod_into_ord(OP prim, OP part, OP f)
 {
     INT erg = OK,i,j,k;
     OP a,b,c,d,e;
@@ -602,7 +580,6 @@ INT embedding_mod_into_ord(prim,part,f) OP prim,part,f;
     b = CALLOCOBJECT();
     weight(part,b);
 
-
     a = CALLOCOBJECT();
     conjugate(part,a);
     init_zero_one(part);
@@ -610,8 +587,6 @@ INT embedding_mod_into_ord(prim,part,f) OP prim,part,f;
     get_specht_basis_of_sbd(a,e);
     FREEALL(a);
 
-
-
     specht_basis_mod_p(e,prim);
     FREEALL(zero_one_matrices);
     c = CALLOCOBJECT();
@@ -621,7 +596,10 @@ INT embedding_mod_into_ord(prim,part,f) OP prim,part,f;
 
     /*sortiere e*/
     ss = S_M_HI(e);
-    qsort(S_M_S(e),S_M_HI(e),sizeof(struct object)*S_M_LI(e),mycmp);
+    qsort(S_M_S(e),
+	  S_M_HI(e),
+	  sizeof(struct object)*S_M_LI(e),
+	  (int (*)(const void *, const void *))mycmp);
 
     m_ilih_nm(S_M_HI(e),S_M_HI(c),f);
 
@@ -631,7 +609,6 @@ INT embedding_mod_into_ord(prim,part,f) OP prim,part,f;
     for (j=0;i<S_M_LI(e);j++) if (S_M_IJI(e,i,j) != 0) {M_I_I(j,S_V_I(d,i)); break; }
 
     /* vector mit erster position != 0 */
-
     b = CALLOCOBJECT();
     m_il_v(S_M_LI(c),b);
     for (i=0;i<S_M_HI(f);i++)
@@ -657,7 +634,7 @@ again:
              M_I_I( (S_V_II(b,j)+ko*S_M_IJI(e,k,j))%S_I_I(prim), S_V_I(b,j));
         goto again;
         }
-      
+
     FREEALL(b);
     FREEALL(d);
 
@@ -668,11 +645,10 @@ again:
 }
 
 
-INT mod_dg_sbd(prim,part,perm,mat) 
-   OP prim,part,perm,mat;
-/* AK 020902 
-   computes a modular irreducible representation
-   using standard bideterminants */
+/* computes a modular irreducible representation using standard
+ * bideterminants
+ */
+INT mod_dg_sbd(OP prim, OP part, OP perm, OP mat)
 {
     INT erg = OK;
     OP a,b,c,d,e;
@@ -680,17 +656,17 @@ INT mod_dg_sbd(prim,part,perm,mat)
     CTO(PARTITION,"mod_dg_sbd(2)",part);
     CTO(PERMUTATION,"mod_dg_sbd(3)",perm);
     CE4(prim,part,perm,mat,mod_dg_sbd);
-    
+
     b = CALLOCOBJECT();
-    weight(part,b); 
-    
+    weight(part,b);
+
     if (S_P_LI(perm) != S_I_I(b)) {
         erg += error("mod_dg_sbd: degree perm != weight part");
         FREEALL(b);
         goto endr_ende;
         }
     FREEALL(b);
-    
+
     e = CALLOCOBJECT();
     basis_mod_dg(prim,part,e);
     get_dg(perm,e,mat,prim);
