@@ -1,11 +1,7 @@
-
 #include "def.h"
 #include "macro.h"
 
-INT tse___faktor();
-
-INT mult_schur_elmsym(a,b,c) OP a,b,c;
-/* AK 081001 */
+INT mult_schur_elmsym(OP a, OP b, OP c)
 {
     OP d;
     INT erg = OK;
@@ -19,4 +15,3 @@ INT mult_schur_elmsym(a,b,c) OP a,b,c;
     FREEALL(d);
     ENDR("mult_schur_monomial");
 }
-
