@@ -1,23 +1,12 @@
-
 #include "def.h"
 #include "macro.h"
 
-static INT m_k_to_h_lambda();
+static INT m_k_to_h_lambda(OP, OP, OP);
 
 static OP mh_speicher = NULL;
-INT mult_hashtable_hashtable_faktor();
-INT mult_hashtable_hashtable();
-INT tmh___faktor();
-INT teh_integer__faktor();
-INT add_apply_hashtable();
-INT monomial_recursion();
-INT splitpart();
-INT mmm_partition_partition_();
-INT binom_small();
 
 
-
-INT tmh_ende()
+INT tmh_ende(void)
 {
     INT erg = OK;
     if (mh_speicher != NULL)
@@ -28,18 +17,18 @@ INT tmh_ende()
     ENDR("tmh_ende");
 }
 
-INT t_MONOMIAL_HOMSYM(a,b) OP a,b;
-/* AK 301001 */
+
+INT t_MONOMIAL_HOMSYM(OP a, OP b)
 {
     INT erg = OK;
     INT t=0;
     INT i,w=0;
     OP z=NULL;
-    CTTTTO(HASHTABLE,INTEGER,MONOMIAL,PARTITION,"t_MONOMIAL_HOMSYM(1)",a); 
+    CTTTTO(HASHTABLE,INTEGER,MONOMIAL,PARTITION,"t_MONOMIAL_HOMSYM(1)",a);
     TCE2(a,b,t_MONOMIAL_HOMSYM,HOMSYM);
 
     /* check for the size of the result */
-    if (S_O_K(a) == INTEGER) 
+    if (S_O_K(a) == INTEGER)
         {
         w = numberofpart_i(a);
         goto ww;
@@ -71,7 +60,7 @@ INT t_MONOMIAL_HOMSYM(a,b) OP a,b;
         }
     else {
         FORALL(z,a,{ goto fff; } );
-        
+
 fff:
         z = S_MO_S(z);
         for (i=0;i<S_PA_LI(z);i++) w += S_PA_II(z,i);
@@ -79,8 +68,8 @@ fff:
         w = numberofpart_i(z);
         FREEALL(z);
         }
-    /* w ist die geschaetzte ergebnis groesse, ist korrekt fuer 
-       homogenes m */
+        /* w ist die geschaetzte ergebnis groesse, ist korrekt fuer
+         * homogenes m */
 ww:
     if (a == b) {
         OP c;
@@ -115,14 +104,12 @@ ww:
         }
     if (t == 1)
         erg += t_HASHTABLE_HOMSYM(b,b);
-  
 
     ENDR("t_MONOMIAL_HOMSYM");
 }
 
-INT tmh_integer__faktor();
-OP find_tmh_integer(a) OP a;
-/* AK 300102 */
+
+OP find_tmh_integer(OP a)
 {
     INT erg = OK;
     CTO(INTEGER,"find_tmh_integer(1)",a);
@@ -136,19 +123,19 @@ OP find_tmh_integer(a) OP a;
        )
            {
            OP c;
-           NEW_HASHTABLE(c);  
+           NEW_HASHTABLE(c);
            tmh_integer__faktor(a,c,cons_eins);
            FREEALL(c);
            }
 
-
     return S_V_I(mh_speicher,S_I_I(a));
-       
+
     ENDO("find_tmh_integer");
 }
 
-INT tmh_integer__faktor(a,b,faktor) OP a,b;OP faktor;
+
 /* called from tme_integer__faktor */
+INT tmh_integer__faktor(OP a, OP b, OP faktor)
 {
     INT erg = OK;
     OP p,c;
@@ -161,9 +148,9 @@ INT tmh_integer__faktor(a,b,faktor) OP a,b;OP faktor;
                                m_il_v(20,mh_speicher); }
 
     if (S_I_I(a) >= S_V_LI(mh_speicher) ) {
-        erg += inc_vector_co(mh_speicher, S_I_I(a)+5- S_V_LI(mh_speicher)); 
+        erg += inc_vector_co(mh_speicher, S_I_I(a)+5- S_V_LI(mh_speicher));
         }
- 
+
 again:
     if (not EMPTYP(S_V_I(mh_speicher,S_I_I(a)) ) )
         {
@@ -180,8 +167,7 @@ again:
 
     SYMCHECK(not EMPTYP(S_V_I(mh_speicher,S_I_I(a))),"tmh_integer__faktor:i1");
     init_size_hashtable(S_V_I(mh_speicher,S_I_I(a)), 2 * numberofpart_i(a)+1);
-    /* erg += init(HASHTABLE,S_V_I(mh_speicher,S_I_I(a))); */
-    
+
     if (S_I_I(a) == 0) {
         OP m;
         m = CALLOCOBJECT();
@@ -196,7 +182,6 @@ again:
         goto again;
         }
 
-   
     p  = CALLOCOBJECT();
     erg += first_partition(a,p);
 
@@ -230,13 +215,13 @@ again:
 
     FREEALL(c);
     FREEALL(p);
- 
+
 eee:
     ENDR("tmh_integer__faktor");
 }
 
-INT mhh_hashtable_hashtable_();
-INT tmh_partition__faktor(a,b,faktor) OP a,b;OP faktor;
+
+INT tmh_partition__faktor(OP a, OP b, OP faktor)
 {
     INT erg = OK;
     CTO(PARTITION,"tmh_partition__faktor(1)",a);
@@ -257,8 +242,8 @@ INT tmh_partition__faktor(a,b,faktor) OP a,b;OP faktor;
         erg += tmh_integer__faktor(S_PA_I(a,0),b,faktor);
         goto eee;
         }
-    else if (S_PA_II(a,S_PA_LI(a)-1) == 1) 
-        { /* AK 191001 */
+    else if (S_PA_II(a,S_PA_LI(a)-1) == 1)
+        {
         erg += teh_integer__faktor(S_PA_L(a),b,faktor);
         goto eee;
         }
@@ -274,14 +259,12 @@ eee:
     ENDR("tmh_partition__faktor");
 }
 
-INT monomial_recursion2(a,b,faktor,partf,integerf,elmsymf,multf) OP a,b;OP faktor;
-     INT (*partf)(); INT (*multf)(); INT (*integerf)();
-     INT (*elmsymf)();
+
 /* implementiert die zweite rekursion fuer monomial symmetric functions */
+INT monomial_recursion2(OP a, OP b, OP faktor, INT (*partf)(OP,OP,OP), INT (*integerf)(OP,OP,OP), INT (*elmsymf)(OP,OP,OP), INT (*multf)(OP,OP,OP))
 {
     INT erg = OK;
     OP z,ha,h2,h3;
-    /* static INT level=0; */
     CTTO(HASHTABLE,MONOMIAL,"monomial_recursion2(1)",a);
     CTO(HASHTABLE,"monomial_recursion2(2)",b);
 
@@ -292,7 +275,7 @@ INT monomial_recursion2(a,b,faktor,partf,integerf,elmsymf,multf) OP a,b;OP fakto
     else
         t_MONOMIAL_HASHTABLE(a,ha);
 
-/* die partitionen in ha werden immer kuerzer */
+    /* die partitionen in ha werden immer kuerzer */
     NEW_HASHTABLE(h2);
     NEW_HASHTABLE(h3);
 
@@ -342,14 +325,12 @@ INT monomial_recursion2(a,b,faktor,partf,integerf,elmsymf,multf) OP a,b;OP fakto
         m2 = CALLOCOBJECT();
         erg += b_sk_mo(NULL,NULL,m2);
         C_MO_S(m2,S_MO_S(z));
-        
- 
+
         c = find_hashtable(m2,m1,eq_monomsymfunc,hash_monompartition);
         SYMCHECK( (c == NULL) ,"monomial_recursion2:wrong leading monomial");
         coeff = CALLOCOBJECT();
         erg += div(S_MO_K(z),S_MO_K(c),coeff); /* leitkoeff */
         MULT_APPLY(coeff,m1);
-
         /* es gilt jetzt m_a = (m_p1 * m_p2 )*coeff - m1 */
 
         /* m1 von ha abziehen */
@@ -361,14 +342,14 @@ INT monomial_recursion2(a,b,faktor,partf,integerf,elmsymf,multf) OP a,b;OP fakto
         erg += (*partf)(p1,h2,coeff);
         C_MO_S(m2,p1);
         C_MO_K(m2,coeff);
-        FREEALL(m2); /* wg NULL in b_sk_mo *//* p1, coeff freed */
+        FREEALL(m2); /* wg NULL in b_sk_mo */
+	/* p1, coeff freed */
 
         erg += (*partf)(p2,h3,faktor);
         FREEALL(p2);
 
         erg += (*multf)(h3,h2,b);
 
-  
         CLEAR_HASHTABLE(h2);
         CLEAR_HASHTABLE(h3);
         }
@@ -380,7 +361,7 @@ INT monomial_recursion2(a,b,faktor,partf,integerf,elmsymf,multf) OP a,b;OP fakto
 }
 
 
-INT tmh_monomial__faktor(a,b,faktor) OP a,b;OP faktor;
+INT tmh_monomial__faktor(OP a, OP b, OP faktor)
 {
     INT erg = OK;
     CTTO(HASHTABLE,MONOMIAL,"tmh_monomial__faktor(1)",a);
@@ -389,17 +370,17 @@ INT tmh_monomial__faktor(a,b,faktor) OP a,b;OP faktor;
     monomial_recursion2(a,b,faktor,
              tmh_partition__faktor,tmh_integer__faktor,teh_integer__faktor,
              mult_homsym_homsym);
-    
-   
+
     ENDR("tmh_monomial__faktor");
 }
 
-INT tmh___faktor(a,b,faktor) OP a,b;OP faktor;
-/* AK 180901 */
-/* after multiplication by the faktor 
-   the result will be inserted in the hashtable b
-*/
-/* not static used from tme.c */   
+
+/* after multiplication by the faktor, the result will be inserted in
+ * the hashtable b.
+ *
+ * (not static because it's used in tme.c)
+ */
+INT tmh___faktor(OP a, OP b, OP faktor)
 {
     INT erg = OK;
     CTTTTO(HASHTABLE,INTEGER,MONOMIAL,PARTITION,"tmh___faktor(1)",a);
@@ -407,7 +388,7 @@ INT tmh___faktor(a,b,faktor) OP a,b;OP faktor;
     CTO(ANYTYPE,"tmh___faktor(3)",faktor);
     if (mh_speicher == NULL) { mh_speicher=CALLOCOBJECT();
                                m_il_v(20,mh_speicher); }
-    if (S_O_K(a) == INTEGER) 
+    if (S_O_K(a) == INTEGER)
         {
         erg += tmh_integer__faktor(a,b,faktor);
         goto eee;
@@ -427,11 +408,8 @@ eee:
 }
 
 
-
-static INT m_k_to_h_lambda(a,b,c) OP a,b,c;
-/* AK 180901 */
-/* computes the single coefficient */
-/* of h_b in the expansion of m_k */
+/* computes the single coefficient of h_b in the expansion of m_k */
+static INT m_k_to_h_lambda(OP a, OP b, OP c)
 {
     INT erg = OK,w,i,l;
     OP exp,oben,mn,bn,unten;
@@ -444,17 +422,15 @@ static INT m_k_to_h_lambda(a,b,c) OP a,b,c;
     if (w != S_I_I(a)) {
         error("different weights");
         goto endr_ende; }
-       
 
     exp = CALLOCOBJECT();
     erg += t_VECTOR_EXPONENT(b,exp);
-    
 
     w = w - S_PA_II(exp,0);
     l = S_PA_LI(b)-S_PA_II(exp,0);
     FREESELF(c);
 
-    if (l <= 0) { 
+    if (l <= 0) {
         M_I_I(1,c);
 	FREEALL(exp);
 	goto faktor;
@@ -462,7 +438,7 @@ static INT m_k_to_h_lambda(a,b,c) OP a,b,c;
 
     oben = CALLOCOBJECT();
     mn = CALLOCOBJECT();
-    M_I_I(l,oben); 
+    M_I_I(l,oben);
     M_I_I(0,S_PA_I(exp,0));
     if (l > 12)
         erg += multinom(oben,S_PA_S(exp),mn);
@@ -473,14 +449,13 @@ static INT m_k_to_h_lambda(a,b,c) OP a,b,c;
     M_I_I(w,c);
     MULT_APPLY(mn,c);
     GANZDIV_APPLY(c,oben);
-    /* erg += div(c,oben,c); */
 
     if ((S_I_I(a)-w-1+l)  > 0) {
         M_I_I(S_I_I(a)-w-1+l,oben);
         unten = CALLOCOBJECT();
         M_I_I(l-1,unten);
         bn = CALLOCOBJECT();
-    
+
         if (S_I_I(oben) <= 12) {
             erg += binom_small(oben,unten,bn);
             MULT_APPLY_INTEGER(bn,c);
@@ -501,12 +476,10 @@ static INT m_k_to_h_lambda(a,b,c) OP a,b,c;
         FREEALL(bn);
         }
 
-    
-
     FREEALL(oben);
     FREEALL(mn);
 faktor:
-    if ((S_PA_LI(b)%2)==0) 
+    if ((S_PA_LI(b)%2)==0)
         {
         ADDINVERS_APPLY(c);
         }
@@ -514,24 +487,22 @@ faktor:
 }
 
 
-INT mult_hashtable_hashtable_faktor(a,b,d,faktor) OP a,b,d; OP faktor;
-/* AK 171001 */
-/* a und b sind hashtable */
-/* sind beides homogene homsym functions
-   sind beide sehr voll besetzt d.h. fast alle partitionenmit coeff != 0
- 
-   das ergebnis wird mit faktor in d eingefuegt */
+/* a und b sind hashtable
+ * sind beides homogene homsym functions
+ * sind beide sehr voll besetzt d.h. fast alle partitionenmit coeff != 0
+ *
+ * das ergebnis wird mit faktor in d eingefuegt
+ */
+INT mult_hashtable_hashtable_faktor(OP a, OP b, OP d, OP faktor)
 {
     OP x=NULL,y=NULL,c;
     OP wx,wy,p;
     INT erg = OK,i,j,k;
- 
+
     CTTTTO(HOMSYM,POWSYM,ELMSYM,HASHTABLE,"mult_hashtable_hashtable(1)",a);
     CTTTTO(HOMSYM,POWSYM,ELMSYM,HASHTABLE,"mult_hashtable_hashtable(2)",b);
     CTO(HASHTABLE,"mult_hashtable_hashtable(3)",d);
- 
- 
- 
+
     FORALL(x,a, { goto ee; });
 ee:
     FORALL(y,b, { goto ff; });
@@ -540,19 +511,16 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
     wy=CALLOCOBJECT(); weight(S_MO_S(y),wy);
     ADD_APPLY(wx,wy);
     p = CALLOCOBJECT();
- 
- 
+
     b_sk_mo(CALLOCOBJECT(),CALLOCOBJECT(),p);
     M_I_I(0,S_MO_K(p));
     b_ks_pa(VECTOR,CALLOCOBJECT(),S_MO_S(p));
     m_il_integervector(S_I_I(wy),S_PA_S(S_MO_S(p)));
-   
+
     /* wy ist das gewicht der ergebnispartition
-       p ist ein monom mit platz fuer die maximale partition */
- 
- 
+     * p ist ein monom mit platz fuer die maximale partition */
+
     FORALL(x,a, {
- 
         FORALL(y,b, {
             i=j=k=0;
             while ( (i<S_PA_LI(S_MO_S(y))) || (j<S_PA_LI(S_MO_S(x))) )
@@ -566,7 +534,7 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
                 else
                     { M_I_I(S_PA_II(S_MO_S(y),i), S_PA_I(S_MO_S(p),k) ); k++;i++; }
                 }
- 
+
             M_I_I(k,S_PA_L(S_MO_S(p)));
             HASH_INTEGERVECTOR(S_PA_S(S_MO_S(p)),j);
             C_PA_HASH(S_MO_S(p),j);
@@ -596,23 +564,21 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
 }
 
 
-INT mult_hashtable_hashtable(a,b,d) OP a,b,d;
-/* AK 171001 */
-/* a und b sind hashtable */
-/* sind beides homogene homsym functions
-   sind beide sehr voll besetzt d.h. fast alle partitionenmit coeff != 0
-   das ergebnis wird in d eingefuegt */
+/* a und b sind hashtable
+ * sind beides homogene homsym functions
+ * sind beide sehr voll besetzt d.h. fast alle partitionenmit coeff != 0
+ * das ergebnis wird in d eingefuegt
+ */
+INT mult_hashtable_hashtable(OP a, OP b, OP d)
 {
     OP x=NULL,y=NULL,c;
     OP wx,wy,p;
     INT erg = OK,i,j,k;
- 
+
     CTTTTO(HOMSYM,POWSYM,ELMSYM,HASHTABLE,"mult_hashtable_hashtable(1)",a);
     CTTTTO(HOMSYM,POWSYM,ELMSYM,HASHTABLE,"mult_hashtable_hashtable(2)",b);
     CTO(HASHTABLE,"mult_hashtable_hashtable(3)",d);
- 
- 
- 
+
     FORALL(x,a, { goto ee; });
 ee:
     FORALL(y,b, { goto ff; });
@@ -621,19 +587,15 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
     wy=CALLOCOBJECT(); weight(S_MO_S(y),wy);
     ADD_APPLY(wx,wy);
     p = CALLOCOBJECT();
- 
- 
+
     b_sk_mo(CALLOCOBJECT(),CALLOCOBJECT(),p);
     M_I_I(0,S_MO_K(p));
     b_ks_pa(VECTOR,CALLOCOBJECT(),S_MO_S(p));
     m_il_integervector(S_I_I(wy),S_PA_S(S_MO_S(p)));
-   
+
     /* wy ist das gewicht der ergebnispartition
-       p ist ein monom mit platz fuer die maximale partition */
- 
- 
+     * p ist ein monom mit platz fuer die maximale partition */
     FORALL(x,a, {
- 
         FORALL(y,b, {
             i=j=k=0;
             while ( (i<S_PA_LI(S_MO_S(y))) || (j<S_PA_LI(S_MO_S(x))) )
@@ -647,7 +609,7 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
                 else
                     { M_I_I(S_PA_II(S_MO_S(y),i), S_PA_I(S_MO_S(p),k) ); k++;i++; }
                 }
- 
+
             M_I_I(k,S_PA_L(S_MO_S(p)));
             HASH_INTEGERVECTOR(S_PA_S(S_MO_S(p)),j);
             C_PA_HASH(S_MO_S(p),j);
@@ -673,4 +635,3 @@ ff: /* x und y sind jetzt monome, das gemeinsame gewicht bestimmen */
      FREEALL(wy);
      ENDR("mult_hashtable_hashtable_faktor");
 }
-
