@@ -1,21 +1,15 @@
-
-/* Routinen zur Berechnung von Zykelindikatorpolynomen
- * Nikolaus Schueler 90/91
- */
+/* Routinen zur Berechnung von Zykelindikatorpolynomen */
 #include "def.h"
 #include "macro.h"
 
 /* Hier wird eigenes FALSE und TRUE eingefuehrt , weil es sich
  * hier im Gegensatz zu def.h auf unsigned short bezieht
  */
-#define N_FALSE 0 
+#define N_FALSE 0
 #define N_TRUE 1
-
-
 #define OFFSET 0
-/* diverse prozeduren zu den zykelindikatorpolynom- programmen */
-
 
+/* diverse prozeduren zu den zykelindikatorpolynom-programmen */
 #ifdef PERMTRUE
 #ifdef VECTORTRUE
 #ifdef MATRIXTRUE
@@ -29,25 +23,21 @@
 #endif
 
 #ifdef ZYKTRUE
+static INT colltypes(OP, OP, OP);
+static INT strongen(INT, INT, OP, OP);
+static INT polyasub(INT, OP, OP);
 
-
-static INT colltypes();
-static INT strongen();
-static INT polyasub();
-
-/* Die beiden naechsten Routinen werden zur Berechnung des 
+/* Die beiden naechsten Routinen werden zur Berechnung des
  * Zykelindikators der zyklischen Gruppe benoetigt
  */
 
 /* liefert den gcd (greatest common divisor) von a und b zurueck */
-
-static INT gcd(a,b) INT a,b;
-/* NS 060891 V1.3 */
+static INT gcd(INT a, INT b)
 {
-    INT c=5L; /* AK 240692 ERROR muss initialisiert werden */
+    INT c=5L;
 
     /* a soll immer den groesseren Wert enthalten */
-    if (b > a) { c=b;b=a;a=c; }  
+    if (b > a) { c=b;b=a;a=c; }
     /* Euklidischer Algorithmus */
     while(c != 0L)
     {
@@ -57,56 +47,55 @@ static INT gcd(a,b) INT a,b;
     return(a);
 }
 
-static INT eulerfunc(n) INT n;
-/* NS 060891 V1.3 */
+
+static INT eulerfunc(INT n)
 {
     INT i,h=0L;
 
     if(n == 1L) return(1L);
     for(i=1L; i < n; i++)
     {
-        if(gcd(n,i) == 1L) 
+        if(gcd(n,i) == 1L)
         {
             h++;
         }
     }
     return(h);
 }
-/* Berechnet das Zykelindikatorpolynom der Cn */   
+
 
 #ifdef BRUCHTRUE
-INT zykelind_Cn(l,pol) OP l; OP pol;
-/* NS 060891 V1.3 */
+/* Berechnet das Zykelindikatorpolynom der Cn */
+INT zykelind_Cn(OP l, OP pol)
 {
     INT d,li;
     INT erg = OK;
     OP b;
 
     CTO(INTEGER,"zykelind_Cn",l);
-    if (S_I_I(l) < 1L) /* AK 060792 */
+    if (S_I_I(l) < 1L)
         {
         error("zykelind_Cn: input < 1");
         goto endr_ende;
         }
 
-
     init(POLYNOM,pol);
-        
-    if (einsp(l)) /* AK 060792 */
+
+    if (einsp(l))
         {
         erg += m_iindex_monom(0L,pol);
         goto endr_ende;
         }
 
     b=callocobject();
-    li=S_I_I(l);    
+    li=S_I_I(l);
     for(d=1L; (d <= li) ; d++)
         if(li%d == 0L)
         {
-        /* stopf den Koeffizienten in den Typ BRUCH von symchar */
-        /* stopf das Ergebnis in den Typ POLYNOM von symchar */
+        /* stopf den Koeffizienten in den Typ BRUCH von symchar;
+         * stopf das Ergebnis in den Typ POLYNOM von symchar */
             erg += b_skn_po(callocobject(),callocobject(),NULL,b);
-            erg += m_ioiu_b(eulerfunc(d),li,S_PO_K(b)); 
+            erg += m_ioiu_b(eulerfunc(d),li,S_PO_K(b));
                         erg += kuerzen(S_PO_K(b));
             erg += m_il_nv(li,S_PO_S    (b));
             erg += m_i_i(li/d,S_PO_SI(b,d-1L));
@@ -117,14 +106,14 @@ INT zykelind_Cn(l,pol) OP l; OP pol;
 }
 #endif /* BRUCHTRUE */
 
-/* Berechnet das Zykelindikatorpolynom der Dn */   
-/* Beruht auf dem Programm fuer den Zykelindex der Cn, da fuer
- * den Zykelindex der Diedergruppe Dn nur ein Summand dazukommt
- * , ruft zykelind_Cn auf.
- */
 
-INT zykelind_Dn(l,pol) OP l; OP pol;
-/* NS 060891 V1.3 */
+/* Berechnet das Zykelindikatorpolynom der Dn
+ *
+ * Beruht auf dem Programm fuer den Zykelindex der Cn, da fuer
+ * den Zykelindex der Diedergruppe Dn nur ein Summand dazukommt,
+ * ruft zykelind_Cn auf.
+ */
+INT zykelind_Dn(OP l, OP pol)
 {
 #ifdef BRUCHTRUE
     INT len,erg=OK;
@@ -133,17 +122,13 @@ INT zykelind_Dn(l,pol) OP l; OP pol;
         CTO(INTEGER,"zykelind_Dn(1)",l);
         SYMCHECK( S_I_I(l) < 1L,"zykelind_Dn: input < 1");
 
-
     len=S_I_I(l);
-
     init(POLYNOM,pol);
-        
 
-    if (einsp(l)) /* AK 060792 */
+    if (einsp(l))
         return m_iindex_monom(0L,pol);
 
     /* Berechne den Zykelindiktor der Cn */
-
     zykelind_Cn(l,pol);
 
     b=callocobject();
@@ -154,12 +139,10 @@ INT zykelind_Dn(l,pol) OP l; OP pol;
     div(pol,cons_zwei,pol);
 
     /* Anhaengen der zusaetzlichen Summanden */
-
     b_skn_po(callocobject(),callocobject(),NULL,b);
-    m_l_nv(l,S_PO_S    (b)); 
+    m_l_nv(l,S_PO_S(b));
 
     /* Wenn m gerade ist ..*/
-
     if((long)len%2L == 0L)
     {
         erg += m_ioiu_b(1L,4L,S_PO_K(b));
@@ -171,35 +154,31 @@ INT zykelind_Dn(l,pol) OP l; OP pol;
         m_i_i(2L,S_PO_SI(b,0L));
         m_i_i((len-2L)/2L,S_PO_SI(b,1L));
         erg += add_apply(b,pol); /* addiere die zusaetzlichen Summanden */
-    }        
+    }
 
     /* Wenn m ungerade ist .. */
-
     if(len%2L == 1L)
     {
         m_ioiu_b(1L,2L,S_PO_K(b));
                 kuerzen(S_PO_K(b));
 
         /* y1 in das Polynom eintragen */
-
-        m_i_i(1L,S_PO_SI(b,0L)); 
+        m_i_i(1L,S_PO_SI(b,0L));
 
         /* y2 hoch (n-1L)/2 in das Polynom eintragen */
-
-        m_i_i(((long)len-1L)/2L,S_PO_SI(b,1L)); 
+        m_i_i(((long)len-1L)/2L,S_PO_SI(b,1L));
         add_apply(b,pol); /* addiere die zusaetzlichen Summanden */
-    }        
+    }
     freeall(b);
     freeall(halb);
     freeall(hilf);
     ENDR("zykelind_Dn");
 #endif /*BRUCHTRUE*/
 }
-/* Berechnet das Zykelindikatorpolynom der An */   
 
 
-INT zykelind_An(l,pol) OP l; OP pol;
-/* NS 060891 V1.3 */
+/* Berechnet das Zykelindikatorpolynom der An */
+INT zykelind_An(OP l, OP pol)
 {
 #ifdef BRUCHTRUE
     INT i,j,veklen,veklen2;
@@ -213,12 +192,12 @@ INT zykelind_An(l,pol) OP l; OP pol;
     OP zahl;
     OP zwisch;
 
-    if (S_O_K(l) != INTEGER)  /* AK 060792 */
+    if (S_O_K(l) != INTEGER)
         return error("zykelind_An: input not INTEGER");
-    if (S_I_I(l) < 1L) /* AK 060792 */
+    if (S_I_I(l) < 1L)
         return error("zykelind_An: input < 1");
 
-    if (einsp(l)) /* AK 040692 */
+    if (einsp(l))
         {
         return m_iindex_monom(0L,pol);
         }
@@ -237,32 +216,29 @@ INT zykelind_An(l,pol) OP l; OP pol;
     b_skn_po(callocobject(),callocobject(),NULL,a);
 
     /* lasse alle partitionen berechnen */
-
-    makevectorofpart(l,v); 
+    makevectorofpart(l,v);
     veklen=S_V_LI(v);
-    m_l_nv(l,S_PO_S    (a));  /* AK 040692 Macro */
+    m_l_nv(l,S_PO_S(a));
     for(i=0L; i < veklen ; i++)
     {
         /* umwandeln in Exponentenschreibweise */
         t_VECTOR_EXPONENT(S_V_I(v,i),party);
         /* und umwandeln in ein Monom */
-        copy(S_PA_S(party),S_PO_S    (a));  /* AK 040692 Macro */
-         
-        veklen2=S_V_LI(S_PO_S    (a));  /* AK 040692 Macro */
+        copy(S_PA_S(party),S_PO_S    (a));
+
+        veklen2=S_V_LI(S_PO_S    (a));
         m_i_i(0L,zwisch); /* Variable entleeren */
 
         for(j=1L; j < veklen2; j+=2L)
         {
         /* addiere a[2], a[4], ... auf */
-        add_apply(S_PO_SI(a,j),zwisch);  /* AK 040692 statt add */
-        }    
+        add_apply(S_PO_SI(a,j),zwisch);
+        }
         /* Nur wenn a[2]+a[4]+... ungerade ist, dann gibts einen Koeff-
-         * izienten 
-         */
+         * izienten */
         if(even(zwisch))
         {
             /* Berechnen der Koeffizienten */
-
             m_i_i(1L,k);
             for(j=0L; j < veklen2; j++)
             {
@@ -275,7 +251,7 @@ INT zykelind_An(l,pol) OP l; OP pol;
             m_i_i(2L,zwisch);
             m_ou_b(zwisch,k,S_PO_K(a));
             kuerzen(S_PO_K(a));
-            add_apply(a,pol); /* AK 040692 statt add */
+            add_apply(a,pol);
         }
     }
     freeall(a);
@@ -291,15 +267,13 @@ INT zykelind_An(l,pol) OP l; OP pol;
     return error("zykelind_An: BRUCH not available");
 #endif /* BRUCHTRUE */
 }
-/* 
- * Berechnet das Zykelindikatorpolynom der Sn    
+
+
+/* Berechnet das Zykelindikatorpolynom der Sn
+ *
+ * l and pol may be equal
  */
-
-
-INT zykelind_Sn(l,pol) OP l; OP pol;
-/* NS 060891 V1.3 */
-/* AK 300998 V2.0 */
-/* l and pol may be equal */
+INT zykelind_Sn(OP l, OP pol)
 {
     INT erg = OK;
 
@@ -314,19 +288,18 @@ INT zykelind_Sn(l,pol) OP l; OP pol;
 
     erg += b_skn_po(CALLOCOBJECT(),CALLOCOBJECT(),NULL,a);
 
-    erg += makevectorofpart(l,v); 
+    erg += makevectorofpart(l,v);
     veklen=S_V_LI(v);
     erg += m_l_nv(l,S_PO_S    (a));
     erg += init(POLYNOM,pol);
     for(i=0L; i < veklen ; i++)
     {
         /* umwandeln in Exponentenschreibweise */
-        erg += t_VECTOR_EXPONENT(S_V_I(v,i),party); 
+        erg += t_VECTOR_EXPONENT(S_V_I(v,i),party);
         /* und umwandeln in ein Monom */
         CLEVER_COPY(S_PA_S(party),S_PO_S(a));
-         
-        /* Berechnen der Koeffizienten */
 
+        /* Berechnen der Koeffizienten */
         m_i_i(1,k);
         veklen2=S_V_LI(S_PO_S    (a));
         for(j=0L; j < veklen2; j++)
@@ -349,21 +322,19 @@ INT zykelind_Sn(l,pol) OP l; OP pol;
 /* Hier folgen die Routinen fuer die Berechnung der Zykel-
  * indizes von beliebigen Permutationsgruppen, die durch
  * erzeugende Permutationen gegeben sind
+ *
+ * routinen zur berechnung eines starken Erzeugers nach Hoffmann
  */
-/* routinen zur berechnung eines starken Erzeugers nach Hoffmann 
- */
-
-
 struct treecomp {
     unsigned short atr; /* 0=FALSE, 1=TRUE */
     INT gen;
     INT point;
 };
 
-static INT stabilizer(i,vec,stabi) INT i; OP vec; OP stabi;
-/* NS 060891 V1.3 */
-/* AK 101291 vec ist VECTOR of PERMUTATION
-             stabi wird VECTOR of PERMUTATION */
+/* vec ist VECTOR of PERMUTATION
+ * stabi wird VECTOR of PERMUTATION
+ */
+static INT stabilizer(INT i, OP vec, OP stabi)
 {
     unsigned short is_stab;
     INT j,k; /* Schleifenzaehler */
@@ -378,7 +349,7 @@ static INT stabilizer(i,vec,stabi) INT i; OP vec; OP stabi;
         for(k=0 ; k < i-1L; k++)
         {
             if(S_P_II(S_V_I(vec,j),k) != k+1L)
-            {    
+            {
                 is_stab=N_FALSE;
                 break;
             }
@@ -392,9 +363,8 @@ static INT stabilizer(i,vec,stabi) INT i; OP vec; OP stabi;
     return OK;
 }
 
-static INT updatemat(degree,i,tree,stabi,repma) 
-    INT degree,i; struct treecomp *tree; OP stabi,repma;
-/* NS 060891 V1.3 */
+
+static INT updatemat(INT degree, INT i, struct treecomp *tree, OP stabi, OP repma)
 {
     INT l,next;
     OP id=callocobject();
@@ -408,7 +378,7 @@ static INT updatemat(degree,i,tree,stabi,repma)
      * von i mache einen Eintrag i,k in der Repraesentations
      * matrix und zwar das Produkt aller Erzeuger, die i
      * sukzessive nach k bewegt haben, dazu benutzte alle
-     * Eintrage in tree.gen auf dem Weg zurueck von k nach i (=wort)  
+     * Eintrage in tree.gen auf dem Weg zurueck von k nach i (=wort)
      * und multipliziere die entsprechenden Erzeuger
      */
     for(l=i; l < degree; l++)
@@ -436,9 +406,7 @@ static INT updatemat(degree,i,tree,stabi,repma)
 /* sift() sieht nach, ob perm in der Repraesentationsmatrix
  * repma enthalten ist. sift() wird von strongen benoetigt.
  */
-
-static INT sift(degree,insrow,perm,repma) INT degree, *insrow; OP perm,repma;
-/* NS 060891 V1.3 */
+static INT sift(INT degree, INT *insrow, OP perm, OP repma)
 {
     register unsigned short ismember=N_TRUE;
     INT i=0L,j;
@@ -458,7 +426,7 @@ static INT sift(degree,insrow,perm,repma) INT degree, *insrow; OP perm,repma;
             ismember=N_FALSE;
             copy(perm,S_M_IJ(repma,i-1L,j-1L));
             /* In diese Zeile wurde die Permutation eingefuegt */
-            (*insrow)=i-1L; 
+            (*insrow)=i-1L;
             break;
         }
     }
@@ -466,25 +434,22 @@ static INT sift(degree,insrow,perm,repma) INT degree, *insrow; OP perm,repma;
     return(ismember);
 }
 
-/* porbit(degree,i,stabi,tree) berechnet die Bahn eines Punktes 
- * i und gibt 
+/* porbit(degree,i,stabi,tree) berechnet die Bahn eines Punktes
+ * i und gibt
+ *
+ * stabi = Stabilisator von 1L,...,i-1
+ *
  * folgenden Baum (tree) zurueck:
  *
- * 
  * tree[r].atr: TRUE, wenn r in der Bahn von i liegt, sonst FALSE
  * tree[r].gen: Nummer k des Generators g[k], der s-> r abb.
  * tree[r].point: Bahnpunkt s, der von dem generator g[k] nach
  *                  r abbgebildet wird, tree[i].point = 0L, um
  * anzuzeigen, dass i die Wurzel des Baumes ist.
- * 
+ *
  * porbit() wird von strongen() benoetigt.
  */
-
-
-static INT porbit(degree,i,stabi,tree) INT degree,i; 
-    OP stabi; /* Stabilisator von 1L,...,i-1 */ 
-    struct treecomp tree[];
-/* NS 060891 V1.3 */
+static INT porbit(INT degree, INT i, OP stabi, struct treecomp tree[])
 {
     INT pos=0L;
     INT stablen;
@@ -494,8 +459,7 @@ static INT porbit(degree,i,stabi,tree) INT degree,i;
     stablen=S_V_LI(stabi);
     points=(INT *) SYM_malloc(sizeof(INT)*degree+OFFSET);
     points[pos] = i; /* initialisiere points mit dem Punkt,
-                    * dessen Bahn gesucht wird
-                    */
+		      * dessen Bahn gesucht wird*/
     for(j=0L; j < degree; j++)
     {
         tree[j].atr=N_FALSE;
@@ -510,7 +474,7 @@ static INT porbit(degree,i,stabi,tree) INT degree,i;
         for(g=0L; g < stablen; g++)
         {
             /* Bestimme das Bild r von s unter dem g-ten Stabilisator */
-            r=S_P_II(S_V_I(stabi,g),s-1L);  
+            r=S_P_II(S_V_I(stabi,g),s-1L);
 
             if(not tree[r-1].atr)
             {
@@ -530,10 +494,11 @@ static INT porbit(degree,i,stabi,tree) INT degree,i;
  */
 
 #ifdef MATRIXTRUE
-INT strong_generators(a,b) OP a,b;
-/* AK 290192 */
-/* a VECTOR of generators
-   b becomes MATRIX of stronggenerators */
+/*
+ * a VECTOR of generators
+ * b becomes MATRIX of stronggenerators
+ */
+INT strong_generators(OP a, OP b)
 {
     INT degree, numgen;
     INT erg = OK;
@@ -545,27 +510,24 @@ INT strong_generators(a,b) OP a,b;
 }
 
 
-
-static INT strongen(degree,numgen,genvec,repma) 
-    INT degree; /* numgen= Anzahl der Erzeuger wird von 
-        strongen an sift() * weitergereicht.  */ 
-    INT numgen; 
-    OP genvec; /* Vektor der die Erzeuger einer Gruppe enthaelt */
-    OP repma; /* Repraesentationsmatrix fuer die Gruppe */
-/* NS 060891 V1.3 */
+/* INT degree; numgen = Anzahl der Erzeuger wird von
+ *   strongen an sift() * weitergereicht.
+ * OP genvec = Vektor der die Erzeuger einer Gruppe enthaelt
+ * OP repma =  Repraesentationsmatrix fuer die Gruppe
+ */
+static INT strongen(INT degree, INT numgen, OP genvec, OP repma)
 {
     INT i,j,k,l; /* Schleifenzaehler */
     INT row;
     INT stablen;
-    INT erg = OK; /* AK 290192 */
+    INT erg = OK;
     struct treecomp *tree;
 
     OP id=callocobject();
     OP queue=callocobject();
     OP ob_degree=callocobject();
     OP perm_eins=callocobject();
-    /* stabi ist Vektor von Permutationen. 
-     */
+    /* stabi ist Vektor von Permutationen */
     OP stabi=callocobject();
     OP strgset=callocobject();
 
@@ -573,7 +535,6 @@ static INT strongen(degree,numgen,genvec,repma)
     m_i_i(degree,ob_degree);
     erg +=first_permutation(ob_degree,id);
 
-
     /* Stabilisator ist am Anfang der ganze Erzeuger */
     erg +=m_il_v(numgen,strgset);
     erg +=m_il_v(0L,stabi);
@@ -585,7 +546,7 @@ static INT strongen(degree,numgen,genvec,repma)
     /* Diagonale der Repraesentationsmatrix mit id besetzen */
     for(k=0L; k < degree; k++)
         erg +=copy(id,S_M_IJ(repma,k,k));
-    
+
     for(i=1L; i <= degree; i++)
     {
 
@@ -603,8 +564,7 @@ static INT strongen(degree,numgen,genvec,repma)
 
         for(l=0L; l < stablen; l++)
         {
-        /* for(k=i-1L; k <= degree; k++) */
-            for(k=i-1L; k < degree; k++) 
+            for(k=i-1L; k < degree; k++)
                 /* statt <= degree < degree */
                 if(not EMPTYP(S_M_IJ(repma,i-1L,k)))
                 {
@@ -613,7 +573,7 @@ static INT strongen(degree,numgen,genvec,repma)
         erg +=copy(perm_eins,S_V_I(queue,S_V_LI(queue)-1L));
                 }
         }
-    
+
     while(S_V_LI(queue))
     {
         erg +=copy(S_V_I(queue,S_V_LI(queue)-1L),perm_eins);
@@ -625,13 +585,12 @@ static INT strongen(degree,numgen,genvec,repma)
 
             for(j=1L; j <= row; j++)
 
-            {    
+            {
                 erg +=stabilizer(j,strgset,stabi);
                 erg +=porbit(degree,j,stabi,tree);
-                erg +=updatemat(degree,j,tree,stabi,repma); 
+                erg +=updatemat(degree,j,tree,stabi,repma);
 
-                /*for(l=j-1L; l <= degree; l++)*/
-                for(l=j-1L; l < degree; l++) 
+                for(l=j-1L; l < degree; l++)
                     /* < degree statt <= degree */
                 {
                     if(not EMPTYP(S_M_IJ(repma,j-1L,l)))
@@ -644,7 +603,7 @@ static INT strongen(degree,numgen,genvec,repma)
             }
         } /* end if */
     }    /* end while */
-    } /* AK end for 110292 */
+    } /* end for */
     erg +=freeall(id);
     erg +=freeall(queue);
     erg +=freeall(ob_degree);
@@ -657,28 +616,21 @@ static INT strongen(degree,numgen,genvec,repma)
 #endif /* MATRIXTRUE */
 
 
-static INT recu(degree,start,numnontriv,ztvec,numztvec,perm,repma)
-    INT degree; INT start; INT numnontriv;
-    OP ztvec; OP numztvec; OP perm; OP repma;
-/* NS 060891 V1.3 */
+static INT recu(INT degree, INT start, INT numnontriv, OP ztvec, OP numztvec, OP perm, OP repma)
 {
     INT i,j;
-
     OP saveperm=callocobject();
 
-
     if(start == numnontriv-1L)
     {
         for(i=start; i< degree; i++)
         {
             if(not EMPTYP(S_M_IJ(repma,start,i)))
             {
-            mult(perm,S_M_IJ(repma,start,i),saveperm); 
+            mult(perm,S_M_IJ(repma,start,i),saveperm);
             colltypes(saveperm,ztvec,numztvec);
             }
         }
-
-
     }
     else
         for(j=start; j < degree; j++)
@@ -693,13 +645,9 @@ static INT recu(degree,start,numnontriv,ztvec,numztvec,perm,repma)
     freeall(saveperm);
     return OK;
 }
-        
 
 
-
-
-static INT callrecu(grad,ztvec,numztvec,repma) INT grad; OP ztvec,numztvec,repma;
-/* NS 060891 V1.3 */
+static INT callrecu(INT grad, OP ztvec, OP numztvec, OP repma)
 {
     unsigned short trivrow;
     INT i,j;
@@ -713,11 +661,10 @@ static INT callrecu(grad,ztvec,numztvec,repma) INT grad; OP ztvec,numztvec,repma
      * hier erstmal festgestellt, ab wo die Matrix leer
      * ist
      */
-
     for(i=grad-1L; i > 0L; i--)
     {
         trivrow=N_TRUE;
-        
+
         for(j=i+1L; j < grad; j++)
         {
             if(not EMPTYP(S_M_IJ(repma,i,j)))
@@ -740,12 +687,10 @@ static INT callrecu(grad,ztvec,numztvec,repma) INT grad; OP ztvec,numztvec,repma
     freeall(ob_grad);
     freeall(perm);
     return OK;
-} /* end all */
+}
 
 
-
-static INT colltypes(perm,ztvec,numztvec) OP perm, ztvec, numztvec;
-/* NS 060891 V1.3 */
+static INT colltypes(OP perm, OP ztvec, OP numztvec)
 {
     INT i;
     INT ztveclen;
@@ -755,7 +700,7 @@ static INT colltypes(perm,ztvec,numztvec) OP perm, ztvec, numztvec;
     ztveclen=S_V_LI(ztvec);
     zykeltyp(perm,ztperm);
     t_VECTOR_EXPONENT(ztperm,expztperm);
-    
+
     for(i=0L; i < ztveclen; i++)
     {
         if(comp(expztperm,S_V_I(ztvec,i)) == 0L)
@@ -773,7 +718,9 @@ ende:
     freeall(ztperm);
     freeall(expztperm);
     return OK;
-}            
+}
+
+
 /* berechnet das Zykelindikatorpolynom einer beliebigen Permutations-
  * gruppe, benutzt dazu die uebergebenen Vektoren, die die
  * Zykeltypen (expztvec), bzw deren Anzahlen (numztvec)
@@ -781,16 +728,14 @@ ende:
  */
 
 #ifdef BRUCHTRUE
-static INT zykelind_arb_co(expztvec,numztvec,pol)
-    OP expztvec;
-    OP numztvec;
-    OP pol; /* enhaelt nach Ablauf der Routine das Zykelindikator-
-             * polynom (noch nicht Polyasubstituiert)
-             */
-/* NS 060891 V1.3 */
+/*
+ *  OP pol; enhaelt nach Ablauf der Routine das Zykelindikator-
+ *          polynom (noch nicht Polyasubstituiert)
+ */
+static INT zykelind_arb_co(OP expztvec, OP numztvec, OP pol)
 {
     INT i,order,veklen;
-        INT erg = OK;
+    INT erg = OK;
 
     OP a,hilf,k,party,zahl,zwisch,zykeltypvec;
     OP ak_order;
@@ -804,26 +749,22 @@ static INT zykelind_arb_co(expztvec,numztvec,pol)
     zykeltypvec = CALLOCOBJECT();
     ak_order = CALLOCOBJECT();
 
-    SYM_sum(numztvec,ak_order); /* AK 060295 */
-
-
+    SYM_sum(numztvec,ak_order);
 
     b_skn_po(CALLOCOBJECT(),CALLOCOBJECT(),NULL,a);
 
     veklen=S_V_LI(expztvec);
-    m_il_nv(5,S_PO_S(a)); 
+    m_il_nv(5,S_PO_S(a));
     init(POLYNOM,pol);
     for(i=0L; i < veklen ; i++)
     {
         COPY(S_PA_S(S_V_I(expztvec,i)),S_PO_S    (a));
-        /* m_i_i(order,k); */
         m_ou_b(S_V_I(numztvec,i),ak_order,S_PO_K(a));
-        /* m_ou_b(S_V_I(numztvec,i),k,S_PO_K(a)); */
         kuerzen(S_PO_K(a));
         add_apply(a,pol);
     }
-    FREEALL3(a,hilf,k); 
-    FREEALL5(ak_order,party,zahl,zwisch,zykeltypvec); 
+    FREEALL3(a,hilf,k);
+    FREEALL5(ak_order,party,zahl,zwisch,zykeltypvec);
     ENDR("zykelind_arb_co:internal routine");
 }
 #endif /* BRUCHTRUE */
@@ -831,15 +772,11 @@ static INT zykelind_arb_co(expztvec,numztvec,pol)
 /*
  * Die Funktion zykelind_arb fasst die Funktionen strongen,
  * callrecu und zykelind_arb_co zusammen. Eingabeparameter
- * der Vektor von Permutationen genvec, er enthaelt die Erzeuger 
- * der Gruppe, in pol wird dann das Zykelindikator polynom 
+ * der Vektor von Permutationen genvec, er enthaelt die Erzeuger
+ * der Gruppe, in pol wird dann das Zykelindikator polynom
  * geliefert.
  */
-
-INT zykelind_arb(genvec,pol) OP genvec; OP pol;
-/* NS 060891 V1.3 */
-/* AK 180998: now the generating permutations may have different
-                degree */
+INT zykelind_arb(OP genvec, OP pol)
 {
 #ifdef BRUCHTRUE
         INT degree,i,j;
@@ -856,12 +793,12 @@ INT zykelind_arb(genvec,pol) OP genvec; OP pol;
 
         /* degree und numgen bestimmen */
         degree=S_P_LI   (S_V_I(genvec,0L));
-        for (i=1;i<S_V_LI(genvec);i++) /* AK 180998 */
+        for (i=1;i<S_V_LI(genvec);i++)
                 if (S_P_LI   (S_V_I(genvec,i)) > degree)
                         degree=S_P_LI   (S_V_I(genvec,i));
         numgen=S_V_LI(genvec);
-        erg += m_il_v(numgen,mygenvec); /* AK 180998 */
-        for (i=0;i<numgen;i++) /* AK 180998 */
+        erg += m_il_v(numgen,mygenvec);
+        for (i=0;i<numgen;i++)
                 {
                 if (degree==S_P_LI   (S_V_I(genvec,i)))
                         erg += copy_permutation(S_V_I(genvec,i), S_V_I(mygenvec,i));
@@ -884,20 +821,21 @@ INT zykelind_arb(genvec,pol) OP genvec; OP pol;
         return error("zkelind_arb: BRUCH not available");
 #endif /* BRUCHTRUE */
 }
+
+
 /* routine zur Polyasubstitution */
 
-
-INT polya_n_sub(p,n,e) OP p,n,e;
-/* AK 060792 */
+INT polya_n_sub(OP p, OP n, OP e)
 {
     return polyasub(S_I_I(n),p,e);
 }
 
-static INT polyasub(numcol,pol,pattpol)
-    INT numcol; /* Anzahl der Farben */
-    OP pol; /* Zykelindikatorpolynom */
-    OP pattpol; /* Ergebnis: Musterpolynom */
-/* NS 060891 V1.3 */
+/*
+ *  INT numcol = Anzahl der Farben
+ *  OP pol = Zykelindikatorpolynom
+ *  OP pattpol = Ergebnis: Musterpolynom
+ */
+static INT polyasub(INT numcol, OP pol, OP pattpol)
 {
     INT i,j; /* Schleifenzaehler */
     INT degree;
@@ -909,18 +847,18 @@ static INT polyasub(numcol,pol,pattpol)
 
     /* Farbenvector herstellen:
      * Monom abc...... -> [11...1][22...2]...[nn...n]
-     * wobei die Laenge von [xx...x] gleich der Anzahl der 
+     * wobei die Laenge von [xx...x] gleich der Anzahl der
      * Farben ist und n die Maechtigkeit der Menge X,
      * auf der die Gruppe operiert.
      */
-    erg += numberofvariables(pol,exp);     /* AK 211194 */
+    erg += numberofvariables(pol,exp);
     degree=S_I_I(exp);
     erg += m_il_v(degree,colvec);
     erg += b_skn_po(callocobject(),callocobject(),NULL,compcolpol);
     erg += b_skn_po(callocobject(),callocobject(),NULL,hpol);
 
     FREESELF(pattpol);
-    
+
     for(i=0L; i < degree; i++)
     {
         erg += init(POLYNOM,compcolpol);
@@ -938,16 +876,16 @@ static INT polyasub(numcol,pol,pattpol)
 
     FREEALL4(colvec,compcolpol,hpol,exp);
     ENDR("zyk:internal function polyasub");
-}    
+}
 
 /* Algorithmus von dimino, berechnet eine Liste mit allen
  * Elementen einer Gruppe aus den erzeugenden Permutationen.
  */
 
-INT dimino(elm) OP elm; 
-/* enthaelt am Anfang die Erzeuger der Gruppe, nach 
- * Ablauf der Routine dann alle Gruppenelemente */
-/* NS 060891 V1.3 */
+/* enthaelt am Anfang die Erzeuger der Gruppe, nach
+ * Ablauf der Routine dann alle Gruppenelemente
+ */
+INT dimino(OP elm)
 {
     INT i,j,k,
         cosetlen, elt_not_elm, numgen,
@@ -959,9 +897,9 @@ INT dimino(elm) OP elm;
     OP elt,g,genvec,id;
     CTO(VECTOR,"dimino(1)",elm);
 
-    elt=callocobject(); /* Hilfsvariable fuer Test auf Enhaltensein
-                            * in elm
-                            */
+    /* Hilfsvariable fuer Test auf Enhaltensein in elm */
+    elt=callocobject();
+
     g=callocobject(); /* eine Permutation */
     genvec=callocobject(); /* enhaelt die Erzeuger */
     id=callocobject(); /* die identische Permutation */
@@ -974,26 +912,24 @@ INT dimino(elm) OP elm;
     eins(S_V_I(genvec,0),id);
 
     /* Liste der Elemente anlegen, laenge ist erstmal = 1 */
-    erg += m_il_v(1L,elm); 
+    erg += m_il_v(1L,elm);
 
     /* Spezialfall G= <S1> */
-
     COPY(id,S_V_I(elm,order)); /* 1. Element ist id */
     COPY(S_V_I(genvec,0L),g); /* g:=s1 */
     // while(comp(g,id)) /* Solange g ungleich id */
     while(not einsp(g)) /* Solange g ungleich id */
     {
         /* Elementevektor muss jedesmal erst um 1 verlaengert werden */
-        INC(elm); 
-        ++order; /* AK 060891 */
+        INC(elm);
+        ++order;
         COPY(g,S_V_I(elm,order)); /* elm[order]=g */
         CLEVER_MULT(S_V_I(elm,order),S_V_I(genvec,0L),g); /* g:=g*s1 */
     }
 
     /* Laenge der Nebenklassen feststellen, muss man nur einmal machen,
-     * da alle Nebenklassen gleiche Laenge haben
-     */
-    cosetlen=S_V_LI(elm); 
+     * da alle Nebenklassen gleiche Laenge haben */
+    cosetlen=S_V_LI(elm);
 
     /* Falls es mehr als einen Erzeuger gibt */
     for(i=1L; i < numgen; i++)
@@ -1005,23 +941,22 @@ INT dimino(elm) OP elm;
 
         /* Wenn s[i] nicht in elm:
          * s[i] und seine Nebenklasse g*s[i]
-         * zu elm hinzufuegen
-         */
+         * zu elm hinzufuegen */
         if(si_not_elm) /* Wenn s(i) nicht in elm */
         {
             /* s[i] hinzufuegen */
             /* Elementevektor muss jedesmal erst um 1 verlaengert werden */
-            inc(elm); 
+            inc(elm);
             ++order;
             COPY(S_V_I(genvec,i),S_V_I(elm,order));
             /* Nebenklasse zu elm hinzufuegen */
-            for(j=1L; j < cosetlen; j++)        
+            for(j=1L; j < cosetlen; j++)
             {
             /* ++order,elm[order]:=elm[j]*s[i] */
-            /* Elementevektor muss jedesmal erst 
-                um 1 verlaengert werden */
+            /* Elementevektor muss jedesmal erst
+             * um 1 verlaengert werden */
             inc(elm);
-            ++order; 
+            ++order;
             MULT(S_V_I(elm,j),S_V_I(genvec,i),S_V_I(elm,order));
             } /* end for */
 
@@ -1035,32 +970,29 @@ INT dimino(elm) OP elm;
                         S_V_I(genvec,s_count),elt);
 
                     elt_not_elm=1L;
-                    for(k=0L; k <= order; k++) 
+                    for(k=0L; k <= order; k++)
                         /* elt in elm ? */
                         if((elt_not_elm=comp(elt,S_V_I(elm,k))) == 0L)
                             break;
-            
+
                     /* Wenn elt nicht in elm:
                      * elt und seine Nebenklasse g*elt
-                     * zu elm hinzufuegen
-                     */
+                     * zu elm hinzufuegen */
                     if(elt_not_elm)
                     {
-                    /* elt hinzufuegen */
-                    /* Elementevektor muss jedesmal erst 
-                         * um 1 verlaengert werden 
-                         */
-                        INC(elm); 
+		        /* elt hinzufuegen */
+		        /* Elementevektor muss jedesmal erst
+                         * um 1 verlaengert werden */
+                        INC(elm);
                         ++order;
                         COPY(elt,S_V_I(elm,order));
                     /* Nebenklasse zu elm hinzufuegen */
-                        for(j=1L; j < cosetlen; j++)        
+                        for(j=1L; j < cosetlen; j++)
                         {
                            /* ++order,elm[order]:=elm[j]*s[i] */
-                           /* Elementevektor muss jedesmal erst 
-                            * um 1 verlaengert werden 
-                             */
-                           INC(elm); 
+                           /* Elementevektor muss jedesmal erst
+                            * um 1 verlaengert werden */
+                           INC(elm);
                            ++order;
                            MULT(S_V_I(elm,j),elt,S_V_I(elm,order));
                         } /* end for */
@@ -1078,9 +1010,7 @@ INT dimino(elm) OP elm;
 }
 
 
-INT grf_arb(gr,n,res) OP gr,n,res;
-/* AK 220998 V2.0 */
-/* AK 091204 V3.0 */
+INT grf_arb(OP gr, OP n, OP res)
 {
         INT erg = OK;
         CTO(INTEGER,"grf_arb(2)",n);
@@ -1097,8 +1027,7 @@ INT grf_arb(gr,n,res) OP gr,n,res;
 }
 
 
-INT grf_Sn(gr,n,res) OP gr,n,res;
-/* AK 220998 V2.0 */
+INT grf_Sn(OP gr, OP n, OP res)
 {
         INT erg = OK;
         CTO(INTEGER,"grf_Sn",n);
@@ -1114,8 +1043,8 @@ INT grf_Sn(gr,n,res) OP gr,n,res;
         ENDR("grf_Sn");
 }
 
-INT grf_An(gr,n,res) OP gr,n,res;
-/* AK 220998 V2.0 */
+
+INT grf_An(OP gr, OP n, OP res)
 {
         OP zw;
         INT erg = OK;
@@ -1129,8 +1058,8 @@ INT grf_An(gr,n,res) OP gr,n,res;
         ENDR("grf_An");
 }
 
-INT grf_Cn(gr,n,res) OP gr,n,res;
-/* AK 220998 V2.0 */
+
+INT grf_Cn(OP gr, OP n, OP res)
 {
         OP zw;
         INT erg = OK;
@@ -1144,8 +1073,8 @@ INT grf_Cn(gr,n,res) OP gr,n,res;
         ENDR("grf_Cn");
 }
 
-INT grf_Dn(gr,n,res) OP gr,n,res;
-/* AK 220998 V2.0 */
+
+INT grf_Dn(OP gr, OP n, OP res)
 {
         OP zw;
         INT erg = OK;
@@ -1160,10 +1089,7 @@ INT grf_Dn(gr,n,res) OP gr,n,res;
 }
 
 
-
-
-INT no_orbits_arb(a,b,c) OP a,b,c;
-/* AK 071098 V2.0 */
+INT no_orbits_arb(OP a, OP b, OP c)
 {
     OP d,e;
     OP z;
@@ -1189,4 +1115,3 @@ INT no_orbits_arb(a,b,c) OP a,b,c;
 }
 
 #endif /* ZYKTRUE */
-
